@@ -1,9 +1,11 @@
+define(
+//begin v1.x content
 ({
 	createLinkTitle: "Propiedades del enlace",
 	insertImageTitle: "Propiedades de la imagen",
 	url: "URL:",
-	text: "Descripción: ",
-	target: "Destino: ",
+	text: "Descripción:",
+	target: "Destino:",
 	set: "Establecer",
 	currentWindow: "Ventana actual",
 	parentWindow: "Ventana padre",
@@ -11,3 +13,5 @@
 	newWindow: "Nueva ventana"
 })
 
+//end v1.x content
+);
