@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	createLinkTitle: "תכונות קישור",
 	insertImageTitle: "תכונות תמונה",
@@ -5,9 +7,11 @@
 	text: "תיאור:",
 	target: "יעד:",
 	set: "הגדרה",
-	currentWindow: "חלון נוכחי ",
+	currentWindow: "חלון נוכחי",
 	parentWindow: "חלון אב",
-	topWindow: "חלון עליון ",
+	topWindow: "חלון עליון",
 	newWindow: "חלון חדש"
 })
+//end v1.x content
+);
 
