@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	createLinkTitle: "Proprietà collegamento",
 	insertImageTitle: "Proprietà immagine",
@@ -6,8 +8,10 @@
 	target: "Destinazione:",
 	set: "Imposta",
 	currentWindow: "Finestra corrente",
-	parentWindow: "Finestra padre",
-	topWindow: "Finestra superiore",
+	parentWindow: "Finestra parent",
+	topWindow: "Finestra in primo piano",
 	newWindow: "Nuova finestra"
 })
 
+//end v1.x content
+);
