@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	'bold': 'Fet',
 	'copy': 'Kopier',
@@ -43,6 +45,9 @@
 	"print": "Skriv ut",
 	"newPage": "Ny side",
 	/* Error messages */
-	'systemShortcut': 'Handlingen "${0}" er bare tilgjengelig i nettleseren ved hjelp av en tastatursnarvei. Bruk ${1}.'
+	'systemShortcut': 'Handlingen "${0}" er bare tilgjengelig i nettleseren ved hjelp av en tastatursnarvei. Bruk ${1}.',
+	'ctrlKey':'ctrl+${0}',
+	'appleKey':'\u2318${0}' // "command" or open-apple key on Macintosh
 })
-
+//end v1.x content
+);
