@@ -1,13 +1,17 @@
+define(
+//begin v1.x content
 ({
 	createLinkTitle: "Proprietăţi legătură",
 	insertImageTitle: "Proprietăţi imagine",
 	url: "URL:",
 	text: "Descriere:",
-	target: "Ţintă:",
+	target: "Destinaţie:",
 	set: "Setare",
 	currentWindow: "Fereastra curentă",
 	parentWindow: "Fereastra părinte",
 	topWindow: "Fereastra cea mai de sus",
-	newWindow: "Fereastră nouă"
+	newWindow: "Fereastra nouă"
 })
 
+//end v1.x content
+);
