@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	fontSize: "大小",
 	fontName: "字体",
@@ -9,6 +11,7 @@
 	cursive: "草书",
 	fantasy: "虚线",
 
+	noFormat: "无",
 	p: "段落",
 	h1: "标题",
 	h2: "子标题",
@@ -22,4 +25,6 @@
 	5: "L 号",
 	6: "XL 号",
 	7: "XXL 号"
-})
\ No newline at end of file
+})
+//end v1.x content
+);
