@@ -1,16 +1,40 @@
-dojo.provide("dijit._editor.plugins.FontChoice");
+define([
+	"dojo/_base/array", // array.indexOf array.map
+	"dojo/_base/declare", // declare
+	"dojo/dom-construct", // domConstruct.place
+	"dojo/i18n", // i18n.getLocalization
+	"dojo/_base/lang", // lang.delegate lang.hitch lang.isString
+	"dojo/store/Memory", // MemoryStore
+	"dojo/_base/window", // win.withGlobal
+	"../../registry", // registry.getUniqueId
+	"../../_Widget",
+	"../../_TemplatedMixin",
+	"../../_WidgetsInTemplateMixin",
+	"../../form/FilteringSelect",
+	"../_Plugin",
+	"../range",
+	"../selection",
+	"dojo/i18n!../nls/FontChoice"
+], function(array, declare, domConstruct, i18n, lang, MemoryStore, win,
+	registry, _Widget, _TemplatedMixin, _WidgetsInTemplateMixin, FilteringSelect, _Plugin, rangeapi, selectionapi){
 
-dojo.require("dijit._editor._Plugin");
-dojo.require("dijit._editor.range");
-dojo.require("dijit._editor.selection");
-dojo.require("dijit.form.FilteringSelect");
-dojo.require("dojo.data.ItemFileReadStore");
-dojo.require("dojo.i18n");
+/*=====
+	var _Plugin = dijit._editor._Plugin;
+	var _Widget = dijit._Widget;
+	var _TemplatedMixin = dijit._TemplatedMixin;
+	var _WidgetsInTemplateMixin = dijit._WidgetsInTemplateMixin;
+	var FilteringSelect = dijit.form.FilteringSelect;
+=====*/
 
-dojo.requireLocalization("dijit._editor", "FontChoice");
 
-dojo.declare("dijit._editor.plugins._FontDropDown",
-	[dijit._Widget, dijit._Templated],{
+// module:
+//		dijit/_editor/plugins/FontChoice
+// summary:
+//		fontchoice, fontsize, and formatblock editor plugins
+
+
+var _FontDropDown = declare("dijit._editor.plugins._FontDropDown",
+	[_Widget, _TemplatedMixin, _WidgetsInTemplateMixin], {
 	// summary:
 	//		Base class for widgets that contains a label (like "Font:")
 	//		and a FilteringSelect drop down to pick a value.
@@ -20,10 +44,6 @@ dojo.declare("dijit._editor.plugins._FontDropDown",
 	//		The label to apply to this particular FontDropDown.
 	label: "",
 
-	// widgetsInTemplate: [public] boolean
-	//		Over-ride denoting the template has widgets to parse.
-	widgetsInTemplate: true,
-
 	// plainText: [public] boolean
 	//		Flag to indicate that the returned label should be plain text
 	//		instead of an example.
@@ -34,21 +54,22 @@ dojo.declare("dijit._editor.plugins._FontDropDown",
 	templateString:
 		"<span style='white-space: nowrap' class='dijit dijitReset dijitInline'>" +
 			"<label class='dijitLeft dijitInline' for='${selectId}'>${label}</label>" +
-			"<input dojoType='dijit.form.FilteringSelect' required=false labelType=html labelAttr=label searchAttr=name " +
-					"tabIndex='-1' id='${selectId}' dojoAttachPoint='select' value=''/>" +
+			"<input data-dojo-type='dijit.form.FilteringSelect' required='false' " +
+			        "data-dojo-props='labelType:\"html\", labelAttr:\"label\", searchAttr:\"name\"' " +
+					"tabIndex='-1' id='${selectId}' data-dojo-attach-point='select' value=''/>" +
 		"</span>",
 
 	postMixInProperties: function(){
 		// summary:
-		//		Over-ride to misin specific properties.
+		//		Over-ride to set specific properties.
 		this.inherited(arguments);
 
-		this.strings = dojo.i18n.getLocalization("dijit._editor", "FontChoice");
+		this.strings = i18n.getLocalization("dijit._editor", "FontChoice");
 
 		// Set some substitution variables used in the template
 		this.label = this.strings[this.command];
-		this.id = dijit.getUniqueId(this.declaredClass.replace(/\./g,"_"));
-		this.selectId = this.id + "_select";
+		this.id = registry.getUniqueId(this.declaredClass.replace(/\./g,"_"));	// TODO: unneeded??
+		this.selectId = this.id + "_select";	// used in template
 
 		this.inherited(arguments);
 	},
@@ -60,21 +81,17 @@ dojo.declare("dijit._editor.plugins._FontDropDown",
 
 		// Initialize the list of items in the drop down by creating data store with items like:
 		// {value: 1, name: "xx-small", label: "<font size=1>xx-small</font-size>" }
-		var	items = dojo.map(this.values, function(value){
+		this.select.set("store", new MemoryStore({
+			idProperty: "value",
+			data: array.map(this.values, function(value){
 				var name = this.strings[value] || value;
 				return {
 					label: this.getLabel(value, name),
 					name: name,
 					value: value
 				};
-			}, this);
-
-		this.select.store = new dojo.data.ItemFileReadStore({
-			data: {
-				identifier: "value",
-				items: items
-			}
-		});
+			}, this)
+		}));
 
 		this.select.set("value", "", false);
 		this.disabled = this.select.get("disabled");
@@ -90,9 +107,9 @@ dojo.declare("dijit._editor.plugins._FontDropDown",
 		//		Optional parameter used to tell the select whether or not to fire
 		//		onChange event.
 
-		//if the value is not a permitted value, just set empty string to prevent showing the warning icon
-		priorityChange = priorityChange !== false?true:false;
-		this.select.set('value', dojo.indexOf(this.values,value) < 0 ? "" : value, priorityChange);
+		// if the value is not a permitted value, just set empty string to prevent showing the warning icon
+		priorityChange = priorityChange !== false;
+		this.select.set('value', array.indexOf(this.values,value) < 0 ? "" : value, priorityChange);
 		if(!priorityChange){
 			// Clear the last state in case of updateState calls.  Ref: #10466
 			this.select._lastValueReported=null;
@@ -101,7 +118,7 @@ dojo.declare("dijit._editor.plugins._FontDropDown",
 
 	_getValueAttr: function(){
 		// summary:
-		//		Allow retreiving the value from the composite select on
+		//		Allow retrieving the value from the composite select on
 		//		call to button.get("value");
 		return this.select.get('value');
 	},
@@ -126,7 +143,7 @@ dojo.declare("dijit._editor.plugins._FontDropDown",
 });
 
 
-dojo.declare("dijit._editor.plugins._FontNameDropDown", dijit._editor.plugins._FontDropDown, {
+var _FontNameDropDown = declare("dijit._editor.plugins._FontNameDropDown", _FontDropDown, {
 	// summary:
 	//		Dropdown to select a font; goes in editor toolbar.
 
@@ -170,7 +187,7 @@ dojo.declare("dijit._editor.plugins._FontNameDropDown", dijit._editor.plugins._F
 		//		Over-ride for the default action of setting the
 		//		widget value, maps the input to known values
 
-		priorityChange = priorityChange !== false?true:false;
+		priorityChange = priorityChange !== false;
 		if(this.generic){
 			var map = {
 				"Arial": "sans-serif",
@@ -182,8 +199,9 @@ dojo.declare("dijit._editor.plugins._FontNameDropDown", dijit._editor.plugins._F
 				"Apple Chancery": "cursive",
 				"Courier": "monospace",
 				"Courier New": "monospace",
-				"Papyrus": "fantasy"
-//					,"????": "fantasy" TODO: IE doesn't map fantasy font-family?
+				"Papyrus": "fantasy",
+				"Estrangelo Edessa": "cursive", // Windows 7
+				"Gabriola": "fantasy" // Windows 7
 			};
 			value = map[value] || value;
 		}
@@ -191,7 +209,7 @@ dojo.declare("dijit._editor.plugins._FontNameDropDown", dijit._editor.plugins._F
 	}
 });
 
-dojo.declare("dijit._editor.plugins._FontSizeDropDown", dijit._editor.plugins._FontDropDown, {
+var _FontSizeDropDown = declare("dijit._editor.plugins._FontSizeDropDown", _FontDropDown, {
 	// summary:
 	//		Dropdown to select a font size; goes in editor toolbar.
 
@@ -225,7 +243,7 @@ dojo.declare("dijit._editor.plugins._FontSizeDropDown", dijit._editor.plugins._F
 		// summary:
 		//		Over-ride for the default action of setting the
 		//		widget value, maps the input to known values
-		priorityChange = priorityChange !== false?true:false;
+		priorityChange = priorityChange !== false;
 		if(value.indexOf && value.indexOf("px") != -1){
 			var pixels = parseInt(value, 10);
 			value = {10:1, 13:2, 16:3, 18:4, 24:5, 32:6, 48:7}[pixels] || value;
@@ -236,7 +254,7 @@ dojo.declare("dijit._editor.plugins._FontSizeDropDown", dijit._editor.plugins._F
 });
 
 
-dojo.declare("dijit._editor.plugins._FormatBlockDropDown", dijit._editor.plugins._FontDropDown, {
+var _FormatBlockDropDown = declare("dijit._editor.plugins._FormatBlockDropDown", _FontDropDown, {
 	// summary:
 	//		Dropdown to select a format (like paragraph or heading); goes in editor toolbar.
 
@@ -264,7 +282,7 @@ dojo.declare("dijit._editor.plugins._FormatBlockDropDown", dijit._editor.plugins
 		//		The 'insert value' associated with a name
 		// name: String
 		//		The text name of the value
-		if(this.plainText){
+		if(this.plainText || value == "noFormat"){
 			return name;
 		}else{
 			return "<" + value + ">" + name + "</" + value + ">";
@@ -278,7 +296,7 @@ dojo.declare("dijit._editor.plugins._FormatBlockDropDown", dijit._editor.plugins
 		if(choice === "noFormat"){
 			var start;
 			var end;
-			var sel = dijit.range.getSelection(editor.window);
+			var sel = rangeapi.getSelection(editor.window);
 			if(sel && sel.rangeCount > 0){
 				var range = sel.getRangeAt(0);
 				var node, tag;
@@ -287,37 +305,37 @@ dojo.declare("dijit._editor.plugins._FormatBlockDropDown", dijit._editor.plugins
 					end = range.endContainer;
 
 					// find containing nodes of start/end.
-					while(start && start !== editor.editNode && 
-						  start !== editor.document.body && 
+					while(start && start !== editor.editNode &&
+						  start !== editor.document.body &&
 						  start.nodeType !== 1){
 						start = start.parentNode;
 					}
 
-					while(end && end !== editor.editNode && 
-						  end !== editor.document.body && 
+					while(end && end !== editor.editNode &&
+						  end !== editor.document.body &&
 						  end.nodeType !== 1){
 						end = end.parentNode;
 					}
 
-					var processChildren = dojo.hitch(this, function(node, array){
+					var processChildren = lang.hitch(this, function(node, ary){
 						if(node.childNodes && node.childNodes.length){
 							var i;
 							for(i = 0; i < node.childNodes.length; i++){
 								var c = node.childNodes[i];
 								if(c.nodeType == 1){
-									if(dojo.withGlobal(editor.window, "inSelection", dijit._editor.selection, [c])){
+									if(win.withGlobal(editor.window, "inSelection", selectionapi, [c])){
 										var tag = c.tagName? c.tagName.toLowerCase(): "";
-										if(dojo.indexOf(this.values, tag) !== -1){
-											array.push(c);
+										if(array.indexOf(this.values, tag) !== -1){
+											ary.push(c);
 										}
-										processChildren(c,array);
+										processChildren(c, ary);
 									}
 								}
 							}
 						}
 					});
 
-					var unformatNodes = dojo.hitch(this, function(nodes){
+					var unformatNodes = lang.hitch(this, function(nodes){
 						// summary:
 						//		Internal function to clear format nodes.
 						// nodes:
@@ -340,7 +358,7 @@ dojo.declare("dijit._editor.plugins._FormatBlockDropDown", dijit._editor.plugins
 						while(node && node !== editor.editNode && node !== editor.document.body){
 							if(node.nodeType == 1){
 								tag = node.tagName? node.tagName.toLowerCase(): "";
-								if(dojo.indexOf(this.values, tag) !== -1){
+								if(array.indexOf(this.values, tag) !== -1){
 									block = node;
 									break;
 								}
@@ -348,18 +366,18 @@ dojo.declare("dijit._editor.plugins._FormatBlockDropDown", dijit._editor.plugins
 							node = node.parentNode;
 						}
 
-						//Also look for all child nodes in the selection that may need to be 
+						//Also look for all child nodes in the selection that may need to be
 						//cleared of formatting
 						processChildren(start, clearNodes);
-						if(block) { clearNodes = [block].concat(clearNodes); }
+						if(block){ clearNodes = [block].concat(clearNodes); }
 						unformatNodes(clearNodes);
 					}else{
 						// Probably a multi select, so we have to process it.  Whee.
 						node = start;
-						while(dojo.withGlobal(editor.window, "inSelection", dijit._editor.selection, [node])){
+						while(win.withGlobal(editor.window, "inSelection", selectionapi, [node])){
 							if(node.nodeType == 1){
 								tag = node.tagName? node.tagName.toLowerCase(): "";
-								if(dojo.indexOf(this.values, tag) !== -1){
+								if(array.indexOf(this.values, tag) !== -1){
 									clearNodes.push(node);
 								}
 								processChildren(node,clearNodes);
@@ -384,21 +402,21 @@ dojo.declare("dijit._editor.plugins._FormatBlockDropDown", dijit._editor.plugins
 		if(editor.customUndo){
 			// So of course IE doesn't work right with paste-overs.
 			// We have to do this manually, which is okay since IE already uses
-			// customUndo and we turned it on for WebKit.  WebKit pasted funny, 
+			// customUndo and we turned it on for WebKit.  WebKit pasted funny,
 			// so couldn't use the execCommand approach
 			while(node.firstChild){
-				dojo.place(node.firstChild, node, "before");
+				domConstruct.place(node.firstChild, node, "before");
 			}
 			node.parentNode.removeChild(node);
 		}else{
 			// Everyone else works fine this way, a paste-over and is native
 			// undo friendly.
-			dojo.withGlobal(editor.window, 
-				 "selectElementChildren", dijit._editor.selection, [node]);
-			var html = 	dojo.withGlobal(editor.window, 
-				 "getSelectedHtml", dijit._editor.selection, [null]);
-			dojo.withGlobal(editor.window, 
-				 "selectElement", dijit._editor.selection, [node]);
+			win.withGlobal(editor.window,
+				 "selectElementChildren", selectionapi, [node]);
+			var html = 	win.withGlobal(editor.window,
+				 "getSelectedHtml", selectionapi, [null]);
+			win.withGlobal(editor.window,
+				 "selectElement", selectionapi, [node]);
 			editor.execCommand("inserthtml", html||"");
 		}
 	}
@@ -406,7 +424,7 @@ dojo.declare("dijit._editor.plugins._FormatBlockDropDown", dijit._editor.plugins
 
 // TODO: for 2.0, split into FontChoice plugin into three separate classes,
 // one for each command (and change registry below)
-dojo.declare("dijit._editor.plugins.FontChoice", dijit._editor._Plugin,{
+var FontChoice = declare("dijit._editor.plugins.FontChoice", _Plugin,{
 	// summary:
 	//		This plugin provides three drop downs for setting style in the editor
 	//		(font, font size, and format block), as controlled by command.
@@ -438,7 +456,7 @@ dojo.declare("dijit._editor.plugins.FontChoice", dijit._editor._Plugin,{
 	//		Note that the editor is often unable to properly handle font styling information defined outside
 	//		the context of the current editor instance, such as pre-populated HTML.
 
-	// useDefaultCommand: [protected] booleam
+	// useDefaultCommand: [protected] Boolean
 	//		Override _Plugin.useDefaultCommand...
 	//		processing is handled by this plugin, not by dijit.Editor.
 	useDefaultCommand: false,
@@ -452,9 +470,9 @@ dojo.declare("dijit._editor.plugins.FontChoice", dijit._editor._Plugin,{
 
 		// Create the widget to go into the toolbar (the so-called "button")
 		var clazz = {
-				fontName: dijit._editor.plugins._FontNameDropDown,
-				fontSize: dijit._editor.plugins._FontSizeDropDown,
-				formatBlock: dijit._editor.plugins._FormatBlockDropDown
+				fontName: _FontNameDropDown,
+				fontSize: _FontSizeDropDown,
+				formatBlock: _FormatBlockDropDown
 			}[this.command],
 		params = this.params;
 
@@ -465,14 +483,14 @@ dojo.declare("dijit._editor.plugins.FontChoice", dijit._editor._Plugin,{
 		}
 
 		var editor = this.editor;
-		this.button = new clazz(dojo.delegate({dir: editor.dir, lang: editor.lang}, params));
+		this.button = new clazz(lang.delegate({dir: editor.dir, lang: editor.lang}, params));
 
 		// Reflect changes to the drop down in the editor
 		this.connect(this.button.select, "onChange", function(choice){
 			// User invoked change, since all internal updates set priorityChange to false and will
 			// not trigger an onChange event.
 			this.editor.focus();
-			
+
 			if(this.command == "fontName" && choice.indexOf(" ") != -1){ choice = "'" + choice + "'"; }
 
 			// Invoke, the editor already normalizes commands called through its
@@ -482,10 +500,6 @@ dojo.declare("dijit._editor.plugins.FontChoice", dijit._editor._Plugin,{
 			}else{
 				this.editor.execCommand(this.command, choice);
 			}
-			
-			// Enable custom undo for webkit, needed for noFormat to work properly
-			// and still undo.
-			this.editor.customUndo = this.editor.customUndo || dojo.isWebKit;
 		});
 	},
 
@@ -501,7 +515,11 @@ dojo.declare("dijit._editor.plugins.FontChoice", dijit._editor._Plugin,{
 		var _e = this.editor;
 		var _c = this.command;
 		if(!_e || !_e.isLoaded || !_c.length){ return; }
+
 		if(this.button){
+			var disabled = this.get("disabled");
+			this.button.set("disabled", disabled);
+			if(disabled){ return; }
 			var value;
 			try{
 				value = _e.queryCommandValue(_c) || "";
@@ -511,7 +529,7 @@ dojo.declare("dijit._editor.plugins.FontChoice", dijit._editor._Plugin,{
 			}
 
 			// strip off single quotes, if any
-			var quoted = dojo.isString(value) && value.match(/'([^']*)'/);
+			var quoted = lang.isString(value) && value.match(/'([^']*)'/);
 			if(quoted){ value = quoted[1]; }
 
 			if(_c === "formatBlock"){
@@ -522,7 +540,7 @@ dojo.declare("dijit._editor.plugins.FontChoice", dijit._editor._Plugin,{
 					value = null;
 					var elem;
 					// Try to find the current element where the caret is.
-					var sel = dijit.range.getSelection(this.editor.window);
+					var sel = rangeapi.getSelection(this.editor.window);
 					if(sel && sel.rangeCount > 0){
 						var range = sel.getRangeAt(0);
 						if(range){
@@ -533,7 +551,7 @@ dojo.declare("dijit._editor.plugins.FontChoice", dijit._editor._Plugin,{
 					// Okay, now see if we can find one of the formatting types we're in.
 					while(elem && elem !== _e.editNode && elem !== _e.document){
 						var tg = elem.tagName?elem.tagName.toLowerCase():"";
-						if(tg && dojo.indexOf(this.button.values, tg) > -1){
+						if(tg && array.indexOf(this.button.values, tg) > -1){
 							value = tg;
 							break;
 						}
@@ -546,7 +564,7 @@ dojo.declare("dijit._editor.plugins.FontChoice", dijit._editor._Plugin,{
 				}else{
 					// Check that the block format is one allowed, if not,
 					// null it so that it gets set to empty.
-					if(dojo.indexOf(this.button.values, value) < 0){
+					if(array.indexOf(this.button.values, value) < 0){
 						value = "noFormat";
 					}
 				}
@@ -560,14 +578,14 @@ dojo.declare("dijit._editor.plugins.FontChoice", dijit._editor._Plugin,{
 	}
 });
 
-// Register this plugin.
-dojo.subscribe(dijit._scopeName + ".Editor.getPlugin",null,function(o){
-	if(o.plugin){ return; }
-	switch(o.args.name){
-	case "fontName": case "fontSize": case "formatBlock":
-		o.plugin = new dijit._editor.plugins.FontChoice({
-			command: o.args.name,
-			plainText: o.args.plainText?o.args.plainText:false
+// Register these plugins
+array.forEach(["fontName", "fontSize", "formatBlock"], function(name){
+	_Plugin.registry[name] = function(args){
+		return new FontChoice({
+			command: name,
+			plainText: args.plainText
 		});
-	}
+	};
+});
+
 });
