@@ -1,6 +1,38 @@
-define("dijit/_editor/plugins/ViewSource", ["dojo", "dijit", "dojo/window", "dojo/i18n", "dijit/_editor/_Plugin", "dijit/form/Button", "i18n!dijit/_editor/nls/commands"], function(dojo, dijit) {
+define([
+	"dojo/_base/array", // array.forEach
+	"dojo/_base/declare", // declare
+	"dojo/dom-attr", // domAttr.set
+	"dojo/dom-construct", // domConstruct.create domConstruct.place
+	"dojo/dom-geometry", // domGeometry.setMarginBox domGeometry.position
+	"dojo/dom-style", // domStyle.set
+	"dojo/_base/event", // event.stop
+	"dojo/i18n", // i18n.getLocalization
+	"dojo/keys",	//  keys.F12
+	"dojo/_base/lang", // lang.hitch
+	"dojo/on", // on()
+	"dojo/_base/sniff", // has("ie") has("webkit")
+	"dojo/_base/window", // win.body win.global
+	"dojo/window", // winUtils.getBox
+	"../../focus",	// focus.focus()
+	"../_Plugin",
+	"../../form/ToggleButton",
+	"../..",	// dijit._scopeName
+	"../../registry", // registry.getEnclosingWidget()
+	"dojo/i18n!../nls/commands"
+], function(array, declare, domAttr, domConstruct, domGeometry, domStyle, event, i18n, keys, lang, on, has, win,
+	winUtils, focus, _Plugin, ToggleButton, dijit, registry){
 
-dojo.declare("dijit._editor.plugins.ViewSource",dijit._editor._Plugin,{
+/*=====
+	var _Plugin = dijit._editor._Plugin;
+=====*/
+
+// module:
+//		dijit/_editor/plugins/ViewSource
+// summary:
+//		This plugin provides a simple view source capability.
+
+
+var ViewSource = declare("dijit._editor.plugins.ViewSource",_Plugin, {
 	// summary:
 	//		This plugin provides a simple view source capability.  When view
 	//		source mode is enabled, it disables all other buttons/plugins on the RTE.
@@ -41,7 +73,7 @@ dojo.declare("dijit._editor.plugins.ViewSource",dijit._editor._Plugin,{
 		// but can't focus this way all the time, only for VS changes.
 		// If we did it all the time, buttons like bold, italic, etc
 		// break.
-		if(dojo.isWebKit){this._vsFocused = true;}
+		if(has("webkit")){this._vsFocused = true;}
 		this.button.set("checked", !this.button.get("checked"));
 
 	},
@@ -49,29 +81,29 @@ dojo.declare("dijit._editor.plugins.ViewSource",dijit._editor._Plugin,{
 	_initButton: function(){
 		// summary:
 		//		Over-ride for creation of the resize button.
-		var strings = dojo.i18n.getLocalization("dijit._editor", "commands"),
+		var strings = i18n.getLocalization("dijit._editor", "commands"),
 			editor = this.editor;
-		this.button = new dijit.form.ToggleButton({
+		this.button = new ToggleButton({
 			label: strings["viewSource"],
 			dir: editor.dir,
 			lang: editor.lang,
 			showLabel: false,
 			iconClass: this.iconClassPrefix + " " + this.iconClassPrefix + "ViewSource",
 			tabIndex: "-1",
-			onChange: dojo.hitch(this, "_showSource")
+			onChange: lang.hitch(this, "_showSource")
 		});
 
 		// IE 7 has a horrible bug with zoom, so we have to create this node
 		// to cross-check later.  Sigh.
-		if(dojo.isIE == 7){
-			this._ieFixNode = dojo.create("div", {
+		if(has("ie") == 7){
+			this._ieFixNode = domConstruct.create("div", {
 				style: {
 					opacity: "0",
 					zIndex: "-1000",
 					position: "absolute",
 					top: "-1000px"
 				}
-			}, dojo.body());
+			}, win.body());
 		}
 		// Make sure readonly mode doesn't make the wrong cursor appear over the button.
 		this.button.set("readOnly", false);
@@ -86,16 +118,16 @@ dojo.declare("dijit._editor.plugins.ViewSource",dijit._editor._Plugin,{
 		this.editor = editor;
 		this._initButton();
 
-		this.editor.addKeyHandler(dojo.keys.F12, true, true, dojo.hitch(this, function(e){
+		this.editor.addKeyHandler(keys.F12, true, true, lang.hitch(this, function(e){
 			// Move the focus before switching
 			// It'll focus back.  Hiding a focused
 			// node causes issues.
 			this.button.focus();
 			this.toggle();
-			dojo.stopEvent(e);
+			event.stop(e);
 
 			// Call the focus shift outside of the handler.
-			setTimeout(dojo.hitch(this, function(){
+			setTimeout(lang.hitch(this, function(){
 				// We over-ride focus, so we just need to call.
 				this.editor.focus();
 			}), 100);
@@ -124,21 +156,15 @@ dojo.declare("dijit._editor.plugins.ViewSource",dijit._editor._Plugin,{
 				// plugins to check their state.
 				ed._sourceQueryCommandEnabled = ed.queryCommandEnabled;
 				ed.queryCommandEnabled = function(cmd){
-					var lcmd = cmd.toLowerCase();
-					if(lcmd === "viewsource"){
-						return true;
-					}else{
-						return false;
-					}
+					return cmd.toLowerCase() === "viewsource";
 				};
 				this.editor.onDisplayChanged();
 				html = ed.get("value");
 				html = this._filter(html);
 				ed.set("value", html);
-				this._pluginList = [];
-				dojo.forEach(edPlugins, function(p){
+				array.forEach(edPlugins, function(p){
 					// Turn off any plugins not controlled by queryCommandenabled.
-					if(!(p instanceof dijit._editor.plugins.ViewSource)){
+					if(!(p instanceof ViewSource)){
 						p.set("disabled", true)
 					}
 				});
@@ -152,15 +178,13 @@ dojo.declare("dijit._editor.plugins.ViewSource",dijit._editor._Plugin,{
 				}
 
 				this.sourceArea.value = html;
-				var is = dojo._getMarginSize(ed.iframe.parentNode);
 
-				dojo.marginBox(this.sourceArea, {
-					w: is.w,
-					h: is.h
-				});
-
-				dojo.style(ed.iframe, "display", "none");
-				dojo.style(this.sourceArea, {
+				// Since neither iframe nor textarea have margin, border, or padding,
+				// just set sizes equal
+				this.sourceArea.style.height = ed.iframe.style.height;
+				this.sourceArea.style.width = ed.iframe.style.width;
+				domStyle.set(ed.iframe, "display", "none");
+				domStyle.set(this.sourceArea, {
 					display: "block"
 				});
 
@@ -168,7 +192,7 @@ dojo.declare("dijit._editor.plugins.ViewSource",dijit._editor._Plugin,{
 					// function to handle resize events.
 					// Will check current VP and only resize if
 					// different.
-					var vp = dojo.window.getBox();
+					var vp = winUtils.getBox();
 
 					if("_prevW" in this && "_prevH" in this){
 						// No actual size change, ignore.
@@ -188,21 +212,21 @@ dojo.declare("dijit._editor.plugins.ViewSource",dijit._editor._Plugin,{
 					}
 					// Timeout it to help avoid spamming resize on IE.
 					// Works for all browsers.
-					this._resizer = setTimeout(dojo.hitch(this, function(){
+					this._resizer = setTimeout(lang.hitch(this, function(){
 						delete this._resizer;
 						this._resize();
 					}), 10);
 				};
-				this._resizeHandle = dojo.connect(window, "onresize", this, resizer);
+				this._resizeHandle = on(window, "resize", lang.hitch(this, resizer));
 
 				//Call this on a delay once to deal with IE glitchiness on initial size.
-				setTimeout(dojo.hitch(this, this._resize), 100);
+				setTimeout(lang.hitch(this, this._resize), 100);
 
 				//Trigger a check for command enablement/disablement.
 				this.editor.onNormalizedDisplayChanged();
 
 				this.editor.__oldGetValue = this.editor.getValue;
-				this.editor.getValue = dojo.hitch(this, function() {
+				this.editor.getValue = lang.hitch(this, function(){
 					var txt = this.sourceArea.value;
 					txt = this._filter(txt);
 					return txt;
@@ -214,7 +238,7 @@ dojo.declare("dijit._editor.plugins.ViewSource",dijit._editor._Plugin,{
 				if(!ed._sourceQueryCommandEnabled){
 					return;
 				}
-				dojo.disconnect(this._resizeHandle);
+				this._resizeHandle.remove();
 				delete this._resizeHandle;
 
 				if(this.editor.__oldGetValue){
@@ -232,24 +256,24 @@ dojo.declare("dijit._editor.plugins.ViewSource",dijit._editor._Plugin,{
 					ed.endEditing();
 				}
 
-				dojo.forEach(edPlugins, function(p){
+				array.forEach(edPlugins, function(p){
 					// Turn back on any plugins we turned off.
 					p.set("disabled", false);
 				});
 
-				dojo.style(this.sourceArea, "display", "none");
-				dojo.style(ed.iframe, "display", "block");
+				domStyle.set(this.sourceArea, "display", "none");
+				domStyle.set(ed.iframe, "display", "block");
 				delete ed._sourceQueryCommandEnabled;
-                
+
 				//Trigger a check for command enablement/disablement.
 				this.editor.onDisplayChanged();
 			}
 			// Call a delayed resize to wait for some things to display in header/footer.
-			setTimeout(dojo.hitch(this, function(){
+			setTimeout(lang.hitch(this, function(){
 				// Make resize calls.
 				var parent = ed.domNode.parentNode;
 				if(parent){
-					var container = dijit.getEnclosingWidget(parent);
+					var container = registry.getEnclosingWidget(parent);
 					if(container && container.resize){
 						container.resize();
 					}
@@ -275,30 +299,29 @@ dojo.declare("dijit._editor.plugins.ViewSource",dijit._editor._Plugin,{
 		var ed = this.editor;
 		var tbH = ed.getHeaderHeight();
 		var fH = ed.getFooterHeight();
-		var eb = dojo.position(ed.domNode);
+		var eb = domGeometry.position(ed.domNode);
 
 		// Styles are now applied to the internal source container, so we have
 		// to subtract them off.
-		var containerPadding = dojo._getPadBorderExtents(ed.iframe.parentNode);
-		var containerMargin = dojo._getMarginExtents(ed.iframe.parentNode);
+		var containerPadding = domGeometry.getPadBorderExtents(ed.iframe.parentNode);
+		var containerMargin = domGeometry.getMarginExtents(ed.iframe.parentNode);
 
-		var extents = dojo._getPadBorderExtents(ed.domNode);
-		var mExtents = dojo._getMarginExtents(ed.domNode);
+		var extents = domGeometry.getPadBorderExtents(ed.domNode);
 		var edb = {
-			w: eb.w - (extents.w + mExtents.w),
-			h: eb.h - (tbH + extents.h + mExtents.h + fH)
+			w: eb.w - extents.w,
+			h: eb.h - (tbH + extents.h + + fH)
 		};
 
 		// Fullscreen gets odd, so we need to check for the FS plugin and
 		// adapt.
 		if(this._fsPlugin && this._fsPlugin.isFullscreen){
 			//Okay, probably in FS, adjust.
-			var vp = dojo.window.getBox();
+			var vp = winUtils.getBox();
 			edb.w = (vp.w - extents.w);
 			edb.h = (vp.h - (tbH + extents.h + fH));
 		}
 
-		if(dojo.isIE){
+		if(has("ie")){
 			// IE is always off by 2px, so we have to adjust here
 			// Note that IE ZOOM is broken here.  I can't get
 			//it to scale right.
@@ -313,13 +336,13 @@ dojo.declare("dijit._editor.plugins.ViewSource",dijit._editor._Plugin,{
 			edb.h = Math.floor((edb.h + 0.9) / _ie7zoom);
 		}
 
-		dojo.marginBox(this.sourceArea, {
+		domGeometry.setMarginBox(this.sourceArea, {
 			w: edb.w - (containerPadding.w + containerMargin.w),
 			h: edb.h - (containerPadding.h + containerMargin.h)
 		});
 
 		// Scale the parent container too in this case.
-		dojo.marginBox(ed.iframe.parentNode, {
+		domGeometry.setMarginBox(ed.iframe.parentNode, {
 			h: edb.h
 		});
 	},
@@ -331,24 +354,24 @@ dojo.declare("dijit._editor.plugins.ViewSource",dijit._editor._Plugin,{
 		//		private
 		var ed = this.editor;
 		var edPlugins = ed._plugins;
-		this.sourceArea = dojo.create("textarea");
+		this.sourceArea = domConstruct.create("textarea");
 		if(this.readOnly){
-			dojo.attr(this.sourceArea, "readOnly", true);
+			domAttr.set(this.sourceArea, "readOnly", true);
 			this._readOnly = true;
 		}
-		dojo.style(this.sourceArea, {
+		domStyle.set(this.sourceArea, {
 			padding: "0px",
 			margin: "0px",
 			borderWidth: "0px",
 			borderStyle: "none"
 		});
-		dojo.place(this.sourceArea, ed.iframe, "before");
+		domConstruct.place(this.sourceArea, ed.iframe, "before");
 
-		if(dojo.isIE && ed.iframe.parentNode.lastChild !== ed.iframe){
+		if(has("ie") && ed.iframe.parentNode.lastChild !== ed.iframe){
 			// There's some weirdo div in IE used for focus control
 			// But is messed up scaling the textarea if we don't config
 			// it some so it doesn't have a varying height.
-			dojo.style(ed.iframe.parentNode.lastChild,{
+			domStyle.set(ed.iframe.parentNode.lastChild,{
 				width: "0px",
 				height: "0px",
 				padding: "0px",
@@ -372,7 +395,7 @@ dojo.declare("dijit._editor.plugins.ViewSource",dijit._editor._Plugin,{
 						// Must focus edit node in this case (webkit only) or
 						// focus doesn't shift right, but in normal
 						// cases we focus with the regular function.
-						dijit.focus(ed.editNode);
+						focus.focus(ed.editNode);
 					}else{
 						ed._viewsource_oldFocus();
 					}
@@ -405,12 +428,12 @@ dojo.declare("dijit._editor.plugins.ViewSource",dijit._editor._Plugin,{
 
 		// Listen to the source area for key events as well, as we need to be able to hotkey toggle
 		// it from there too.
-		this.connect(this.sourceArea, "onkeydown", dojo.hitch(this, function(e){
-			if(this._sourceShown && e.keyCode == dojo.keys.F12 && e.ctrlKey && e.shiftKey){
+		this.connect(this.sourceArea, "onkeydown", lang.hitch(this, function(e){
+			if(this._sourceShown && e.keyCode == keys.F12 && e.ctrlKey && e.shiftKey){
 				this.button.focus();
 				this.button.set("checked", false);
-				setTimeout(dojo.hitch(this, function(){ed.focus();}), 100);
-				dojo.stopEvent(e);
+				setTimeout(lang.hitch(this, function(){ed.focus();}), 100);
+				event.stop(e);
 			}
 		}));
 	},
@@ -483,11 +506,11 @@ dojo.declare("dijit._editor.plugins.ViewSource",dijit._editor._Plugin,{
 		// summary:
 		//		Internal function to set the caret in the sourceArea
 		//		to 0x0
-		var win = dojo.global;
+		var global = win.global;
 		var elem = this.sourceArea;
-		dijit.focus(elem);
+		focus.focus(elem);
 		if(this._sourceShown && !this.readOnly){
-			if(dojo.isIE){
+			if(has("ie")){
 				if(this.sourceArea.createTextRange){
 					var range = elem.createTextRange();
 					range.collapse(true);
@@ -496,7 +519,7 @@ dojo.declare("dijit._editor.plugins.ViewSource",dijit._editor._Plugin,{
 					range.moveEnd("character", 0);
 					range.select();
 				}
-			}else if(win.getSelection){
+			}else if(global.getSelection){
 				if(elem.setSelectionRange){
 					elem.setSelectionRange(0,0);
 				}
@@ -509,14 +532,14 @@ dojo.declare("dijit._editor.plugins.ViewSource",dijit._editor._Plugin,{
 		//		Over-ride to remove the node used to correct for IE's
 		//		zoom bug.
 		if(this._ieFixNode){
-			dojo.body().removeChild(this._ieFixNode);
+			win.body().removeChild(this._ieFixNode);
 		}
 		if(this._resizer){
 			clearTimeout(this._resizer);
 			delete this._resizer;
 		}
 		if(this._resizeHandle){
-			dojo.disconnect(this._resizeHandle);
+			this._resizeHandle.remove();
 			delete this._resizeHandle;
 		}
 		this.inherited(arguments);
@@ -524,19 +547,18 @@ dojo.declare("dijit._editor.plugins.ViewSource",dijit._editor._Plugin,{
 });
 
 // Register this plugin.
-dojo.subscribe(dijit._scopeName + ".Editor.getPlugin",null,function(o){
-	if(o.plugin){ return; }
-	var name = o.args.name.toLowerCase();
-	if(name ===  "viewsource"){
-		o.plugin = new dijit._editor.plugins.ViewSource({
-			readOnly: ("readOnly" in o.args)?o.args.readOnly:false,
-			stripComments: ("stripComments" in o.args)?o.args.stripComments:true,
-			stripScripts: ("stripScripts" in o.args)?o.args.stripScripts:true,
-			stripIFrames: ("stripIFrames" in o.args)?o.args.stripIFrames:true
-		});
-	}
-});
+// For back-compat accept "viewsource" (all lowercase) too, remove in 2.0
+_Plugin.registry["viewSource"] = _Plugin.registry["viewsource"] = function(args){
+	return new ViewSource({
+		readOnly: ("readOnly" in args)?args.readOnly:false,
+		stripComments: ("stripComments" in args)?args.stripComments:true,
+		stripScripts: ("stripScripts" in args)?args.stripScripts:true,
+		stripIFrames: ("stripIFrames" in args)?args.stripIFrames:true
+	});
+};
 
 
-return dijit._editor.plugins.ViewSource;
+
+
+return ViewSource;
 });
