@@ -1,6 +1,6 @@
 define({ root:
 //begin v1.x content
-/* used by both the editor and textarea widgets to provide information to screen reader users */
+// used by both the editor and textarea widgets to provide information to screen reader users
 ({
 	iframeEditTitle: 'edit area',  // primary title for editable IFRAME, for screen readers when focus is in the editing area
 	iframeFocusTitle: 'edit area frame'  // secondary title for editable IFRAME when focus is on outer container
@@ -28,6 +28,7 @@ define({ root:
 "ja": true,
 "it": true,
 "hu": true,
+"hr": true,
 "he": true,
 "fr": true,
 "fi": true,
@@ -37,5 +38,6 @@ define({ root:
 "da": true,
 "cs": true,
 "ca": true,
+"az": true,
 "ar": true
 });
