@@ -25,6 +25,7 @@ define({ root:
 "ja": true,
 "it": true,
 "hu": true,
+"hr": true,
 "he": true,
 "fr": true,
 "fi": true,
@@ -34,5 +35,6 @@ define({ root:
 "da": true,
 "cs": true,
 "ca": true,
+"az": true,
 "ar": true
 });
