@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	buttonOk: "OK",
 	buttonCancel: "Zrušiť",
@@ -5,3 +7,5 @@
 	itemClose: "Zatvoriť"
 })
 
+//end v1.x content
+);
