@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	buttonOk: "V redu",
 	buttonCancel: "Prekliči",
@@ -5,3 +7,5 @@
 	itemClose: "Zapri"
 })
 
+//end v1.x content
+);
