@@ -1,6 +1,10 @@
+define(
+//begin v1.x content
 ({
 	buttonOk: "OK",
 	buttonCancel: "Avbryt",
 	buttonSave: "Spara",
 	itemClose: "Stäng"
 })
+//end v1.x content
+);
