@@ -1,15 +1,23 @@
-dojo.provide("dojo.NodeList-manipulate");
+define(["./query", "./_base/lang", "./_base/array", "./dom-construct", "./NodeList-dom"], function(dquery, lang, array, construct) {
+	// module:
+	//		dojo/NodeList-manipulate
+	// summary:
+	//		TODOC
+
+var NodeList = dquery.NodeList;
 
 /*=====
 dojo["NodeList-manipulate"] = {
 	// summary: Adds a chainable methods to dojo.query() / Nodelist instances for manipulating HTML
 	// and DOM nodes and their properties.
 };
+
+// doc alias helpers:
+NodeList = dojo.NodeList;
 =====*/
 
 //TODO: add a way to parse for widgets in the injected markup?
 
-(function(){
 	function getText(/*DOMNode*/node){
 		// summary:
 		// 		recursion method for text() to use. Gets text value for a node.
@@ -42,10 +50,10 @@ dojo["NodeList-manipulate"] = {
 	}
 
 	function makeWrapNode(/*DOMNode||String*/html, /*DOMNode*/refNode){
-		// summary: 
+		// summary:
 		// 		convert HTML into nodes if it is not already a node.
 		if(typeof html == "string"){
-			html = dojo._toDom(html, (refNode && refNode.ownerDocument));
+			html = construct.toDom(html, (refNode && refNode.ownerDocument));
 			if(html.nodeType == 11){
 				//DocumentFragment cannot handle cloneNode, so choose first child.
 				html = html.childNodes[0];
@@ -57,13 +65,13 @@ dojo["NodeList-manipulate"] = {
 		return html; /*DOMNode*/
 	}
 
-	dojo.extend(dojo.NodeList, {
+	lang.extend(NodeList, {
 		_placeMultiple: function(/*String||Node||NodeList*/query, /*String*/position){
 			// summary:
 			// 		private method for inserting queried nodes into all nodes in this NodeList
 			// 		at different positions. Differs from NodeList.place because it will clone
 			// 		the nodes in this NodeList if the query matches more than one element.
-			var nl2 = typeof query == "string" || query.nodeType ? dojo.query(query) : query;
+			var nl2 = typeof query == "string" || query.nodeType ? dquery(query) : query;
 			var toAdd = [];
 			for(var i = 0; i < nl2.length; i++){
 				//Go backwards in DOM to make dom insertions easier via insertBefore
@@ -78,7 +86,7 @@ dojo["NodeList-manipulate"] = {
 						toAdd.unshift(item);
 					}
 					if(j == length - 1){
-						dojo.place(item, refNode, position);
+						construct.place(item, refNode, position);
 					}else{
 						refNode.parentNode.insertBefore(item, refNode);
 					}
@@ -180,7 +188,7 @@ dojo["NodeList-manipulate"] = {
 			if(arguments.length){
 				for(var i = 0, node; node = this[i]; i++){
 					if(node.nodeType == 1){
-						dojo.empty(node);
+						construct.empty(node);
 						node.appendChild(node.ownerDocument.createTextNode(value));
 					}
 				}
@@ -220,18 +228,18 @@ dojo["NodeList-manipulate"] = {
 
 			//Special work for input elements.
 			if(arguments.length){
-				var isArray = dojo.isArray(value);
+				var isArray = lang.isArray(value);
 				for(var index = 0, node; node = this[index]; index++){
 					var name = node.nodeName.toUpperCase();
 					var type = node.type;
 					var newValue = isArray ? value[index] : value;
-	
+
 					if(name == "SELECT"){
 						var opts = node.options;
 						for(var i = 0; i < opts.length; i++){
 							var opt = opts[i];
 							if(node.multiple){
-								opt.selected = (dojo.indexOf(value, opt.value) != -1);
+								opt.selected = (array.indexOf(value, opt.value) != -1);
 							}else{
 								opt.selected = (opt.value == newValue);
 							}
@@ -470,7 +478,7 @@ dojo["NodeList-manipulate"] = {
 			return; // dojo.NodeList
 		},
 		=====*/
-		remove: dojo.NodeList.prototype.orphan,
+		remove: NodeList.prototype.orphan,
 
 		wrap: function(/*String||DOMNode*/html){
 			// summary:
@@ -587,10 +595,10 @@ dojo["NodeList-manipulate"] = {
 					//the "this" nodes, then on the clone of html it will contain
 					//that "this" node, and that would be bad.
 					var clone = this._cloneNode(html);
-					
+
 					//Need to convert the childNodes to an array since wrapAll modifies the
 					//DOM and can change the live childNodes NodeList.
-					this._wrap(dojo._toArray(this[i].childNodes), null, this._NodeListCtor).wrapAll(clone);
+					this._wrap(lang._toArray(this[i].childNodes), null, this._NodeListCtor).wrapAll(clone);
 				}
 			}
 			return this; //dojo.NodeList
@@ -646,29 +654,29 @@ dojo["NodeList-manipulate"] = {
 			//	example:
 			//		assume a DOM created by this markup:
 			//	|	<div class="container">
-			// 	|		<div class="spacer">___</div>			
+			// 	|		<div class="spacer">___</div>
 			// 	|		<div class="red">Red One</div>
-			// 	|		<div class="spacer">___</div>			
+			// 	|		<div class="spacer">___</div>
 			// 	|		<div class="blue">Blue One</div>
-			// 	|		<div class="spacer">___</div>			
+			// 	|		<div class="spacer">___</div>
 			// 	|		<div class="red">Red Two</div>
-			// 	|		<div class="spacer">___</div>			
+			// 	|		<div class="spacer">___</div>
 			// 	|		<div class="blue">Blue Two</div>
 			//	|	</div>
 			//		Running this code:
 			//	|	dojo.query(".red").replaceAll(".blue");
 			//		Results in this DOM structure:
 			//	|	<div class="container">
-			// 	|		<div class="spacer">___</div>			
-			// 	|		<div class="spacer">___</div>			
+			// 	|		<div class="spacer">___</div>
+			// 	|		<div class="spacer">___</div>
 			// 	|		<div class="red">Red One</div>
 			// 	|		<div class="red">Red Two</div>
-			// 	|		<div class="spacer">___</div>			
-			// 	|		<div class="spacer">___</div>			
+			// 	|		<div class="spacer">___</div>
+			// 	|		<div class="spacer">___</div>
 			// 	|		<div class="red">Red One</div>
 			// 	|		<div class="red">Red Two</div>
 			//	|	</div>
-			var nl = dojo.query(query);
+			var nl = dquery(query);
 			var content = this._normalize(this, this[0]);
 			for(var i = 0, node; node = nl[i]; i++){
 				this._place(content, node, "before", i > 0);
@@ -714,7 +722,9 @@ dojo["NodeList-manipulate"] = {
 	});
 
 	//set up html method if one does not exist
-	if(!dojo.NodeList.prototype.html){
-		dojo.NodeList.prototype.html = dojo.NodeList.prototype.innerHTML;
+	if(!NodeList.prototype.html){
+		NodeList.prototype.html = NodeList.prototype.innerHTML;
 	}
-})();
+
+return NodeList;
+});
