@@ -1,18 +1,14 @@
-dojo.provide("tests.cache");
-
-dojo.require("dojo.cache");
-
-tests.register("tests.cache",
-	[
-		{
+define(["../main", "doh", "require", "../cache", "../_base/url"], function(dojo, doh, require) {
+	doh.register("tests.cache", [{
+			name: "dojo.cache",
 			runTest: function(t){
 				var expected = "<h1>Hello World</h1>";
 
 				t.is(expected, dojo.trim(dojo.cache("dojo.tests.cache", "regular.html")));
 				t.is(expected, dojo.trim(dojo.cache("dojo.tests.cache", "sanitized.html", {sanitize: true})));
-				
+
 				//Test object variant for module.
-				var objPath = dojo.moduleUrl("dojo.tests.cache", "object.html").toString();
+				var objPath = require.toUrl("dojo/tests/cache/object.html");
 				t.is(expected, dojo.trim(dojo.cache(new dojo._Url(objPath), {sanitize: true})));
 
 				//Just a couple of other passes just to make sure on manual inspection that the
@@ -29,5 +25,5 @@ tests.register("tests.cache",
 				t.is("", dojo.cache("dojo.tests.cache", "regular.html"));
 			}
 		}
-	]
-);
+	]);
+});
