@@ -1,9 +1,5 @@
-dojo.provide("tests.date");
-
-dojo.require("dojo.date");
-
-tests.register("tests.date.util",
-	[
+define(["../main", "doh", "../date", "./date/locale", "./date/stamp"], function(dojo, doh){
+doh.register("tests.date.util", [
 
 /* Informational Functions
  **************************/
@@ -50,7 +46,7 @@ function test_date_isLeapYear(t){
 // produced by various browser/OS combinations.
 // FIXME: the function and tests are not localized.
 function test_date_getTimezoneName(t){
-	
+
 	// Create a fake Date object with toString and toLocaleString
 	// results manually set to simulate tests for multiple browsers
 	function FakeDate(str, strLocale){
@@ -64,7 +60,7 @@ function test_date_getTimezoneName(t){
 		};
 	}
 	var dt = new FakeDate();
-	
+
 	// FF 1.5 Ubuntu Linux (Breezy)
 	dt.str = 'Sun Sep 17 2006 22:25:51 GMT-0500 (CDT)';
 	dt.strLocale = 'Sun 17 Sep 2006 10:25:51 PM CDT';
@@ -84,7 +80,7 @@ function test_date_getTimezoneName(t){
 	dt.str = 'Sun, 17 Sep 2006 22:58:06 GMT-0500';
 	dt.strLocale = 'Sunday September 17, 22:58:06 GMT-0500 2006';
 	t.is('', dojo.date.getTimezoneName(dt));
-	
+
 	// IE 6 Windows XP
 	dt.str = 'Mon Sep 18 11:21:07 CDT 2006';
 	dt.strLocale = 'Monday, September 18, 2006 11:21:07 AM';
@@ -94,7 +90,7 @@ function test_date_getTimezoneName(t){
 	dt.str = 'Mon, 18 Sep 2006 13:30:32 GMT-0500';
 	dt.strLocale = 'Monday September 18, 13:30:32 GMT-0500 2006';
 	t.is('', dojo.date.getTimezoneName(dt));
-	
+
 	// IE 5.5 Windows 2000
 	dt.str = 'Mon Sep 18 13:49:22 CDT 2006';
 	dt.strLocale = 'Monday, September 18, 2006 1:49:22 PM';
@@ -103,7 +99,7 @@ function test_date_getTimezoneName(t){
 	]
 );
 
-tests.register("tests.date.math",
+doh.register("tests.date.math",
 	[
 function test_date_compare(t){
 	var d1=new Date();
@@ -121,28 +117,28 @@ function test_date_add(t){
 	var interv = ''; // Interval (e.g., year, month)
 	var dtA = null; // Date to increment
 	var dtB = null; // Expected result date
-	
+
 	interv = "year";
 	dtA = new Date(2005, 11, 27);
 	dtB = new Date(2006, 11, 27);
 	t.is(dtB, dojo.date.add(dtA, interv, 1));
-	
+
 	dtA = new Date(2005, 11, 27);
 	dtB = new Date(2004, 11, 27);
 	t.is(dtB, dojo.date.add(dtA, interv, -1));
-	
+
 	dtA = new Date(2000, 1, 29);
 	dtB = new Date(2001, 1, 28);
 	t.is(dtB, dojo.date.add(dtA, interv, 1));
-	
+
 	dtA = new Date(2000, 1, 29);
 	dtB = new Date(2005, 1, 28);
 	t.is(dtB, dojo.date.add(dtA, interv, 5));
-	
+
 	dtA = new Date(1900, 11, 31);
 	dtB = new Date(1930, 11, 31);
 	t.is(dtB, dojo.date.add(dtA, interv, 30));
-	
+
 	dtA = new Date(1995, 11, 31);
 	dtB = new Date(2030, 11, 31);
 	t.is(dtB, dojo.date.add(dtA, interv, 35));
@@ -151,28 +147,28 @@ function test_date_add(t){
 	dtA = new Date(2000, 0, 1);
 	dtB = new Date(2000, 3, 1);
 	t.is(dtB, dojo.date.add(dtA, interv, 1));
-	
+
 	dtA = new Date(2000, 1, 29);
 	dtB = new Date(2000, 7, 29);
 	t.is(dtB, dojo.date.add(dtA, interv, 2));
-	
+
 	dtA = new Date(2000, 1, 29);
 	dtB = new Date(2001, 1, 28);
 	t.is(dtB, dojo.date.add(dtA, interv, 4));
-	
+
 	interv = "month";
 	dtA = new Date(2000, 0, 1);
 	dtB = new Date(2000, 1, 1);
 	t.is(dtB, dojo.date.add(dtA, interv, 1));
-	
+
 	dtA = new Date(2000, 0, 31);
 	dtB = new Date(2000, 1, 29);
 	t.is(dtB, dojo.date.add(dtA, interv, 1));
-	
+
 	dtA = new Date(2000, 1, 29);
 	dtB = new Date(2001, 1, 28);
 	t.is(dtB, dojo.date.add(dtA, interv, 12));
-	
+
 	interv = "week";
 	dtA = new Date(2000, 0, 1);
 	dtB = new Date(2000, 0, 8);
@@ -182,84 +178,84 @@ function test_date_add(t){
 	dtA = new Date(2000, 0, 1);
 	dtB = new Date(2000, 0, 2);
 	t.is(dtB, dojo.date.add(dtA, interv, 1));
-	
+
 	dtA = new Date(2001, 0, 1);
 	dtB = new Date(2002, 0, 1);
 	t.is(dtB, dojo.date.add(dtA, interv, 365));
-	
+
 	dtA = new Date(2000, 0, 1);
 	dtB = new Date(2001, 0, 1);
 	t.is(dtB, dojo.date.add(dtA, interv, 366));
-	
+
 	dtA = new Date(2000, 1, 28);
 	dtB = new Date(2000, 1, 29);
 	t.is(dtB, dojo.date.add(dtA, interv, 1));
-	
+
 	dtA = new Date(2001, 1, 28);
 	dtB = new Date(2001, 2, 1);
 	t.is(dtB, dojo.date.add(dtA, interv, 1));
-	
+
 	dtA = new Date(2000, 2, 1);
 	dtB = new Date(2000, 1, 29);
 	t.is(dtB, dojo.date.add(dtA, interv, -1));
-	
+
 	dtA = new Date(2001, 2, 1);
 	dtB = new Date(2001, 1, 28);
 	t.is(dtB, dojo.date.add(dtA, interv, -1));
-	
+
 	dtA = new Date(2000, 0, 1);
 	dtB = new Date(1999, 11, 31);
 	t.is(dtB, dojo.date.add(dtA, interv, -1));
-	
+
 	interv = "weekday";
 	// Sat, Jan 1
 	dtA = new Date(2000, 0, 1);
 	// Should be Mon, Jan 3
 	dtB = new Date(2000, 0, 3);
 	t.is(dtB, dojo.date.add(dtA, interv, 1));
-	
+
 	// Sun, Jan 2
 	dtA = new Date(2000, 0, 2);
 	// Should be Mon, Jan 3
 	dtB = new Date(2000, 0, 3);
 	t.is(dtB, dojo.date.add(dtA, interv, 1));
-	
+
 	// Sun, Jan 2
 	dtA = new Date(2000, 0, 2);
 	// Should be Fri, Jan 7
 	dtB = new Date(2000, 0, 7);
 	t.is(dtB, dojo.date.add(dtA, interv, 5));
-	
+
 	// Sun, Jan 2
 	dtA = new Date(2000, 0, 2);
 	// Should be Mon, Jan 10
 	dtB = new Date(2000, 0, 10);
 	t.is(dtB, dojo.date.add(dtA, interv, 6));
-	
+
 	// Mon, Jan 3
 	dtA = new Date(2000, 0, 3);
 	// Should be Mon, Jan 17
 	dtB = new Date(2000, 0, 17);
 	t.is(dtB, dojo.date.add(dtA, interv, 10));
-	
+
 	// Sat, Jan 8
 	dtA = new Date(2000, 0, 8);
 	// Should be Mon, Jan 3
 	dtB = new Date(2000, 0, 3);
 	t.is(dtB, dojo.date.add(dtA, interv, -5));
-	
+
 	// Sun, Jan 9
 	dtA = new Date(2000, 0, 9);
 	// Should be Wed, Jan 5
 	dtB = new Date(2000, 0, 5);
 	t.is(dtB, dojo.date.add(dtA, interv, -3));
-	
+
 	// Sun, Jan 23
 	dtA = new Date(2000, 0, 23);
 	// Should be Fri, Jan 7
 	dtB = new Date(2000, 0, 7);
 	t.is(dtB, dojo.date.add(dtA, interv, -11));
-	
+
 	interv = "hour";
 	dtA = new Date(2000, 0, 1, 11);
 	dtB = new Date(2000, 0, 1, 12);
@@ -285,7 +281,7 @@ function test_date_add(t){
 	dtA = new Date(2000, 11, 27, 12, 2);
 	dtB = new Date(2000, 11, 27, 13, 2);
 	t.is(dtB, dojo.date.add(dtA, interv, 60));
-	
+
 	interv = "second";
 	dtA = new Date(2000, 11, 31, 23, 59, 59);
 	dtB = new Date(2001, 0, 1, 0, 0, 0);
@@ -294,7 +290,7 @@ function test_date_add(t){
 	dtA = new Date(2000, 11, 27, 8, 10, 59);
 	dtB = new Date(2000, 11, 27, 8, 11, 59);
 	t.is(dtB, dojo.date.add(dtA, interv, 60));
-	
+
 	// Test environment JS Date doesn't support millisec?
 	//interv = "millisecond";
 	//
@@ -310,138 +306,138 @@ function test_date_diff(t){
 	var dtA = null; // First date to compare
 	var dtB = null; // Second date to compare
 	var interv = ''; // Interval to compare on (e.g., year, month)
-	
+
 	interv = "year";
 	dtA = new Date(2005, 11, 27);
 	dtB = new Date(2006, 11, 27);
 	t.is(1, dojo.date.difference(dtA, dtB, interv));
-	
+
 	dtA = new Date(2000, 11, 31);
 	dtB = new Date(2001, 0, 1);
 	t.is(1, dojo.date.difference(dtA, dtB, interv));
-	
+
 	interv = "quarter";
 	dtA = new Date(2000, 1, 29);
 	dtB = new Date(2001, 2, 1);
 	t.is(4, dojo.date.difference(dtA, dtB, interv));
-	
+
 	dtA = new Date(2000, 11, 1);
 	dtB = new Date(2001, 0, 1);
 	t.is(1, dojo.date.difference(dtA, dtB, interv));
-	
+
 	interv = "month";
 	dtA = new Date(2000, 1, 29);
 	dtB = new Date(2001, 2, 1);
 	t.is(13, dojo.date.difference(dtA, dtB, interv));
-	
+
 	dtA = new Date(2000, 11, 1);
 	dtB = new Date(2001, 0, 1);
 	t.is(1, dojo.date.difference(dtA, dtB, interv));
-	
+
 	interv = "week";
 	dtA = new Date(2000, 1, 1);
 	dtB = new Date(2000, 1, 8);
 	t.is(1, dojo.date.difference(dtA, dtB, interv));
-	
+
 	dtA = new Date(2000, 1, 28);
 	dtB = new Date(2000, 2, 6);
 	t.is(1, dojo.date.difference(dtA, dtB, interv));
-	
+
 	dtA = new Date(2000, 2, 6);
 	dtB = new Date(2000, 1, 28);
 	t.is(-1, dojo.date.difference(dtA, dtB, interv));
-	
+
 	interv = "day";
 	dtA = new Date(2000, 1, 29);
 	dtB = new Date(2000, 2, 1);
 	t.is(1, dojo.date.difference(dtA, dtB, interv));
-	
+
 	dtA = new Date(2000, 11, 31);
 	dtB = new Date(2001, 0, 1);
 	t.is(1, dojo.date.difference(dtA, dtB, interv));
-	
+
 	// DST leap -- check for rounding err
 	// This is dependent on US calendar, but
 	// shouldn't break in other locales
 	dtA = new Date(2005, 3, 3);
 	dtB = new Date(2005, 3, 4);
 	t.is(1, dojo.date.difference(dtA, dtB, interv));
-	
+
 	interv = "weekday";
 	dtA = new Date(2006, 7, 3);
 	dtB = new Date(2006, 7, 11);
 	t.is(6, dojo.date.difference(dtA, dtB, interv));
-	
+
 	// Positive diffs
 	dtA = new Date(2006, 7, 4);
 	dtB = new Date(2006, 7, 11);
 	t.is(5, dojo.date.difference(dtA, dtB, interv));
-	
+
 	dtA = new Date(2006, 7, 5);
 	dtB = new Date(2006, 7, 11);
 	t.is(5, dojo.date.difference(dtA, dtB, interv));
-	
+
 	dtA = new Date(2006, 7, 6);
 	dtB = new Date(2006, 7, 11);
 	t.is(5, dojo.date.difference(dtA, dtB, interv));
-	
+
 	dtA = new Date(2006, 7, 7);
 	dtB = new Date(2006, 7, 11);
 	t.is(4, dojo.date.difference(dtA, dtB, interv));
-	
+
 	dtA = new Date(2006, 7, 7);
 	dtB = new Date(2006, 7, 13);
 	t.is(4, dojo.date.difference(dtA, dtB, interv));
-	
+
 	dtA = new Date(2006, 7, 7);
 	dtB = new Date(2006, 7, 14);
 	t.is(5, dojo.date.difference(dtA, dtB, interv));
-	
+
 	dtA = new Date(2006, 7, 7);
 	dtB = new Date(2006, 7, 15);
 	t.is(6, dojo.date.difference(dtA, dtB, interv));
-	
+
 	dtA = new Date(2006, 7, 7);
 	dtB = new Date(2006, 7, 28);
 	t.is(15, dojo.date.difference(dtA, dtB, interv));
-	
+
 	dtA = new Date(2006, 2, 2);
 	dtB = new Date(2006, 2, 28);
 	t.is(18, dojo.date.difference(dtA, dtB, interv));
-	
+
 	// Negative diffs
 	dtA = new Date(2006, 7, 11);
 	dtB = new Date(2006, 7, 4);
 	t.is(-5, dojo.date.difference(dtA, dtB, interv));
-	
+
 	dtA = new Date(2006, 7, 11);
 	dtB = new Date(2006, 7, 5);
 	t.is(-4, dojo.date.difference(dtA, dtB, interv));
-	
+
 	dtA = new Date(2006, 7, 11);
 	dtB = new Date(2006, 7, 6);
 	t.is(-4, dojo.date.difference(dtA, dtB, interv));
-	
+
 	dtA = new Date(2006, 7, 11);
 	dtB = new Date(2006, 7, 7);
 	t.is(-4, dojo.date.difference(dtA, dtB, interv));
-	
+
 	dtA = new Date(2006, 7, 13);
 	dtB = new Date(2006, 7, 7);
 	t.is(-5, dojo.date.difference(dtA, dtB, interv));
-	
+
 	dtA = new Date(2006, 7, 14);
 	dtB = new Date(2006, 7, 7);
 	t.is(-5, dojo.date.difference(dtA, dtB, interv));
-	
+
 	dtA = new Date(2006, 7, 15);
 	dtB = new Date(2006, 7, 7);
 	t.is(-6, dojo.date.difference(dtA, dtB, interv));
-	
+
 	dtA = new Date(2006, 7, 28);
 	dtB = new Date(2006, 7, 7);
 	t.is(-15, dojo.date.difference(dtA, dtB, interv));
-	
+
 	dtA = new Date(2006, 2, 28);
 	dtB = new Date(2006, 2, 2);
 	t.is(-18, dojo.date.difference(dtA, dtB, interv));
@@ -450,35 +446,35 @@ function test_date_diff(t){
 	dtA = new Date(2006, 7, 5);
 	dtB = new Date(2006, 7, 6);
 	t.is(0, dojo.date.difference(dtA, dtB, interv));
-	
+
 	interv = "hour";
 	dtA = new Date(2000, 11, 31, 23);
 	dtB = new Date(2001, 0, 1, 0);
 	t.is(1, dojo.date.difference(dtA, dtB, interv));
-	
+
 	dtA = new Date(2000, 11, 31, 12);
 	dtB = new Date(2001, 0, 1, 0);
 	t.is(12, dojo.date.difference(dtA, dtB, interv));
-	
+
 	interv = "minute";
 	dtA = new Date(2000, 11, 31, 23, 59);
 	dtB = new Date(2001, 0, 1, 0, 0);
 	t.is(1, dojo.date.difference(dtA, dtB, interv));
-	
+
 	dtA = new Date(2000, 1, 28, 23, 59);
 	dtB = new Date(2000, 1, 29, 0, 0);
 	t.is(1, dojo.date.difference(dtA, dtB, interv));
-	
+
 	interv = "second";
 	dtA = new Date(2000, 11, 31, 23, 59, 59);
 	dtB = new Date(2001, 0, 1, 0, 0, 0);
 	t.is(1, dojo.date.difference(dtA, dtB, interv));
-	
+
 	interv = "millisecond";
 	dtA = new Date(2000, 11, 31, 23, 59, 59, 999);
 	dtB = new Date(2001, 0, 1, 0, 0, 0, 0);
 	t.is(1, dojo.date.difference(dtA, dtB, interv));
-	
+
 	dtA = new Date(2000, 11, 31, 23, 59, 59, 0);
 	dtB = new Date(2001, 0, 1, 0, 0, 0, 0);
 	t.is(1000, dojo.date.difference(dtA, dtB, interv));
@@ -487,28 +483,28 @@ function test_date_add_diff_year(t){
 	var interv = ''; // Interval (e.g., year, month)
 	var dtA = null; // Date to increment
 	var dtB = null; // Expected result date
-	
+
 	interv = "year";
 	dtA = new Date(2005, 11, 27);
 	dtB = dojo.date.add(dtA, interv, 1);
 	t.is(dojo.date.difference(dtA, dtB, interv), 1);
-	
+
 	dtA = new Date(2005, 11, 27);
 	dtB = dojo.date.add(dtA, interv, -1);
 	t.is(dojo.date.difference(dtA, dtB, interv), -1);
-	
+
 	dtA = new Date(2000, 1, 29);
 	dtB = dojo.date.add(dtA, interv, 1);
 	t.is(dojo.date.difference(dtA, dtB, interv), 1);
-	
+
 	dtA = new Date(2000, 1, 29);
 	dtB = dojo.date.add(dtA, interv, 5);
 	t.is(dojo.date.difference(dtA, dtB, interv), 5);
-	
+
 	dtA = new Date(1900, 11, 31);
 	dtB = dojo.date.add(dtA, interv, 30);
 	t.is(dojo.date.difference(dtA, dtB, interv), 30);
-	
+
 	dtA = new Date(1995, 11, 31);
 	dtB = dojo.date.add(dtA, interv, 35);
 	t.is(dojo.date.difference(dtA, dtB, interv), 35);
@@ -521,11 +517,11 @@ function test_date_add_diff_quarter(t){
 	dtA = new Date(2000, 0, 1);
 	dtB = dojo.date.add(dtA, interv, 1);
 	t.is(dojo.date.difference(dtA, dtB, interv), 1);
-	
+
 	dtA = new Date(2000, 1, 29);
 	dtB = dojo.date.add(dtA, interv, 2);
 	t.is(dojo.date.difference(dtA, dtB, interv), 2);
-	
+
 	dtA = new Date(2000, 1, 29);
 	dtB = dojo.date.add(dtA, interv, 4);
 	t.is(dojo.date.difference(dtA, dtB, interv), 4);
@@ -538,11 +534,11 @@ function test_date_add_diff_month(t){
 	dtA = new Date(2000, 0, 1);
 	dtB = dojo.date.add(dtA, interv, 1);
 	t.is(dojo.date.difference(dtA, dtB, interv), 1);
-	
+
 	dtA = new Date(2000, 0, 31);
 	dtB = dojo.date.add(dtA, interv, 1);
 	t.is(dojo.date.difference(dtA, dtB, interv), 1);
-	
+
 	dtA = new Date(2000, 1, 29);
 	dtB = dojo.date.add(dtA, interv, 12);
 	t.is(dojo.date.difference(dtA, dtB, interv), 12);
@@ -564,31 +560,31 @@ function test_date_add_diff_day(t){
 	dtA = new Date(2000, 0, 1);
 	dtB = dojo.date.add(dtA, interv, 1);
 	t.is(dojo.date.difference(dtA, dtB, interv), 1);
-	
+
 	dtA = new Date(2001, 0, 1);
 	dtB = dojo.date.add(dtA, interv, 365);
 	t.is(dojo.date.difference(dtA, dtB, interv), 365);
-	
+
 	dtA = new Date(2000, 0, 1);
 	dtB = dojo.date.add(dtA, interv, 366);
 	t.is(dojo.date.difference(dtA, dtB, interv), 366);
-	
+
 	dtA = new Date(2000, 1, 28);
 	dtB = dojo.date.add(dtA, interv, 1);
 	t.is(dojo.date.difference(dtA, dtB, interv), 1);
-	
+
 	dtA = new Date(2001, 1, 28);
 	dtB = dojo.date.add(dtA, interv, 1);
 	t.is(dojo.date.difference(dtA, dtB, interv), 1);
-	
+
 	dtA = new Date(2000, 2, 1);
 	dtB = dojo.date.add(dtA, interv, -1);
 	t.is(dojo.date.difference(dtA, dtB, interv), -1);
-	
+
 	dtA = new Date(2001, 2, 1);
 	dtB = dojo.date.add(dtA, interv, -1);
 	t.is(dojo.date.difference(dtA, dtB, interv), -1);
-	
+
 	dtA = new Date(2000, 0, 1);
 	dtB = dojo.date.add(dtA, interv, -1);
 	t.is(dojo.date.difference(dtA, dtB, interv), -1);
@@ -603,43 +599,43 @@ function test_date_add_diff_weekday(t){
 	// Should be Mon, Jan 3
 	dtB = dojo.date.add(dtA, interv, 1);
 	t.is(dojo.date.difference(dtA, dtB, interv), 1);
-	
+
 	// Sun, Jan 2
 	dtA = new Date(2000, 0, 2);
 	// Should be Mon, Jan 3
 	dtB = dojo.date.add(dtA, interv, 1);
 	t.is(dojo.date.difference(dtA, dtB, interv), 1);
-	
+
 	// Sun, Jan 2
 	dtA = new Date(2000, 0, 2);
 	// Should be Fri, Jan 7
 	dtB = dojo.date.add(dtA, interv, 5);
 	t.is(dojo.date.difference(dtA, dtB, interv), 5);
-	
+
 	// Sun, Jan 2
 	dtA = new Date(2000, 0, 2);
 	// Should be Mon, Jan 10
 	dtB = dojo.date.add(dtA, interv, 6);
 	t.is(dojo.date.difference(dtA, dtB, interv), 6);
-	
+
 	// Mon, Jan 3
 	dtA = new Date(2000, 0, 3);
 	// Should be Mon, Jan 17
 	dtB = dojo.date.add(dtA, interv, 10);
 	t.is(dojo.date.difference(dtA, dtB, interv), 10);
-	
+
 	// Sat, Jan 8
 	dtA = new Date(2000, 0, 8);
 	// Should be Mon, Jan 3
 	dtB = dojo.date.add(dtA, interv, -5);
 	t.is(dojo.date.difference(dtA, dtB, interv), -5);
-	
+
 	// Sun, Jan 9
 	dtA = new Date(2000, 0, 9);
 	// Should be Wed, Jan 5
 	dtB = dojo.date.add(dtA, interv, -3);
 	t.is(dojo.date.difference(dtA, dtB, interv), -3);
-	
+
 	// Sun, Jan 23
 	dtA = new Date(2000, 0, 23);
 	// Should be Fri, Jan 7
@@ -693,7 +689,7 @@ function test_date_add_diff_second(t){
 	dtA = new Date(2000, 11, 27, 8, 10, 59);
 	dtB = dojo.date.add(dtA, interv, 60);
 	t.is(dojo.date.difference(dtA, dtB, interv), 60);
-	
+
 	// Test environment JS Date doesn't support millisec?
 	//interv = "millisecond";
 	//
@@ -707,6 +703,4 @@ function test_date_add_diff_second(t){
 }
 	]
 );
-
-dojo.require("tests.date.locale");
-dojo.require("tests.date.stamp");
+});
