@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 /*<?xml version="1.0" encoding="UTF-8" ?>*/
 // The above is a workaround for Konqueror and Safari (see bug #1010)
 // The parentheses are optional, but make this file a valid JS expression for
@@ -6,3 +8,5 @@
  ar: "العربية",
  hello: "ﺎﺑﺣﺮﻣ"
 })
+//end v1.x content
+);
