@@ -1,12 +1,11 @@
-dojo.provide("tests.regexp");
+define(["../main", "doh", "../regexp"], function(dojo, doh){
 
-dojo.require("dojo.regexp");
-
-tests.register("tests.regexp",
-	[
+doh.register("tests.regexp",
 		function test_regexp_escape(t){
 			t.assertTrue(new RegExp(dojo.regexp.escapeString("\f\b\n\t\r+.$?*|{}()[]\\/^")).test("TEST\f\b\n\t\r+.$?*|{}()[]\\/^TEST"));
 			t.assertTrue(new RegExp(dojo.regexp.escapeString("\f\b\n\t\r+.$?*|{}()[]\\/^", ".")).test("TEST\f\b\n\t\r+X$?*|{}()[]\\/^TEST"));
 		}
-	]
 );
+
+
+});
