@@ -1,14 +1,16 @@
 dojo.provide("dojo.tests.store.DataStore");
 dojo.require("dojo.store.DataStore");
-dojo.require("dojo.data.ItemFileWriteStore")
+dojo.require("dojo.data.ItemFileWriteStore");
 var temp = function(){
-	var two, four;
+	var two = {id: 2, name: "two", even: true, prime: true},
+			four = {id: 4, name: "four", even: true, prime: false};
+	
 	var dataStore = new dojo.data.ItemFileWriteStore({data:{
 		items: [
 			{id: 1, name: "one", prime: false},
-			two = {id: 2, name: "two", even: true, prime: true},
+			{id: 2, name: "two", even: true, prime: true},
 			{id: 3, name: "three", prime: true},
-			four = {id: 4, name: "four", even: true, prime: false},
+			{id: 4, name: "four", even: true, prime: false},
 			{id: 5, name: "five", prime: true}
 		],
 		identifier:"id"
@@ -22,17 +24,25 @@ var temp = function(){
 				t.is(store.get(4).name, "four");
 				t.t(store.get(5).prime);
 			},
-			function testQuery(t){
-				store.query({prime: true}).then(function(results){
+			function testQuery1(t){
+				var d = new doh.Deferred();
+				store.query({prime: true}).then(d.getTestCallback(function(results){
 					t.is(results.length, 3);
-				});
-				store.query({even: true}).map(function(object){
+				}));
+				return d;
+			},
+			function testQuery2(t){
+				var d = new doh.Deferred();
+				var result = store.query({even: true});
+				result.map(d.getTestErrback(function(object){
 					for(var i in object){
-						t.is(object[i], (object.id == 2 ? two : four)[i]);
+						t.is(object[i], (object.id == 2 ? two : four)[i], "map of " + i);
 					}
-				}).then(function(results){
-					t.is(results[1].name, "four");
-				});
+				}));
+				result.then(d.getTestCallback(function(results){
+					t.is("four", results[1].name, "then");
+				}));
+				return d;
 			},
 			function testPutUpdate(t){
 				var four = store.get(4);
@@ -47,6 +57,10 @@ var temp = function(){
 					perfect: true
 				});
 				t.t(store.get(6).perfect);
+			},
+			function testNoWriteFeature(t){
+				var readOnlyStore = new dojo.store.DataStore({store:new dojo.data.ItemFileReadStore({})});
+				t.f(readOnlyStore.put);
 			}
 		]
 	);
