@@ -1,5 +1,7 @@
+define(
+//begin v1.x content
 ({
-	displayOptions: "[opcions de visualització]",
+	displayOptions: "[mostra opcions]",
 	title: "Títol",
 	authors: "Autors",
 	contributors: "Col·laboradors",
@@ -9,4 +11,5 @@
 	summary: "Resum",
 	content: "Contingut"
 })
-
+//end v1.x content
+);
