@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	displayOptions: "[fremvisningsvalg]",
 	title: "Titel",
@@ -6,6 +8,8 @@
 	id: "Id",
 	close: "[luk]",
 	updated: "Opdateret",
-	summary: "Summary",
+	summary: "Resumé",
 	content: "Indhold"
 })
+//end v1.x content
+);
