@@ -1,5 +1,9 @@
+define(
+//begin v1.x content
 ({
 	add: "Hinzufügen",
 	addAuthor: "Autor hinzufügen",
 	addContributor: "Mitwirkenden hinzufügen"
-})
\ No newline at end of file
+})
+//end v1.x content
+);
