@@ -1,11 +1,15 @@
+define(
+//begin v1.x content
 ({
 	displayOptions: "[näyttöasetukset]",
 	title: "Otsikko",
 	authors: "Tekijät",
-	contributors: "Osallistujat",
+	contributors: "Lisääjät",
 	id: "Tunnus",
 	close: "[sulje]",
 	updated: "Päivitetty",
-	summary: "Yhteenveto",
+	summary: "Tiivistelmä",
 	content: "Sisältö"
 })
+//end v1.x content
+);
