@@ -1,5 +1,7 @@
+define(
+//begin v1.x content
 ({
-	displayOptions: "[הצגת אפשרויות]",
+	displayOptions: "[אפשרויות הצגה]",
 	title: "כותרת",
 	authors: "מחברים",
 	contributors: "תורמים",
@@ -9,3 +11,5 @@
 	summary: "סיכום",
 	content: "תוכן"
 })
+//end v1.x content
+);
