@@ -1,5 +1,9 @@
+define(
+//begin v1.x content
 ({
 	add: "Aggiungi",
 	addAuthor: "Aggiungi autore",
 	addContributor: "Aggiungi collaboratori"
-})
\ No newline at end of file
+})
+//end v1.x content
+);
