@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	displayOptions: "[表示オプション]",
 	title: "タイトル",
@@ -8,4 +10,6 @@
 	updated: "更新",
 	summary: "要約",
 	content: "内容"
-})
\ No newline at end of file
+})
+//end v1.x content
+);
