@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	displayOptions: "[exibir opções]",
 	title: "Título",
@@ -8,4 +10,6 @@
 	updated: "Atualizado",
 	summary: "Resumo",
 	content: "Conteúdo"
-})
\ No newline at end of file
+})
+//end v1.x content
+);
