@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	displayOptions: "[показать опции]",
 	title: "Название",
@@ -8,4 +10,6 @@
 	updated: "Обновлено",
 	summary: "Сводка",
 	content: "Информационное наполнение"
-})
\ No newline at end of file
+})
+//end v1.x content
+);
