@@ -1,6 +1,10 @@
+define(
+//begin v1.x content
 ({
 	doNew: "[新建]",
 	edit: "[編輯]",
 	save: "[儲存]",
 	cancel: "[取消]"
-})
\ No newline at end of file
+})
+//end v1.x content
+);
