@@ -1,5 +1,9 @@
+define(
+//begin v1.x content
 ({
 	add: "添加",
 	addAuthor: "添加作者",
 	addContributor: "添加内容添加者"
-})
\ No newline at end of file
+})
+//end v1.x content
+);
