@@ -1,28 +1,18 @@
-dojo.provide("dojox.charting.plot2d.Spider");
+define(["dojo/_base/lang", "dojo/_base/declare", "dojo/_base/connect", "dojo/_base/html", "dojo/_base/array",
+	"dojo/dom-geometry", "dojo/_base/fx", "dojo/fx", "dojo/_base/sniff", 
+	"../Element", "./_PlotEvents", "dojo/_base/Color", "dojox/color/_base", "./common", "../axis2d/common", 
+	"../scaler/primitive", "dojox/gfx", "dojox/gfx/matrix", "dojox/gfx/fx", "dojox/lang/functional", 
+	"dojox/lang/utils", "dojo/fx/easing"],
+	function(lang, declare, hub, html, arr, domGeom, baseFx, coreFx, has, 
+			Element, PlotEvents, Color, dxcolor, dc, da, primitive,
+			g, m, gfxfx, df, du, easing){
+/*=====
+var Element = dojox.charting.Element;
+var PlotEvents = dojox.charting.plot2d._PlotEvents;
+=====*/
+	var FUDGE_FACTOR = 0.2; // use to overlap fans
 
-dojo.experimental("dojox.charting.plot2d.Spider");
-
-dojo.require("dojox.charting.Element");
-dojo.require("dojox.charting.plot2d._PlotEvents");
-dojo.require("dojox.charting.axis2d.common");
-dojo.require("dojox.charting.plot2d.common");
-dojo.require("dojox.charting.scaler.primitive");
-
-dojo.require("dojox.lang.functional");
-dojo.require("dojox.lang.utils");
-dojo.require("dojox.gfx");
-dojo.require("dojo.fx");
-dojo.require("dojo.fx.easing");
-dojo.require("dojox.gfx.fx");
-
-(function(){
-	var df = dojox.lang.functional, du = dojox.lang.utils,
-		dc = dojox.charting.plot2d.common,
-		da = dojox.charting.axis2d.common,
-		g = dojox.gfx, m = g.matrix,
-		FUDGE_FACTOR = 0.2; // use to overlap fans
-
-	dojo.declare("dojox.charting.plot2d.Spider", [dojox.charting.Element, dojox.charting.plot2d._PlotEvents], {
+	var Spider = declare("dojox.charting.plot2d.Spider", [Element, PlotEvents], {
 		//	summary:
 		//		The plot that represents a typical Spider chart.
 		defaultParams: {
@@ -44,7 +34,7 @@ dojo.require("dojox.gfx.fx");
 			spiderOrigin:	 0.16,
 			markerSize:		 3,			// radius of plot vertex (px)
 			spiderType:		 "polygon", //"circle"
-			animationType:	 dojo.fx.easing.backOut,
+			animationType:	 easing.backOut,
 			axisTickFont:		"",
 			axisTickFontColor:	"",
 			axisFont:			"",
@@ -59,7 +49,7 @@ dojo.require("dojox.gfx.fx");
 		constructor: function(chart, kwArgs){
 			//	summary:
 			//		Create a Spider plot.
-			this.opt = dojo.clone(this.defaultParams);
+			this.opt = lang.clone(this.defaultParams);
 			du.updateWithObject(this.opt, kwArgs);
 			du.updateWithPattern(this.opt, kwArgs, this.optionalParams);
 			this.series = [];
@@ -122,7 +112,7 @@ dojo.require("dojox.gfx.fx");
 			//		Calculate the min/max on all attached series in both directions.
 			//	returns: Object
 			//		{hmin, hmax, vmin, vmax} min/max in both directions.
-			return dojox.charting.plot2d.common.collectSimpleStats(this.series);
+			return dc.collectSimpleStats(this.series);
 		},
 		calculateAxes: function(dim){
 			//	summary:
@@ -156,7 +146,7 @@ dojo.require("dojox.gfx.fx");
 				}
 				this._hScaler = this._hAxis.getScaler();
 			}else{
-				this._hScaler = dojox.charting.scaler.primitive.buildScaler(stats.hmin, stats.hmax, dim.width);
+				this._hScaler = primitive.buildScaler(stats.hmin, stats.hmax, dim.width);
 			}
 			if(this._vAxis){
 				if(!this._vAxis.initialized()){
@@ -164,7 +154,7 @@ dojo.require("dojox.gfx.fx");
 				}
 				this._vScaler = this._vAxis.getScaler();
 			}else{
-				this._vScaler = dojox.charting.scaler.primitive.buildScaler(stats.vmin, stats.vmax, dim.height);
+				this._vScaler = primitive.buildScaler(stats.vmin, stats.vmax, dim.height);
 			}
 			return this;	//	dojox.charting.plot2d.Base
 		},
@@ -210,12 +200,12 @@ dojo.require("dojox.gfx.fx");
 				axisExtra = 0.2;
 			
 			if(o.labels){
-				labels = dojo.map(this.series, function(s){
+				labels = arr.map(this.series, function(s){
 					return s.name;
 				}, this);
 				shift = df.foldl1(df.map(labels, function(label, i){
 					var font = t.series.font;
-					return dojox.gfx._base._getTextBox(label, {
+					return g._base._getTextBox(label, {
 						font: font
 					}).w;
 				}, this), "Math.max(a, b)") / 2;
@@ -289,9 +279,9 @@ dojo.require("dojox.gfx.fx");
 			var labelGroup = s.createGroup();
 			for (var j = labelPoints.length - 1; j >= 0; --j) {
 				var point = labelPoints[j],
-					fontWidth = dojox.gfx._base._getTextBox(this.labelKey[j], {font: axisFont}).w || 0,
-					render = this.opt.htmlLabels && dojox.gfx.renderer != "vml" ? "html" : "gfx";
-					elem = da.createText[render](this.chart, labelGroup, (!dojo._isBodyLtr() && render == "html") ? (point.x + fontWidth - dim.width) : point.x, point.y,
+					fontWidth = g._base._getTextBox(this.labelKey[j], {font: axisFont}).w || 0,
+					render = this.opt.htmlLabels && g.renderer != "vml" ? "html" : "gfx",
+					elem = da.createText[render](this.chart, labelGroup, (!domGeom.isBodyLtr() && render == "html") ? (point.x + fontWidth - dim.width) : point.x, point.y,
 							"middle", this.labelKey[j], axisFont, axisFontColor);
 				if (this.opt.htmlLabels) {
 					this.htmlElements.push(elem);
@@ -326,11 +316,11 @@ dojo.require("dojox.gfx.fx");
 				for (var i = 0; i < dv; i++) {
 					var text = min + distance*i/(dv-1), point = this._getCoordinate(circle, r*(ro + (1-ro)*i/(dv-1)), end);
 					text = this._getLabel(text);
-					var fontWidth = dojox.gfx._base._getTextBox(text, {font: axisTickFont}).w || 0,
-						render = this.opt.htmlLabels && dojox.gfx.renderer != "vml" ? "html" : "gfx";
+					var fontWidth = g._base._getTextBox(text, {font: axisTickFont}).w || 0,
+						render = this.opt.htmlLabels && g.renderer != "vml" ? "html" : "gfx";
 					if (this.opt.htmlLabels) {
 						this.htmlElements.push(da.createText[render]
-							(this.chart, textGroup, (!dojo._isBodyLtr() && render == "html") ? (point.x + fontWidth - dim.width) : point.x, point.y,
+							(this.chart, textGroup, (!domGeom.isBodyLtr() && render == "html") ? (point.x + fontWidth - dim.width) : point.x, point.y,
 								"start", text, axisTickFont, axisTickFontColor));
 					}
 				}
@@ -393,7 +383,7 @@ dojo.require("dojox.gfx.fx");
 					};
 					this._connectEvents(so);
 					
-					dojo.forEach(cs.circles, function(c, i){
+					arr.forEach(cs.circles, function(c, i){
 						var shape = c.getShape(),
 							co = {
 								element: "spider_circle",
@@ -424,16 +414,16 @@ dojo.require("dojox.gfx.fx");
 				scircle.push(circle);
 			}
 			
-			var anims = dojo.map(sps, function(np, j){
+			var anims = arr.map(sps, function(np, j){
 				// create animation
 				var sp = osps[j],
-					anim = new dojo._Animation({
+					anim = new baseFx.Animation({
 					duration: 1000,
 					easing:	  at,
 					curve:	  [sp.y, np.y]
 				});
 				var spl = spoly, sc = scircle[j];
-				dojo.connect(anim, "onAnimate", function(y){
+				hub.connect(anim, "onAnimate", function(y){
 					//apply poly
 					var pshape = spl.getShape();
 					pshape.points[j].y = y;
@@ -446,16 +436,16 @@ dojo.require("dojox.gfx.fx");
 				return anim;
 			});
 			
-			var anims1 = dojo.map(sps, function(np, j){
+			var anims1 = arr.map(sps, function(np, j){
 				// create animation
 				var sp = osps[j],
-					anim = new dojo._Animation({
+					anim = new baseFx.Animation({
 					duration: 1000,
 					easing:	  at,
 					curve:	  [sp.x, np.x]
 				});
 				var spl = spoly, sc = scircle[j];
-				dojo.connect(anim, "onAnimate", function(x){
+				hub.connect(anim, "onAnimate", function(x){
 					//apply poly
 					var pshape = spl.getShape();
 					pshape.points[j].x = x;
@@ -467,7 +457,7 @@ dojo.require("dojox.gfx.fx");
 				});
 				return anim;
 			});
-			var masterAnimation = dojo.fx.combine(anims.concat(anims1)); //dojo.fx.chain(anims);
+			var masterAnimation = coreFx.combine(anims.concat(anims1)); //dojo.fx.chain(anims);
 			masterAnimation.play();
 			return {group :ts, poly: spoly, circles: scircle};
 		},
@@ -486,7 +476,7 @@ dojo.require("dojox.gfx.fx");
 			if(o.element == "spider_poly"){
 				if(!a.color){
 					var color = o.shape.getFill();
-					if(!color || !(color instanceof dojo.Color)){
+					if(!color || !(color instanceof Color)){
 						return;
 					}
 					a.color = {
@@ -499,24 +489,24 @@ dojo.require("dojox.gfx.fx");
 					// swap colors
 					var t = start; start = end; end = t;
 				}
-				a.anim = dojox.gfx.fx.animateFill({
+				a.anim = gfxfx.animateFill({
 					shape:	  o.shape,
 					duration: 800,
-					easing:	  dojo.fx.easing.backOut,
+					easing:	  easing.backOut,
 					color:	  {start: start, end: end}
 				});
 				a.anim.play();
 			}else if(o.element == "spider_circle"){
 				var init, scale, defaultScale = 1.5;
 				if(o.type == "onmouseover"){
-					init  = dojox.gfx.matrix.identity;
+					init  = m.identity;
 					scale = defaultScale;
 					//show tooltip
 					var aroundRect = {type: "rect"};
 					aroundRect.x = o.cx;
 					aroundRect.y = o.cy;
 					aroundRect.width = aroundRect.height = 1;
-					var lt = dojo.coords(this.chart.node, true);
+					var lt = html.coords(this.chart.node, true);
 					aroundRect.x += lt.x;
 					aroundRect.y += lt.y;
 					aroundRect.x = Math.round(aroundRect.x);
@@ -525,32 +515,32 @@ dojo.require("dojox.gfx.fx");
 					aroundRect.height = Math.ceil(aroundRect.height);
 					this.aroundRect = aroundRect;
 					var position = ["after", "before"];
-					if(dijit && dijit.Tooltip){
-						dijit.showTooltip(o.tdata.sname + "<br/>" + o.tdata.key + "<br/>" + o.tdata.data, this.aroundRect, position);
-					}
+					dc.doIfLoaded("dijit/Tooltip", dojo.hitch(this, function(Tooltip){
+						Tooltip.show(o.tdata.sname + "<br/>" + o.tdata.key + "<br/>" + o.tdata.data, this.aroundRect, position);
+					}));
 				}else{
-					init  = dojox.gfx.matrix.scaleAt(defaultScale, o.cx, o.cy);
+					init  = m.scaleAt(defaultScale, o.cx, o.cy);
 					scale = 1/defaultScale;
-					if(dijit && dijit.Tooltip){
-						this.aroundRect && dijit.hideTooltip(this.aroundRect);
-					}
+					dc.doIfLoaded("dijit/Tooltip", dojo.hitch(this, function(Tooltip){
+						this.aroundRect && Tooltip.hide(this.aroundRect);
+					}));
 				}
 				var cs = o.shape.getShape(),
 					init = m.scaleAt(defaultScale, cs.cx, cs.cy),
 					kwArgs = {
 						shape: o.shape,
 						duration: 200,
-						easing:	  dojo.fx.easing.backOut,
+						easing:	  easing.backOut,
 						transform: [
 							{name: "scaleAt", start: [1, cs.cx, cs.cy], end: [scale, cs.cx, cs.cy]},
 							init
 						]
 					};
-				a.anim = dojox.gfx.fx.animateTransform(kwArgs);
+				a.anim = gfxfx.animateTransform(kwArgs);
 				a.anim.play();
 			}else if(o.element == "spider_plot"){
 				//dojo gfx function "moveToFront" not work in IE
-				if (o.type == "onmouseover" && !dojo.isIE) {
+				if (o.type == "onmouseover" && !has("ie")) {
 					o.shape.moveToFront();
 				}
 			}
@@ -602,7 +592,7 @@ dojo.require("dojox.gfx.fx");
 		
 		_getObjectLength: function(obj){
 			var count = 0;
-			if(dojo.isObject(obj)){
+			if(lang.isObject(obj)){
 				for(var key in obj){
 					count++;
 				}
@@ -617,7 +607,7 @@ dojo.require("dojox.gfx.fx");
 	});
 	
 	function transColor(color){
-		var a = new dojox.color.Color(color),
+		var a = new dxcolor.Color(color),
 			x = a.toHsl();
 		if(x.s == 0){
 			x.l = x.l < 50 ? 100 : 0;
@@ -632,9 +622,10 @@ dojo.require("dojox.gfx.fx");
 					50 : 75;
 			}
 		}
-		var color = dojox.color.fromHsl(x);
+		var color = dxcolor.fromHsl(x);
 		color.a = 0.7;
 		return color;
 	}
 	
-})();
+	return Spider; // dojox.plot2d.Spider
+});
