@@ -1,12 +1,29 @@
-dojo.provide("dojox.charting.scaler.common");
+define(["dojo/_base/lang"], function(lang){
 
-(function(){
 	var eq = function(/*Number*/ a, /*Number*/ b){
 		// summary: compare two FP numbers for equality
 		return Math.abs(a - b) <= 1e-6 * (Math.abs(a) + Math.abs(b));	// Boolean
 	};
 	
-	dojo.mixin(dojox.charting.scaler.common, {
+	var common = lang.getObject("dojox.charting.scaler.common", true);
+	
+	var testedModules = {};
+
+	return lang.mixin(common, {
+		doIfLoaded: function(moduleName, ifloaded, ifnotloaded){
+			if(testedModules[moduleName] == undefined){
+				try{
+					testedModules[moduleName] = require(moduleName);
+				}catch(e){
+					testedModules[moduleName] = null;
+				}
+			}
+			if(testedModules[moduleName]){
+				return ifloaded(testedModules[moduleName]);
+			}else{
+				return ifnotloaded();
+			}
+		},
 		findString: function(/*String*/ val, /*Array*/ text){
 			val = val.toLowerCase();
 			for(var i = 0; i < text.length; ++i){
@@ -15,9 +32,13 @@ dojo.provide("dojox.charting.scaler.common");
 			return false;
 		},
 		getNumericLabel: function(/*Number*/ number, /*Number*/ precision, /*Object*/ kwArgs){
-			var def = kwArgs.fixed ? 
-						number.toFixed(precision < 0 ? -precision : 0) : 
-						number.toString();
+			var def = "";
+			common.doIfLoaded("dojo/number", function(numberLib){
+				def = (kwArgs.fixed ? numberLib.format(number, {places : precision < 0 ? -precision : 0}) :
+					numberLib.format(number)) || "";
+			}, function(){
+				def = kwArgs.fixed ? number.toFixed(precision < 0 ? -precision : 0) : number.toString();
+			});
 			if(kwArgs.labelFunc){
 				var r = kwArgs.labelFunc(def, number, precision);
 				if(r){ return r; }
@@ -51,4 +72,4 @@ dojo.provide("dojox.charting.scaler.common");
 			return def;
 		}
 	});
-})();
+});
