@@ -1,8 +1,6 @@
-dojo.provide("dojox.charting.themes.Distinctive");
-dojo.require("dojox.charting.Theme");
-(function(){
-	var dxc=dojox.charting;
-	dxc.themes.Distinctive=new dxc.Theme({  
+define(["../Theme", "./common"], function(Theme, themes){
+	
+	themes.Distinctive=new Theme({
 		colors: [
 			"#497c91",
 			"#ada9d6",
@@ -35,8 +33,10 @@ dojo.require("dojox.charting.Theme");
 			"#efdeb0",
 			"#b17044",
 			"#ddc0c0",
-			"#a5a5a5" 
+			"#a5a5a5"
 		
 		]
 	});
-})();
\ No newline at end of file
+	
+	return themes.Distinctive;
+});
