@@ -5,20 +5,20 @@ dojo.require("dojo.data.api.Identity");
 
 
 dojox.data.tests.stores.HtmlTableStore.getBooks2Store = function(){
-	return new dojox.data.HtmlTableStore({url: dojo.moduleUrl("dojox.data.tests", "stores/books2.html").toString(), tableId: "books2"});
+	return new dojox.data.HtmlTableStore({url: require.toUrl("dojox/data/tests/stores/books2.html").toString(), tableId: "books2"});
 };
 
 dojox.data.tests.stores.HtmlTableStore.getBooksStore = function(){
-	return new dojox.data.HtmlTableStore({url: dojo.moduleUrl("dojox.data.tests", "stores/books.html").toString(), tableId: "books"});
+	return new dojox.data.HtmlTableStore({url: require.toUrl("dojox/data/tests/stores/books.html").toString(), tableId: "books"});
 };
 
-doh.register("dojox.data.tests.stores.HtmlTableStore", 
+doh.register("dojox.data.tests.stores.HtmlTableStore",
 	[
 /***************************************
      dojo.data.api.Read API
 ***************************************/
 		function testReadAPI_fetch_all(t){
-			//	summary: 
+			//	summary:
 			//		Simple test of fetching all xml items through an XML element called isbn
 			//	description:
 			//		Simple test of fetching all xml items through an XML element called isbn
@@ -36,7 +36,7 @@ doh.register("dojox.data.tests.stores.HtmlTableStore",
 			return d; //Object
 		},
 		function testReadAPI_fetch_one(t){
-			//	summary: 
+			//	summary:
 			//		Simple test of fetching one xml items through an XML element called isbn
 			//	description:
 			//		Simple test of fetching one xml items through an XML element called isbn
@@ -54,7 +54,7 @@ doh.register("dojox.data.tests.stores.HtmlTableStore",
 			return d; //Object
 		},
 		function testReadAPI_fetch_paging(t){
-			//	summary: 
+			//	summary:
 			//		Simple test of fetching one xml items through an XML element called isbn
 			//	description:
 			//		Simple test of fetching one xml items through an XML element called isbn
@@ -122,12 +122,12 @@ doh.register("dojox.data.tests.stores.HtmlTableStore",
 			return d; //Object
 		},
 		function testReadAPI_fetch_pattern0(t){
-			//	summary: 
+			//	summary:
 			//		Simple test of fetching one xml items through an XML element called isbn with ? pattern match
 			//	description:
 			//		Simple test of fetching one xml items through an XML element called isbn with ? pattern match
 			var store = dojox.data.tests.stores.HtmlTableStore.getBooks2Store();
-			var d = new doh.Deferred();                                                             
+			var d = new doh.Deferred();
 			function onComplete(items, request) {
 				t.assertEqual(1, items.length);
 				d.callback(true);
@@ -139,7 +139,7 @@ doh.register("dojox.data.tests.stores.HtmlTableStore",
 			return d; //Object
 		},
 		function testReadAPI_fetch_pattern1(t){
-			//	summary: 
+			//	summary:
 			//		Simple test of fetching one xml items through an XML element called isbn with ? pattern match
 			//	description:
 			//		Simple test of fetching one xml items through an XML element called isbn with ? pattern match
@@ -156,7 +156,7 @@ doh.register("dojox.data.tests.stores.HtmlTableStore",
 			return d; //Object
 		},
 		function testReadAPI_fetch_pattern2(t){
-			//	summary: 
+			//	summary:
 			//		Simple test of fetching one xml items through an XML element called isbn with * pattern match
 			//	description:
 			//		Simple test of fetching one xml items through an XML element called isbn with * pattern match
@@ -173,12 +173,12 @@ doh.register("dojox.data.tests.stores.HtmlTableStore",
 			return d; //Object
 		},
 		function testReadAPI_fetch_pattern_caseInsensitive(t){
-			//	summary: 
+			//	summary:
 			//		Simple test of fetching one xml items through an XML element called isbn with ? pattern match and in case insensitive mode.
 			//	description:
 			//		Simple test of fetching one xml items through an XML element called isbn with ? pattern match and in case insensitive mode.
 			var store = dojox.data.tests.stores.HtmlTableStore.getBooks2Store();
-			var d = new doh.Deferred();                                                             
+			var d = new doh.Deferred();
 			function onComplete(items, request) {
 				t.assertEqual(1, items.length);
 				d.callback(true);
@@ -190,12 +190,12 @@ doh.register("dojox.data.tests.stores.HtmlTableStore",
 			return d; //Object
 		},
 		function testReadAPI_fetch_pattern_caseSensitive(t){
-			//	summary: 
+			//	summary:
 			//		Simple test of fetching one xml items through an XML element called isbn with ? pattern match and in case sensitive mode.
 			//	description:
 			//		Simple test of fetching one xml items through an XML element called isbn with ? pattern match and in case sensitive mode.
 			var store = dojox.data.tests.stores.HtmlTableStore.getBooks2Store();
-			var d = new doh.Deferred();                                                             
+			var d = new doh.Deferred();
 			function onComplete(items, request) {
 				t.assertEqual(1, items.length);
 				d.callback(true);
@@ -207,7 +207,7 @@ doh.register("dojox.data.tests.stores.HtmlTableStore",
 			return d; //Object
 		},
 		function testReadAPI_getLabel(t){
-			//	summary: 
+			//	summary:
 			//		Simple test of the getLabel function against a store set that has a label defined.
 			//	description:
 			//		Simple test of the getLabel function against a store set that has a label defined.
@@ -229,7 +229,7 @@ doh.register("dojox.data.tests.stores.HtmlTableStore",
 			return d;
 		},
 		function testReadAPI_getLabelAttributes(t){
-			//	summary: 
+			//	summary:
 			//		Simple test of the getLabelAttributes function against a store set that has a label defined.
 			//	description:
 			//		Simple test of the getLabelAttributes function against a store set that has a label defined.
@@ -251,7 +251,7 @@ doh.register("dojox.data.tests.stores.HtmlTableStore",
 		},
 
 		function testReadAPI_getValue(t){
-			 //	summary: 
+			 //	summary:
 			 //		Simple test of the getValue API
 			 //	description:
 			 //		Simple test of the getValue API
@@ -272,7 +272,7 @@ doh.register("dojox.data.tests.stores.HtmlTableStore",
 			 return d; //Object
 		},
 		function testReadAPI_getValues(t){
-			 //	summary: 
+			 //	summary:
 			 //		Simple test of the getValues API
 			 //	description:
 			 //		Simple test of the getValues API
@@ -295,7 +295,7 @@ doh.register("dojox.data.tests.stores.HtmlTableStore",
 			 return d; //Object
 		},
 		function testReadAPI_isItem(t){
-			 //	summary: 
+			 //	summary:
 			 //		Simple test of the isItem API
 			 //	description:
 			 //		Simple test of the isItem API
@@ -318,7 +318,7 @@ doh.register("dojox.data.tests.stores.HtmlTableStore",
 			 return d; //Object
 		},
 		function testReadAPI_isItem_multistore(t){
-			//	summary: 
+			//	summary:
 			//		Simple test of the isItem API across multiple store instances.
 			//	description:
 			//		Simple test of the isItem API across multiple store instances.
@@ -348,7 +348,7 @@ doh.register("dojox.data.tests.stores.HtmlTableStore",
 			return d; //Object
 		},
 		function testReadAPI_hasAttribute(t){
-			//	summary: 
+			//	summary:
 			//		Simple test of the hasAttribute API
 			//	description:
 			//		Simple test of the hasAttribute API
@@ -369,7 +369,7 @@ doh.register("dojox.data.tests.stores.HtmlTableStore",
 			return d; //Object
 		},
 		function testReadAPI_containsValue(t){
-			//	summary: 
+			//	summary:
 			//		Simple test of the containsValue API
 			//	description:
 			//		Simple test of the containsValue API
@@ -390,7 +390,7 @@ doh.register("dojox.data.tests.stores.HtmlTableStore",
 			return d; //Object
 		},
 		function testReadAPI_sortDescending(t){
-			//	summary: 
+			//	summary:
 			//		Simple test of the sorting API in descending order.
 			//	description:
 			//		Simple test of the sorting API in descending order.
@@ -418,7 +418,7 @@ doh.register("dojox.data.tests.stores.HtmlTableStore",
 			return d; //Object
 		},
 		function testReadAPI_sortAscending(t){
-			//	summary: 
+			//	summary:
 			//		Simple test of the sorting API in ascending order.
 			//	description:
 			//		Simple test of the sorting API in ascending order.
@@ -446,7 +446,7 @@ doh.register("dojox.data.tests.stores.HtmlTableStore",
 			return d; //Object
 		},
 		function testReadAPI_sortDescendingNumeric(t){
-			//	summary: 
+			//	summary:
 			//		Simple test of the sorting API in descending order using a numeric comparator.
 			//	description:
 			//		Simple test of the sorting API in descending order using a numeric comparator.
@@ -483,7 +483,7 @@ doh.register("dojox.data.tests.stores.HtmlTableStore",
 			return d; //Object
 		},
 		function testReadAPI_sortAscendingNumeric(t){
-			//	summary: 
+			//	summary:
 			//		Simple test of the sorting API in ascending order using a numeric comparator.
 			//	description:
 			//		Simple test of the sorting API in ascending order using a numeric comparator.
@@ -520,7 +520,7 @@ doh.register("dojox.data.tests.stores.HtmlTableStore",
 			return d; //Object
 		},
 		function testReadAPI_isItemLoaded(t){
-			//	summary: 
+			//	summary:
 			//		Simple test of the isItemLoaded API
 			//	description:
 			//		Simple test of the isItemLoaded API
@@ -540,13 +540,13 @@ doh.register("dojox.data.tests.stores.HtmlTableStore",
 			return d; //Object
 		},
 		function testReadAPI_getFeatures(t){
-			//	summary: 
+			//	summary:
 			//		Simple test of the getFeatures function of the store
 			//	description:
 			//		Simple test of the getFeatures function of the store
 
 			var store = dojox.data.tests.stores.HtmlTableStore.getBooks2Store();
-			var features = store.getFeatures(); 
+			var features = store.getFeatures();
 			var count = 0;
 			for(i in features){
 				t.assertTrue((i === "dojo.data.api.Read" || i === "dojo.data.api.Identity"));
@@ -555,7 +555,7 @@ doh.register("dojox.data.tests.stores.HtmlTableStore",
 			t.assertEqual(2, count);
 		},
 		function testReadAPI_getAttributes(t){
-			//	summary: 
+			//	summary:
 			//		Simple test of the getAttributes API
 			//	description:
 			//		Simple test of the getAttributes API
@@ -579,7 +579,7 @@ doh.register("dojox.data.tests.stores.HtmlTableStore",
 			return d; //Object
 		},
 		function testReadAPI_functionConformance(t){
-			//	summary: 
+			//	summary:
 			//		Simple test read API conformance.  Checks to see all declared functions are actual functions on the instances.
 			//	description:
 			//		Simple test read API conformance.  Checks to see all declared functions are actual functions on the instances.
@@ -606,7 +606,7 @@ doh.register("dojox.data.tests.stores.HtmlTableStore",
      dojo.data.api.Identity API
 ***************************************/
 		function testIdentityAPI_getIdentity(t){
-			//	summary: 
+			//	summary:
 			//		Simple test of the getAttributes API
 			//	description:
 			//		Simple test of the getAttributes API
@@ -626,7 +626,7 @@ doh.register("dojox.data.tests.stores.HtmlTableStore",
 			return d; //Object
 		},
 		function testIdentityAPI_getIdentityAttributes(t){
-			//	summary: 
+			//	summary:
 			//		Simple test of the getAttributes API
 			//	description:
 			//		Simple test of the getAttributes API
@@ -648,7 +648,7 @@ doh.register("dojox.data.tests.stores.HtmlTableStore",
 			return d; //Object
 		},
 		function testIdentityAPI_fetchItemByIdentity(t){
-			//	summary: 
+			//	summary:
 			//		Simple test of the fetchItemByIdentity API
 			//	description:
 			//		Simple test of the fetchItemByIdentity API
@@ -668,7 +668,7 @@ doh.register("dojox.data.tests.stores.HtmlTableStore",
 			return d; //Object
 		},
 		function testIdentityAPI_functionConformance(t){
-			//	summary: 
+			//	summary:
 			//		Simple test identity API conformance.  Checks to see all declared functions are actual functions on the instances.
 			//	description:
 			//		Simple test identity API conformance.  Checks to see all declared functions are actual functions on the instances.
