@@ -1,9 +1,15 @@
-dojo.provide("dojox.date.buddhist.Date");
+define([
+	"dojo/_base/kernel",
+	"dojo/_base/declare",
+	"dojo/date"
+], function(dojo, declare, dd){
+
+dojo.getObject("date.buddhist.Date", true, dojox);
 dojo.experimental("dojox.date.buddhist.Date");
 
 dojo.declare("dojox.date.buddhist.Date", null, {
 
-    _date: 0,
+	_date: 0,
 	_month: 0,
 	_year: 0,
 	_hours: 0,
@@ -200,74 +206,43 @@ dojo.declare("dojox.date.buddhist.Date", null, {
 		}
 		this._hours = hours;
 	},
-
-	setMinutes: function(/*number*/minutes){
-		//summary: set the Minutes  frm 0-59
-		while(minutes >= 60){
-			this._hours++;
-			if(this._hours >= 24){
-				this._date++;
-				this._hours -= 24;
-				var mdays = this._getDaysInMonth(this._month, this._year);
-				if(this._date > mdays){
-						this._month ++;
-						if(this._month >= 12){this._year++; this._month -= 12;}
-						this._date -= mdays;
-				}
-			}
-			minutes -= 60;
-		}
-		this._minutes = minutes;
+	
+	_addMinutes: function(/*Number*/minutes){
+		minutes += this._minutes;
+		this.setMinutes(minutes);
+		this.setHours(this._hours + parseInt(minutes / 60));
+		return this;
 	},
 
-	setSeconds: function(/*number*/seconds){
-		//summary: set the Seconds  from 0-59
-		while(seconds >= 60){
-			this._minutes++;
-			if(this._minutes >= 60){
-				this._hours++;
-				this._minutes -= 60;
-				if(this._hours >= 24){
-					this._date++;
-					this._hours -= 24;
-					var mdays = this._getDaysInMonth(this._month, this._year);
-					if(this._date > mdays){
-						this._month ++;
-						if(this._month >= 12){this._year++; this._month -= 12;}
-						this._date -= mdays;
-					}
-				}
-			}
-			seconds -= 60;
-		}
-		this._seconds = seconds;
+	_addSeconds: function(/*Number*/seconds){
+		seconds += this._seconds;
+		this.setSeconds(seconds);
+		this._addMinutes(parseInt(seconds / 60));
+		return this;
 	},
 
-	setMilliseconds: function(/*number*/milliseconds){
-		//summary: set the milliseconds
-		while(milliseconds >= 1000){
-			this.setSeconds++;
-			if(this.setSeconds >= 60){
-				this._minutes++;
-				this.setSeconds -= 60;
-				if(this._minutes >= 60){
-					this._hours++;
-					this._minutes -= 60;
-					if(this._hours >= 24){
-						this._date++;
-						this._hours -= 24;
-						var mdays = this._getDaysInMonth(this._month, this._year);
-				if(this._date > mdays){
-					this._month ++;
-					if(this._month >= 12){this._year++; this._month -= 12;}
-					this._date -= mdays;
-					}
-				}
-			}
-		}
-			milliseconds -= 1000;
-		}
-		this._milliseconds = milliseconds;
+	_addMilliseconds: function(/*Number*/milliseconds){
+		milliseconds += this._milliseconds;
+		this.setMilliseconds(milliseconds);
+		this._addSeconds(parseInt(milliseconds / 1000));
+		return this;
+	},
+
+	setMinutes: function(/*Number*/minutes){
+		//summary: sets the minutes (0-59) only.
+		this._minutes = minutes % 60;
+		return this;
+	},
+
+	setSeconds: function(/*Number*/seconds){
+		//summary: sets the seconds (0-59) only.
+		this._seconds = seconds % 60;
+		return this;
+	},
+
+	setMilliseconds: function(/*Number*/milliseconds){
+		this._milliseconds = milliseconds % 1000;
+		return this;
 	},
 
 	toString: function(){
@@ -277,7 +252,7 @@ dojo.declare("dojox.date.buddhist.Date", null, {
 
 //FIXME: remove this and replace usage with dojox.date.buddhist.getDaysInMonth?
 	_getDaysInMonth: function(/*number*/month, /*number*/ year){
-		return dojo.date.getDaysInMonth(new Date(year-543, month));
+		return dd.getDaysInMonth(new Date(year-543, month));
 	},
 
 	fromGregorian: function(/*Date*/gdate){
@@ -308,3 +283,6 @@ dojo.declare("dojox.date.buddhist.Date", null, {
 dojox.date.buddhist.Date.prototype.valueOf = function(){
 	return this.toGregorian().valueOf();
 };
+
+return dojox.date.buddhist.Date;
+});
