@@ -28,7 +28,7 @@ dojo.provide("dojox.drawing.Drawing");
 		//			Like Drawing, Toolbar is a psudeo Dijit that does not need Dijit. It is
 		//			optional. It can be oriented horizontal or vertical by placing one of
 		//			those params in the class (at least one is required).  Plugins
-		//			can be added in markup. A drawingId is required to point toolbar to 
+		//			can be added in markup. A drawingId is required to point toolbar to
 		//			the drawing.
 		//		- defaults
 		//			Contains the default styles and dimensions for Stencils. An individual
@@ -67,7 +67,7 @@ dojo.provide("dojox.drawing.Drawing");
 		//
 		// example:
 		//		|	<div dojoType="dojox.drawing.Drawing" id="drawing" defaults="myCustom.defaults"
-		//		|		plugins="[{'name':'dojox.drawing.plugins.drawing.Grid', 'options':{gap:100}}]">   
+		//		|		plugins="[{'name':'dojox.drawing.plugins.drawing.Grid', 'options':{gap:100}}]">
 		//		|   </div>
 		//
 		//	example:
@@ -131,9 +131,8 @@ dojo.provide("dojox.drawing.Drawing");
 			this.stencilTypeMap = {};
 			this.srcRefNode = node; // need this?
 			this.domNode = node;
-			var str = dojo.attr(node, "plugins"); // FIXME: get this from props if available
-			if(str){
-				this.plugins = eval(str);
+			if(props.plugins){
+				this.plugins = eval(props.plugins);
 			}else{
 				this.plugins = [];
 			}
@@ -198,7 +197,7 @@ dojo.provide("dojox.drawing.Drawing");
 				height:box.h+"px"
 			});
 			if(!this.canvas){
-				this._createCanvas();		
+				this._createCanvas();
 			}else if(box){
 				this.canvas.resize(box.w, box.h);
 			}
@@ -214,7 +213,7 @@ dojo.provide("dojox.drawing.Drawing");
 			//		a new Stencil. Mostly internal, but could be used.
 			//
 			var surface = data.stencilType;
-			var ui = this.mode=="ui" || mode=="ui"; 
+			var ui = this.mode=="ui" || mode=="ui";
 			return dojo.mixin({
 				container: ui && !surface ? this.canvas.overlay.createGroup() : this.canvas.surface.createGroup(),
 				util:this.util,
@@ -232,7 +231,7 @@ dojo.provide("dojox.drawing.Drawing");
 			//		to be parsed
 			this.plugins.push(plugin);
 			if(this.canvas.surfaceReady){
-				this.initPlugins();		
+				this.initPlugins();
 			}
 		},
 		
@@ -248,7 +247,6 @@ dojo.provide("dojox.drawing.Drawing");
 				});
 				return;
 			}
-			
 			dojo.forEach(this.plugins, function(p, i){
 				var props = dojo.mixin({
 					util:this.util,
@@ -298,7 +296,7 @@ dojo.provide("dojox.drawing.Drawing");
 				}
 			}
 			dojo.forEach(this.plugins, function(p){
-				p.onSurfaceReady && p.onSurfaceReady();	
+				p.onSurfaceReady && p.onSurfaceReady();
 			});
 		
 		},
@@ -420,10 +418,10 @@ dojo.provide("dojox.drawing.Drawing");
 			//		to the drawing.
 			dojo.forEach(objects, function(m){
 				this.addStencil(m.type, m);
-			}, this);	
+			}, this);
 		},
 		
-		changeDefaults: function(/*Object*/newStyle){
+		changeDefaults: function(/*Object*/newStyle,/*boolean*/value){
 			// summary:
 			//		Change the defaults so that all Stencils from this
 			// 		point on will use the newly changed style.
@@ -432,8 +430,11 @@ dojo.provide("dojox.drawing.Drawing");
 			//			An object that represents one of the objects in
 			//			drawing.style that will be mixed in. Not all
 			//			properties are necessary. Only one object may
-			//			be changed at a time. Non-objects like angleSnap
-			//			cannot be changed in this manner.
+			//			be changed at a time. The object boolean parameter
+			//			is not required and if not set objects will automatically
+			//			be changed.
+			//			Changing non-objects like angleSnap requires value
+			//			to be true.
 			// example:
 			//		|	myDrawing.changeDefaults({
 			//		|		norm:{
@@ -443,14 +444,24 @@ dojo.provide("dojox.drawing.Drawing");
 			//		|		}
 			//		|	});
 			//
-			for(var nm in newStyle){
-				for(var n in newStyle[nm]){
-					console.log("  copy", nm, n, " to: ", newStyle[nm][n]);
-					this.defaults[nm][n] = newStyle[nm][n];
+			//console.log("----->>> changeDefault: ",newStyle, " value?: ",value);
+			if(value!=undefined && value){
+				for(var nm in newStyle){
+					this.defaults[nm] = newStyle[nm];
+				}
+			}else{
+				for(var nm in newStyle){
+					for(var n in newStyle[nm]){
+						//console.log("  copy", nm, n, " to: ", newStyle[nm][n]);
+						this.defaults[nm][n] = newStyle[nm][n];
+					}
 				}
 			}
-			this.unSetTool();
-			this.setTool(this.currentType);
+			
+			if(this.currentStencil!=undefined && (!this.currentStencil.created || this.defaults.clickMode)){
+				this.unSetTool();
+				this.setTool(this.currentType);
+			}
 		},
 		
 		onRenderStencil: function(/* Object */stencil){
@@ -462,10 +473,10 @@ dojo.provide("dojox.drawing.Drawing");
 			
 			this.stencils.register(stencil);
 			this.unSetTool();
-			if(!this.defaults.clickMode){ 
+			if(!this.defaults.clickMode){
 				this.setTool(this.currentType);
 			}else{
-				if(this.defaults.clickMode){ this.defaults.clickable = true; }
+				this.defaults.clickable = true;
 			}
 		},
 		
@@ -473,7 +484,7 @@ dojo.provide("dojox.drawing.Drawing");
 			// summary:
 			//		Event fired from a stencil that has destroyed itself
 			//	 	will also be called when it is removed by "removeStencil"
-			//	 	or stencils.onDelete. 
+			//	 	or stencils.onDelete.
 			//
 			this.stencils.unregister(stencil);
 		},
@@ -531,11 +542,18 @@ dojo.provide("dojox.drawing.Drawing");
 			}
 		},
 		
+		set: function(name, value){
+			// summary:
+			//		Drawing registers as a widget and needs to support
+			//		widget's api.
+			console.info("Attempting to set ",name," to: ",value,". Set currently not fully supported in Drawing");
+		},
+		
 		unSetTool: function(){
 			// summary:
 			//		Destroys current tool
 			if(!this.currentStencil.created){
-				this.currentStencil.destroy();	
+				this.currentStencil.destroy();
 			}
 			
 		}
