@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	"saveLabel": "حفظ",
 	"saveSettingLabelOn": "تحديد الفترة الزمنية للحفظ الآلي...",
@@ -12,3 +14,5 @@
 	"saveMessageFail": "فشل في الحفظ في ${0}"
 })
 
+//end v1.x content
+);
