@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	insertImageTitle: "ادراج صورة",
 	url: "صورة",
@@ -9,3 +11,5 @@
 	prePopuTextBrowse: " أو تصفح الى ملف محلي."
 })
 
+//end v1.x content
+);
