@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	insertTableTitle: "‏ادراج جدول‏",
 	modifyTableTitle: "تعديل جدول",
@@ -18,6 +20,7 @@
 	right: "لليمين",
 	buttonSet: "تحديد", // translated elsewhere?
 	buttonInsert: "‏ادراج‏",
+	buttonCancel: "الغاء",
 
 	selectTableLabel: "تحديد جدول",
 	insertTableRowBeforeLabel: "اضافة صف قبل",
@@ -27,3 +30,5 @@
 	deleteTableRowLabel: "حذف صف",
 	deleteTableColumnLabel: "حذف عمود"
 })
+//end v1.x content
+);
