@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	"nodeActions": "${nodeName} - Accions",
 	"selectContents": "Selecciona contingut",
@@ -8,3 +10,5 @@
 	"moveEnd": "Mou el cursor al final"
 })
 
+//end v1.x content
+);
