@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	insertAnchor: "Insereix una àncora",
 	title: "Propietats de l'àncora",
@@ -7,3 +9,5 @@
 	cancel: "Cancel·la"
 })
 
+//end v1.x content
+);
