@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	widgetLabel: "Correcció ortogràfica per lots",
 	unfound: "No trobat",
@@ -15,3 +17,5 @@
 	iMsg: "No hi ha suggeriments ortogràfics"
 })
 
+//end v1.x content
+);
