@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	widgetLabel: "Dávková kontrola pravopisu",
 	unfound: "Nenalezeno",
@@ -15,3 +17,5 @@
 	iMsg: "Žádné návrhy pravopisu"
 })
 
+//end v1.x content
+);
