@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	insertTableTitle: "Vložit tabulku",
 	modifyTableTitle: "Upravit tabulku",
@@ -18,6 +20,7 @@
 	right: "vpravo",
 	buttonSet: "Nastavit", // translated elsewhere?
 	buttonInsert: "Vložit",
+	buttonCancel: "Storno",
 
 	selectTableLabel: "Vybrat tabulku",
 	insertTableRowBeforeLabel: "Přidat řádek před",
@@ -27,4 +30,5 @@
 	deleteTableRowLabel: "Odstranit řádek",
 	deleteTableColumnLabel: "Odstranit sloupec"
 })
-
+//end v1.x content
+);
