@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	"nodeActions": "${nodeName} - handlinger",
 	"selectContents": "Vælg indhold",
@@ -8,3 +10,5 @@
 	"moveEnd": "Flyt markør til slut"
 })
 
+//end v1.x content
+);
