@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	insertAnchor: "Indsæt anker",
 	title: "Ankeregenskaber",
@@ -7,3 +9,5 @@
 	cancel: "Annullér"
 })
 
+//end v1.x content
+);
