@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	smiley: "Indsæt humørikon",
 	emoticonSmile: "smil",
@@ -17,6 +19,9 @@
 	emoticonYes: "ja",
 	emoticonNo: "nej",
 	emoticonAngel: "engel",
-	emoticonCrying: "græder"
+	emoticonCrying: "græder",
+	emoticonHappy: "glad"
 })
 
+//end v1.x content
+);
