@@ -1,5 +1,9 @@
+define(
+//begin v1.x content
 ({
 	"collapse": "Editor-Symbolleiste ausblenden",
 	"expand": "Editor-Symbolleiste einblenden"
 })
 
+//end v1.x content
+);
