@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	insertAnchor: "Anker einfügen",
 	title: "Eigenschaften des Ankers",
@@ -7,3 +9,5 @@
 	cancel: "Abbrechen"
 })
 
+//end v1.x content
+);
