@@ -1,4 +1,8 @@
+define(
+//begin v1.x content
 ({
 	"showBlockNodes": "Εμφάνιση στοιχείων ενότητας HTML"
 })
 
+//end v1.x content
+);
