@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	smiley: "Εισαγωγή εικονιδίου συναισθήματος",
 	emoticonSmile: "Χαμόγελο",
@@ -17,6 +19,9 @@
 	emoticonYes: "Ναι",
 	emoticonNo: "Όχι",
 	emoticonAngel: "Αγγελούδι",
-	emoticonCrying: "Κλάμα"
+	emoticonCrying: "Κλάμα",
+	emoticonHappy: "Ευτυχία"
 })
 
+//end v1.x content
+);
