@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	insertTableTitle: "Insertar tabla",
 	modifyTableTitle: "Modificar tabla",
@@ -18,6 +20,7 @@
 	right: "derecha",
 	buttonSet: "Establecer", // translated elsewhere?
 	buttonInsert: "Insertar",
+	buttonCancel: "Cancelar",
 
 	selectTableLabel: "Seleccionar tabla",
 	insertTableRowBeforeLabel: "Añadir fila antes",
@@ -27,4 +30,7 @@
 	deleteTableRowLabel: "Suprimir fila",
 	deleteTableColumnLabel: "Suprimir columna"
 })
+	
 
+//end v1.x content
+);
