@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	"saveLabel": "Tallenna",
 	"saveSettingLabelOn": "Aseta automaattisen tallennuksen väli...",
@@ -12,3 +14,5 @@
 	"saveMessageFail": "Tallennus epäonnistui ${0}"
 })
 
+//end v1.x content
+);
