@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	insertTableTitle: "Lisää taulukko",
 	modifyTableTitle: "Muokkaa taulukkoa",
@@ -18,6 +20,7 @@
 	right: "oikea",
 	buttonSet: "Aseta", // translated elsewhere?
 	buttonInsert: "Lisää",
+	buttonCancel: "Peruuta",
 
 	selectTableLabel: "Valitse taulukko",
 	insertTableRowBeforeLabel: "Lisää rivi ennen",
@@ -27,3 +30,5 @@
 	deleteTableRowLabel: "Poista rivi",
 	deleteTableColumnLabel: "Poista sarake"
 })
+//end v1.x content
+);
