@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	insertImageTitle: "Insérer une image",
 	url: "Image",
@@ -9,3 +11,5 @@
 	prePopuTextBrowse: " ou sélectionnez un fichier local."
 })
 
+//end v1.x content
+);
