@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	smiley: "Insérer une émoticône",
 	emoticonSmile: "sourire",
@@ -17,6 +19,9 @@
 	emoticonYes: "oui",
 	emoticonNo: "non",
 	emoticonAngel: "ange",
-	emoticonCrying: "pleurs"
+	emoticonCrying: "pleurs",
+	emoticonHappy: "sourire"
 })
 
+//end v1.x content
+);
