@@ -1,5 +1,9 @@
+define(
+//begin v1.x content
 ({
 	"collapse": "כיווץ סרגל הכלים של העורך ",
 	"expand": "הרחבת סרגל הכלים של העורך"
 })
 
+//end v1.x content
+);
