@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	"nodeActions": "${nodeName} műveletek",
 	"selectContents": "Tartalom kiválasztása",
@@ -8,3 +10,5 @@
 	"moveEnd": "Kurzor mozgatása a végére"
 })
 
+//end v1.x content
+);
