@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	insertImageTitle: "Kép beszúrása",
 	url: "Kép",
@@ -9,3 +11,5 @@
 	prePopuTextBrowse: " vagy tallózással válasszon ki egy helyi fájlt."
 })
 
+//end v1.x content
+);
