@@ -1,15 +1,17 @@
+define(
+//begin v1.x content
 ({
 	insertTableTitle: "Táblázat beszúrása",
 	modifyTableTitle: "Táblázat módosítása",
-	rows: "Sorok: ",
-	columns: "Oszlopok: ",
-	align: "Igazítás: ",
-	cellPadding: "Cellakitöltés: ",
-	cellSpacing: "Cella térköz: ",
-	tableWidth: "Táblázat szélessége: ",
-	backgroundColor: "Háttérszín: ",
-	borderColor: "Szegélyszín: ",
-	borderThickness: "Szegély vastagsága ",
+	rows: "Sorok:",
+	columns: "Oszlopok:",
+	align: "Igazítás:",
+	cellPadding: "Cellakitöltés:",
+	cellSpacing: "Cella térköz:",
+	tableWidth: "Táblázat szélessége:",
+	backgroundColor: "Háttérszín:",
+	borderColor: "Szegélyszín:",
+	borderThickness: "Szegély vastagsága",
 	percent: "százalék",
 	pixels: "képpont",
 	"default": "alapértelmezett",
@@ -18,13 +20,15 @@
 	right: "jobbra",
 	buttonSet: "Beállítás", // translated elsewhere?
 	buttonInsert: "Beszúrás",
+	buttonCancel: "Mégse",
 
 	selectTableLabel: "Táblázat kijelölése",
 	insertTableRowBeforeLabel: "Sor hozzáadása előtte",
 	insertTableRowAfterLabel: "Sor hozzáadása utána",
 	insertTableColumnBeforeLabel: "Oszlop hozzáadása előtte",
 	insertTableColumnAfterLabel: "Oszlop hozzáadása utána",
-	deleteTableRowLabel: "Sor törlése ",
+	deleteTableRowLabel: "Sor törlése",
 	deleteTableColumnLabel: "Oszlop törlése"
 })
-
+//end v1.x content
+);
