@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	insertAnchor: "アンカーの挿入",
 	title: "アンカー・プロパティー",
@@ -6,3 +8,5 @@
 	set: "設定",
 	cancel: "キャンセル"
 })
+//end v1.x content
+);
