@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	widgetLabel: "一括スペル・チェック",
 	unfound: "見つかりません",
@@ -14,3 +16,5 @@
 	iSkipAll: "これと類似のものをスキップ",
 	iMsg: "スペルの修正候補はありません"
 })
+//end v1.x content
+);
