@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	"pasteFromWord": "단어에서 붙여넣기",
 	"paste": "붙여넣기",
@@ -5,3 +7,5 @@
 	"instructions": "단어에서 아래 텍스트 상자로 컨텐츠를 붙여 넣으십시오. 삽입할 컨텐츠가 준비되면 붙여넣기 단추를 누르십시오. 텍스트 삽입을 중단하려면 취소 단추를 누르십시오. "
 })
 
+//end v1.x content
+);
