@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	"findLabel": "Søk:",
 	"findTooltip": "Skriv inn teksten du vil søke etter",
@@ -8,7 +10,6 @@
 	"matchCaseTooltip": "Skill mellom store og små bokstaver",
 	"backwards": "Bakover",
 	"backwardsTooltip": "Søk bakover etter tekst",
-	"replaceAll": "Alle forekomster",
 	"replaceAllButton": "Erstatt alle",
 	"replaceAllButtonTooltip": "Erstatt all tekst",
 	"findButton": "Søk",
@@ -20,3 +21,5 @@
 	"eofDialogTextFind": "funnet",
 	"eofDialogTextReplace": "erstattet"
 })
+//end v1.x content
+);
