@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	insertTableTitle: "Sett inn tabell",
 	modifyTableTitle: "Endre tabell",
@@ -18,6 +20,7 @@
 	right: "høyre",
 	buttonSet: "Definer", // translated elsewhere?
 	buttonInsert: "Sett inn",
+	buttonCancel: "Avbryt",
 
 	selectTableLabel: "Velg tabell",
 	insertTableRowBeforeLabel: "Legg til rad foran",
@@ -27,3 +30,5 @@
 	deleteTableRowLabel: "Slett rad",
 	deleteTableColumnLabel: "Slett kolonne"
 })
+//end v1.x content
+);
