@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	"saveLabel": "Opslaan",
 	"saveSettingLabelOn": "Interval voor automatisch opslaan instellen...",
@@ -12,3 +14,5 @@
 	"saveMessageFail": "Opslaan mislukt op ${0}"
 })
 
+//end v1.x content
+);
