@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	insertImageTitle: "Afbeelding invoegen",
 	url: "Afbeelding",
@@ -9,3 +11,5 @@
 	prePopuTextBrowse: " of navigeer naar een lokaal bestand."
 })
 
+//end v1.x content
+);
