@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	"pasteFromWord": "Plakken vanuit Word",
 	"paste": "Plakken",
@@ -5,3 +7,5 @@
 	"instructions": "Plak de content vanuit Word in het tekstvak hieronder. Klik als u klaar bent op de knop Plakken. Kies Annuleren als u de invoeging van tekst wilt afbreken."
 })
 
+//end v1.x content
+);
