@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	"findLabel": "Znajdź:",
 	"findTooltip": "Wprowadź szukany tekst",
@@ -8,7 +10,6 @@
 	"matchCaseTooltip": "Uwzględnij wielkość liter",
 	"backwards": "Do tyłu",
 	"backwardsTooltip": "Wyszukaj tekst wstecz",
-	"replaceAll": "Wszystkie wystąpienia",
 	"replaceAllButton": "Zastąp wszystkie",
 	"replaceAllButtonTooltip": "Zastąp cały tekst",
 	"findButton": "Znajdź",
@@ -21,3 +22,5 @@
 	"eofDialogTextReplace": "zastąpiono"
 })
 
+//end v1.x content
+);
