@@ -1,22 +1,27 @@
+define(
+//begin v1.x content
 ({
 	smiley: "Wstaw emotikon",
 	emoticonSmile: "uśmiech",
 	emoticonLaughing: "śmiech",
 	emoticonWink: "mrugnięcie",
 	emoticonGrin: "szeroki uśmiech",
-	emoticonCool: "na luzie",
-	emoticonAngry: "złość",  
-	emoticonHalf: "niesmak", 
-	emoticonEyebrow: "brew",
+	emoticonCool: "cwaniak",
+	emoticonAngry: "złość",
+	emoticonHalf: "niesmak",
+	emoticonEyebrow: "uniesienie brwi",
 	emoticonFrown: "niezadowolenie",
 	emoticonShy: "nieśmiałość",
 	emoticonGoofy: "niezdarność",
-	emoticonOops: "oj",
-	emoticonTongue: "język",
+	emoticonOops: "ups",
+	emoticonTongue: "pokazywanie języka",
 	emoticonIdea: "pomysł",
 	emoticonYes: "Tak",
-	emoticonNo: "Nie",	
+	emoticonNo: "Nie",
 	emoticonAngel: "anioł",
-	emoticonCrying: "płacz"
+	emoticonCrying: "płacz",
+	emoticonHappy: "radość"
 })
 
+//end v1.x content
+);
