@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	insertTableTitle: "Inserir tabela",
 	modifyTableTitle: "Modificar tabela",
@@ -28,3 +30,5 @@
 	deleteTableRowLabel: "Eliminar linha",
 	deleteTableColumnLabel: "Eliminar coluna"
 })
+//end v1.x content
+);
