@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	"nodeActions": "${nodeName} Ações",
 	"selectContents": "Selecionar Conteúdo",
@@ -8,3 +10,5 @@
 	"moveEnd": "Mover Cursor para o Final"
 })
 
+//end v1.x content
+);
