@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	smiley: "Inserir Emoticon",
 	emoticonSmile: "sorriso",
@@ -17,5 +19,8 @@
 	emoticonYes: "sim",
 	emoticonNo: "não",
 	emoticonAngel: "angelical",
-	emoticonCrying: "chorando"
+	emoticonCrying: "chorando",
+	emoticonHappy: "feliz"
 })
+//end v1.x content
+);
