@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	insertTableTitle: "Inserir Tabela",
 	modifyTableTitle: "Modificar Tabela",
@@ -18,6 +20,7 @@
 	right: "direita",
 	buttonSet: "Configurar", // translated elsewhere?
 	buttonInsert: "Inserir",
+	buttonCancel: "Cancelar",
 
 	selectTableLabel: "Selecionar Tabela",
 	insertTableRowBeforeLabel: "Incluir Linha Antes",
@@ -27,4 +30,6 @@
 	deleteTableRowLabel: "Excluir Linha",
 	deleteTableColumnLabel: "Excluir Coluna"
 })
-
+	
+//end v1.x content
+);
