@@ -1,18 +1,20 @@
+define(
+//begin v1.x content
 ({
 	"findLabel": "Găsire:",
-	"findTooltip": "Introduceţi textul de găsit ",
-	"replaceLabel": "Înlocuire cu: ",
+	"findTooltip": "Introduceţi textul de găsit",
+	"replaceLabel": "Înlocuire cu:",
 	"replaceTooltip": "Introduceţi textul cu care se înlocuieşte",
 	"findReplace": "Găsire şi înlocuire",
-	"matchCase": "Potrivire majuscule ",
-	"matchCaseTooltip": "Potrivire majuscule ",
+	"matchCase": "Potrivire majuscule",
+	"matchCaseTooltip": "Potrivire majuscule",
 	"backwards": "Înapoi",
 	"backwardsTooltip": "Căutaţi înapoi pentru text",
-	"replaceAllButton": "Înlocuire toate ",
+	"replaceAllButton": "Înlocuire toate",
 	"replaceAllButtonTooltip": "Înlocuiţi tot textul",
 	"findButton": "Găsire",
 	"findButtonTooltip": "Găsiţi textul",
-	"replaceButton": "Înlocuire ",
+	"replaceButton": "Înlocuire",
 	"replaceButtonTooltip": "Înlocuiţi textul",
 	"replaceDialogText": "Au fost înlocuite ${0} apariţii.",
 	"eofDialogText": "Ultima apariţie ${0}",
@@ -20,3 +22,5 @@
 	"eofDialogTextReplace": "înlocuită"
 })
 
+//end v1.x content
+);
