@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	insertAnchor: "Вставить метку",
 	title: "Свойства метки",
@@ -7,3 +9,5 @@
 	cancel: "Отменить"
 })
 
+//end v1.x content
+);
