@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	"pasteFromWord": "Вставить из Word",
 	"paste": "Вставить",
@@ -5,3 +7,5 @@
 	"instructions": "Вставить содержимое из Word в текстовое поле ниже.  Когда выберите содержимое для вставки, нажмите кнопку Вставить.  Для отмены вставки текста нажмите кнопку Отмена."
 })
 
+//end v1.x content
+);
