@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	insertTableTitle: "Вставить таблицу",
 	modifyTableTitle: "Изменить таблицу",
@@ -18,6 +20,7 @@
 	right: "по правому краю",
 	buttonSet: "Задать", // translated elsewhere?
 	buttonInsert: "Вставить",
+	buttonCancel: "Отмена",
 
 	selectTableLabel: "Выбрать таблицу",
 	insertTableRowBeforeLabel: "Добавить строку перед",
@@ -27,4 +30,5 @@
 	deleteTableRowLabel: "Удалить строку",
 	deleteTableColumnLabel: "Удалить столбец"
 })
-
+//end v1.x content
+);
