@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	insertAnchor: "Vložiť kotvu",
 	title: "Vlastnosti kotvy",
@@ -7,3 +9,5 @@
 	cancel: "Zrušiť"
 })
 
+//end v1.x content
+);
