@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	insertImageTitle: "Vložiť obrázok",
 	url: "Obrázok",
@@ -9,3 +11,5 @@
 	prePopuTextBrowse: "alebo nájdite lokálny súbor."
 })
 
+//end v1.x content
+);
