@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	insertAnchor: "Vstavi sidro",
 	title: "Lastnosti sidra",
@@ -7,3 +9,5 @@
 	cancel: "Prekliči"
 })
 
+//end v1.x content
+);
