@@ -1,10 +1,12 @@
+define(
+//begin v1.x content
 ({
 	insertTableTitle: "Vstavi tabelo",
 	modifyTableTitle: "Spremeni tabelo",
 	rows: "Vrstice:",
 	columns: "Stolpci:",
 	align: "Poravnaj:",
-	cellPadding: "Odmik celic:",
+	cellPadding: "Polnjenje celic:",
 	cellSpacing: "Razmik med celicami:",
 	tableWidth: "Širina tabele:",
 	backgroundColor: "Barva ozadja:",
@@ -18,6 +20,7 @@
 	right: "desno",
 	buttonSet: "Nastavi", // translated elsewhere?
 	buttonInsert: "Vstavi",
+	buttonCancel: "Prekliči",
 
 	selectTableLabel: "Izberi tabelo",
 	insertTableRowBeforeLabel: "Dodaj vrstico pred",
@@ -27,4 +30,7 @@
 	deleteTableRowLabel: "Izbriši vrstico",
 	deleteTableColumnLabel: "Izbriši stolpec"
 })
+	
 
+//end v1.x content
+);
