@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	"findLabel": "Sök:",
 	"findTooltip": "Ange den text du vill söka efter",
@@ -8,7 +10,6 @@
 	"matchCaseTooltip": "Matcha skiftläge",
 	"backwards": "Bakåt",
 	"backwardsTooltip": "Sök bakåt efter text",
-	"replaceAll": "Alla förekomster",
 	"replaceAllButton": "Ersätt alla",
 	"replaceAllButtonTooltip": "Ersätt all text",
 	"findButton": "Sök",
@@ -21,3 +22,5 @@
 	"eofDialogTextReplace": "ersattes"
 })
 
+//end v1.x content
+);
