@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	widgetLabel: "Kontrollera stavning",
 	unfound: "Hittades inte",
@@ -15,3 +17,5 @@
 	iMsg: "Inga stavningsförslag"
 })
 
+//end v1.x content
+);
