@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	insertTableTitle: "Infoga tabell",
 	modifyTableTitle: "Ändra tabell",
@@ -18,6 +20,7 @@
 	right: "högerjustera",
 	buttonSet: "Ange", // translated elsewhere?
 	buttonInsert: "Infoga",
+	buttonCancel: "Avbryt",
 
 	selectTableLabel: "Välj tabell",
 	insertTableRowBeforeLabel: "Lägg till rad före",
@@ -27,3 +30,5 @@
 	deleteTableRowLabel: "Ta bort rad",
 	deleteTableColumnLabel: "Ta bort kolumn"
 })
+//end v1.x content
+);
