@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	"saveLabel": "บันทึก",
 	"saveSettingLabelOn": "ตั้งช่วงเวลาบันทึกอัตโนมัติ...",
@@ -12,3 +14,5 @@
 	"saveMessageFail": "ล้มเหลวในการบันทึกเมื่อ ${0}"
 })
 
+//end v1.x content
+);
