@@ -1,6 +1,8 @@
+define(
+//begin v1.x content
 ({
 	insertTableTitle: "แทรกตาราง",
-	modifyTableTitle: "ปรับเปลี่ยนตาราง",
+	modifyTableTitle: "ปรับเปลี่ยนไขตาราง",
 	rows: "แถว:",
 	columns: "คอลัมน์:",
 	align: "จัดตำแหน่ง:",
@@ -18,6 +20,7 @@
 	right: "ขวา",
 	buttonSet: "ตั้งค่า", // translated elsewhere?
 	buttonInsert: "แทรก",
+	buttonCancel: "ยกเลิก",
 
 	selectTableLabel: "เลือกตาราง",
 	insertTableRowBeforeLabel: "เพิ่มแถวก่อน",
@@ -27,4 +30,5 @@
 	deleteTableRowLabel: "ลบแถว",
 	deleteTableColumnLabel: "ลบคอลัมน์"
 })
-
+//end v1.x content
+);
