@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	/* These are already handled in the default RTE
 		amp:"ampersand",lt:"less-than sign",
@@ -255,3 +257,5 @@
 	euro:"เครื่องหมายยูโร"
 })
 
+//end v1.x content
+);
