@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	"nodeActions": "${nodeName} Eylemleri",
 	"selectContents": "İçindekileri seç",
@@ -8,3 +10,5 @@
 	"moveEnd": "İmleci sona taşı"
 })
 
+//end v1.x content
+);
