@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	smiley: "İfade Ekle",
 	emoticonSmile: "gülümseme",
@@ -17,6 +19,9 @@
 	emoticonYes: "evet",
 	emoticonNo: "hayır",
 	emoticonAngel: "melek",
-	emoticonCrying: "ağlayan ifade"
+	emoticonCrying: "ağlayan ifade",
+	emoticonHappy: "mutlu ifade"
 })
 
+//end v1.x content
+);
