@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	insertTableTitle: "Tablo Ekle",
 	modifyTableTitle: "Tabloyu Değiştir",
@@ -8,7 +10,7 @@
 	cellSpacing: "Hücre Aralığı:",
 	tableWidth: "Tablo Genişliği",
 	backgroundColor: "Arka Plan Rengi:",
-	borderColor: "Kenarlık Rengi: ",
+	borderColor: "Kenarlık Rengi:",
 	borderThickness: "Kenarlık Kalınlığı",
 	percent: "yüzde",
 	pixels: "piksel",
@@ -18,6 +20,7 @@
 	right: "sağ",
 	buttonSet: "Ayarla", // translated elsewhere?
 	buttonInsert: "Ekle",
+	buttonCancel: "İptal",
 
 	selectTableLabel: "Tablo Seç",
 	insertTableRowBeforeLabel: "Satırı Önüne Ekle",
@@ -27,3 +30,5 @@
 	deleteTableRowLabel: "Satırı Sil",
 	deleteTableColumnLabel: "Sütunu Sil"
 })
+//end v1.x content
+);
