@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	"findLabel": "查找：",
 	"findTooltip": "输入要查找的文本",
@@ -8,7 +10,6 @@
 	"matchCaseTooltip": "匹配大小写",
 	"backwards": "向后",
 	"backwardsTooltip": "向后搜索文本",
-	"replaceAll": "所有匹配项",
 	"replaceAllButton": "全部替换",
 	"replaceAllButtonTooltip": "替换所有文本",
 	"findButton": "查找",
@@ -20,3 +21,5 @@
 	"eofDialogTextFind": "已找到",
 	"eofDialogTextReplace": "已替换"
 })
+//end v1.x content
+);
