@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	insertAnchor: "插入锚点",
 	title: "锚点属性",
@@ -6,3 +8,5 @@
 	set: "设置",
 	cancel: "取消"
 })
+//end v1.x content
+);
