@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	smiley: "插入表情图标",
 	emoticonSmile: "微笑",
@@ -5,8 +7,8 @@
 	emoticonWink: "眨眼",
 	emoticonGrin: "咧着嘴笑",
 	emoticonCool: "酷",
-	emoticonAngry: "愤怒",  
-	emoticonHalf: "左右为难", 
+	emoticonAngry: "愤怒",
+	emoticonHalf: "左右为难",
 	emoticonEyebrow: "挑眉",
 	emoticonFrown: "皱眉",
 	emoticonShy: "害羞",
@@ -15,8 +17,11 @@
 	emoticonTongue: "吐舌",
 	emoticonIdea: "思考",
 	emoticonYes: "点头",
-	emoticonNo: "摇头",	
+	emoticonNo: "摇头",
 	emoticonAngel: "天使",
-	emoticonCrying: "哭泣"
+	emoticonCrying: "哭泣",
+	emoticonHappy: "高兴"
 })
 
+//end v1.x content
+);
