@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	insertTableTitle: "插入表",
 	modifyTableTitle: "修改表",
@@ -18,6 +20,7 @@
 	right: "右边对齐",
 	buttonSet: "设置", // translated elsewhere?
 	buttonInsert: "插入",
+	buttonCancel: "取消",
 
 	selectTableLabel: "选择表",
 	insertTableRowBeforeLabel: "在之前添加行",
@@ -28,3 +31,5 @@
 	deleteTableColumnLabel: "删除列"
 })
 
+//end v1.x content
+);
