@@ -1,5 +1,9 @@
+define(
+//begin v1.x content
 ({
         nomatchMessage: "A jelszavak nem egyeznek.",
 		badPasswordMessage: "Érvénytelen jelszó."
 })
 
+//end v1.x content
+);
\ No newline at end of file
