@@ -1,5 +1,9 @@
+define(
+//begin v1.x content
 ({
         nomatchMessage: "Le password non corrispondono.",
 		badPasswordMessage: "Password non valida."
 })
 
+//end v1.x content
+);
\ No newline at end of file
