@@ -1,5 +1,9 @@
+define(
+//begin v1.x content
 ({
         nomatchMessage: "Пароли не совпадают.",
 		badPasswordMessage: "Неправильный пароль."
 })
 
+//end v1.x content
+);
\ No newline at end of file
