@@ -1,5 +1,9 @@
+define(
+//begin v1.x content
 ({
         nomatchMessage: "Parolalar eşleşmiyor.",
 		badPasswordMessage: "Geçersiz Parola."
 })
 
+//end v1.x content
+);
\ No newline at end of file
