@@ -1,9 +1,8 @@
-dojo.provide("dojox.fx.split");
-
-dojo.require("dojo.fx");
-dojo.require("dojo.fx.easing");
-
-dojo.mixin(dojox.fx,{
+define(["dojo/_base/lang", "dojo/dom", "dojo/_base/window", "dojo/_base/html", "dojo/dom-geometry", 
+		"dojo/dom-construct", "dojo/dom-attr", "dojo/_base/fx", "dojo/fx", "./_base", "dojo/fx/easing", "dojo/_base/connect"],
+	function(lang, dom, winUtil, htmlUtil, domGeom, domConstruct, domAttr, baseFx, coreFx, fxExt, easingUtil, connectUtil){
+var dojoxFx = lang.getObject("dojox.fx");
+lang.mixin(dojoxFx,{
 	_split: function(/*Object*/ args){
 		// summary: Split a node into rectangular pieces and animate them.
 		//
@@ -23,26 +22,26 @@ dojo.mixin(dojox.fx,{
 		args.columns = args.columns || 3;
 		args.duration = args.duration || 1000;
 
-		var node = args.node = dojo.byId(args.node),
+		var node = args.node = dom.byId(args.node),
 			parentNode = node.parentNode,
 			pNode = parentNode,
-			body = dojo.body(),
+			body = winUtil.body(),
 			_pos = "position"
 		;
 
-		while(pNode && pNode != body && dojo.style(pNode, _pos) == "static"){
+		while(pNode && pNode != body && htmlUtil.style(pNode, _pos) == "static"){
 			pNode = pNode.parentNode;
 		}
 
-		var pCoords = pNode != body ? dojo.position(pNode, true) : { x: 0, y: 0 },
-			coords = dojo.position(node, true),
-			nodeHeight = dojo.style(node, "height"),
-			nodeWidth = dojo.style(node, "width"),
-			hBorder = dojo.style(node, "borderLeftWidth") + dojo.style(node, "borderRightWidth"),
-			vBorder = dojo.style(node, "borderTopWidth") + dojo.style(node, "borderBottomWidth"),
+		var pCoords = pNode != body ? domGeom.position(pNode, true) : { x: 0, y: 0 },
+			coords = domGeom.position(node, true),
+			nodeHeight = htmlUtil.style(node, "height"),
+			nodeWidth = htmlUtil.style(node, "width"),
+			hBorder = htmlUtil.style(node, "borderLeftWidth") + htmlUtil.style(node, "borderRightWidth"),
+			vBorder = htmlUtil.style(node, "borderTopWidth") + htmlUtil.style(node, "borderBottomWidth"),
 			pieceHeight = Math.ceil(nodeHeight / args.rows),
 			pieceWidth = Math.ceil(nodeWidth / args.columns),
-			container = dojo.create(node.tagName, {
+			container = domConstruct.create(node.tagName, {
 				style: {
 					position: "absolute",
 					padding: 0,
@@ -54,11 +53,11 @@ dojo.mixin(dojox.fx,{
 					width: nodeWidth + hBorder + "px",
 					background: "none",
 					overflow: args.crop ? "hidden" : "visible",
-					zIndex: dojo.style(node, "zIndex")
+					zIndex: htmlUtil.style(node, "zIndex")
 				}
 			}, node, "after"),
 			animations = [],
-			pieceHelper = dojo.create(node.tagName, {
+			pieceHelper = domConstruct.create(node.tagName, {
 				style: {
 					position: "absolute",
 					border: "none",
@@ -74,8 +73,8 @@ dojo.mixin(dojox.fx,{
 		for(var y = 0, ly = args.rows; y < ly; y++){
 			for(var x = 0, lx = args.columns; x < lx; x++){
 				// Create the piece
-				var piece = dojo.clone(pieceHelper),
-					pieceContents = dojo.clone(node),
+				var piece = lang.clone(pieceHelper),
+					pieceContents = lang.clone(node),
 					pTop = y * pieceHeight,
 					pLeft = x * pieceWidth
 				;
@@ -84,15 +83,15 @@ dojo.mixin(dojox.fx,{
 				pieceContents.style.filter = "";
 
 				// removing the id attribute from the cloned nodes
-				dojo.removeAttr(pieceContents, "id");
+				domAttr.remove(pieceContents, "id");
 
-				dojo.style(piece, {
+				htmlUtil.style(piece, {
 					border: "none",
 					overflow: "hidden",
 					top: pTop + "px",
 					left: pLeft + "px"
 				});
-				dojo.style(pieceContents, {
+				htmlUtil.style(pieceContents, {
 					position: "static",
 					opacity: "1",
 					marginTop: -pTop + "px",
@@ -102,7 +101,7 @@ dojo.mixin(dojox.fx,{
 				container.appendChild(piece);
 
 				var pieceAnimation = args.pieceAnimation(piece, x, y, coords);
-				if(dojo.isArray(pieceAnimation)){
+				if(lang.isArray(pieceAnimation)){
 					// if pieceAnimation is an array, append its elements
 					animations = animations.concat(pieceAnimation);
 				}else{
@@ -111,15 +110,15 @@ dojo.mixin(dojox.fx,{
 				}
 			}
 		}
-		var anim = dojo.fx.combine(animations);
-		dojo.connect(anim, "onEnd", anim, function(){
+		var anim = coreFx.combine(animations);
+		connectUtil.connect(anim, "onEnd", anim, function(){
 			container.parentNode.removeChild(container);
 		});
 		if(args.onPlay){
-			dojo.connect(anim, "onPlay", anim, args.onPlay);
+			connectUtil.connect(anim, "onPlay", anim, args.onPlay);
 		}
 		if(args.onEnd){
-			dojo.connect(anim, "onEnd", anim, args.onEnd);
+			connectUtil.connect(anim, "onEnd", anim, args.onEnd);
 		}
 		return anim; // dojo.Animation
 	},
@@ -144,7 +143,7 @@ dojo.mixin(dojox.fx,{
 		//		args.sync: Boolean - If args.unhide is true, all the pieces converge at the same time
 		//							 (default is true)
 
-		var node = args.node = dojo.byId(args.node);
+		var node = args.node = dom.byId(args.node);
 		args.rows = args.rows || 3;
 		args.columns = args.columns || 3;
 		args.distance = args.distance || 1;
@@ -191,14 +190,14 @@ dojo.mixin(dojox.fx,{
 
 			// Create the animation objects for the piece
 			// These are separate anim objects so they can have different curves
-			var pieceSlide = dojo.animateProperty({
+			var pieceSlide = baseFx.animateProperty({
 				node: piece,
 				duration: duration,
 				delay: delay,
-				easing: (args.easing || (args.unhide ? dojo.fx.easing.sinOut : dojo.fx.easing.circOut)),
+				easing: (args.easing || (args.unhide ? easingUtil.sinOut : easingUtil.circOut)),
 				beforeBegin: (args.unhide ? function(){
 						if(args.fade){
-							dojo.style(piece, { opacity: "0"});
+							htmlUtil.style(piece, { opacity: "0"});
 						}
 						ps.top = endTop + "px";
 						ps.left = endLeft + "px";
@@ -209,11 +208,11 @@ dojo.mixin(dojox.fx,{
 				}
 			});
 			if(args.fade){
-				var pieceFade = dojo.animateProperty({
+				var pieceFade = baseFx.animateProperty({
 					node: piece,
 					duration: duration,
 					delay: delay,
-					easing: (args.fadeEasing || dojo.fx.easing.quadOut),
+					easing: (args.fadeEasing || easingUtil.quadOut),
 					properties: {
 						opacity: (args.unhide ? { start: "0", end: "1" } : { start: "1", end: "0" })
 					}
@@ -227,14 +226,14 @@ dojo.mixin(dojox.fx,{
 			}
 		};
 
-		var anim = dojox.fx._split(args);
+		var anim = dojoxFx._split(args);
 		if(args.unhide){
-			dojo.connect(anim, "onEnd", null, function(){
-				dojo.style(node, {opacity: "1" });
+			connectUtil.connect(anim, "onEnd", null, function(){
+				htmlUtil.style(node, {opacity: "1" });
 			});
 		}else{
-			dojo.connect(anim, "onPlay", null, function(){
-				dojo.style(node, { opacity: "0" });
+			connectUtil.connect(anim, "onPlay", null, function(){
+				htmlUtil.style(node, { opacity: "0" });
 			});
 		}
 		return anim; // dojo.Animation
@@ -242,7 +241,7 @@ dojo.mixin(dojox.fx,{
 
 	converge: function(/*Object*/ args){
 		args.unhide = true;
-		return dojox.fx.explode(args);
+		return dojoxFx.explode(args);
 	},
 
 	disintegrate: function(/*Object*/ args){
@@ -262,7 +261,7 @@ dojo.mixin(dojox.fx,{
 		//							   randomness is introduced.
 		//		args.reverseOrder: Boolean - If true, pieces animate in reversed order
 		//		args.unhide: Boolean - If true, the peices fall from above and land in place
-		var node = args.node = dojo.byId(args.node);
+		var node = args.node = dom.byId(args.node);
 
 		args.rows = args.rows || 5;
 		args.columns = args.columns || 5;
@@ -305,15 +304,15 @@ dojo.mixin(dojox.fx,{
 					properties.opacity = {end: "0"};
 				}
 			}
-			var pieceAnimation = dojo.animateProperty({
+			var pieceAnimation = baseFx.animateProperty({
 				node: piece,
 				duration: duration,
 				delay: delay,
-				easing: (args.easing || (args.unhide ? dojo.fx.easing.sinIn : dojo.fx.easing.circIn)),
+				easing: (args.easing || (args.unhide ? easingUtil.sinIn : easingUtil.circIn)),
 				properties: properties,
 				beforeBegin: (args.unhide ? function(){
 					if(args.fade){
-						dojo.style(piece, { opacity: "0" });
+						htmlUtil.style(piece, { opacity: "0" });
 					}
 					ps.top = properties.top.start + "px";
 				} : undefined)
@@ -322,14 +321,14 @@ dojo.mixin(dojox.fx,{
 			return pieceAnimation;
 		};
 
-		var anim = dojox.fx._split(args);
+		var anim = dojoxFx._split(args);
 		if(args.unhide){
-			dojo.connect(anim, "onEnd", anim, function(){
-				dojo.style(node, { opacity: "1" });
+			connectUtil.connect(anim, "onEnd", anim, function(){
+				htmlUtil.style(node, { opacity: "1" });
 			});
 		}else{
-			dojo.connect(anim, "onPlay", anim, function(){
-				dojo.style(node, { opacity: "0" });
+			connectUtil.connect(anim, "onPlay", anim, function(){
+				htmlUtil.style(node, { opacity: "0" });
 			});
 		}
 		return anim; // dojo.Animation
@@ -337,7 +336,7 @@ dojo.mixin(dojox.fx,{
 
 	build: function(/*Object*/ args){
 		args.unhide = true;
-		return dojox.fx.disintegrate(args);
+		return dojoxFx.disintegrate(args);
 	},
 
 	shear: function(/*Object*/ args){
@@ -358,7 +357,7 @@ dojo.mixin(dojox.fx,{
 		//		args.reverseOrder: Boolean - If true, pieces animate in reversed order
 		//		args.unhide: Boolean - If true, the animation is reversed
 
-		var node = args.node = dojo.byId(args.node);
+		var node = args.node = dom.byId(args.node);
 
 		args.rows = args.rows || 6;
 		args.columns = args.columns || 6;
@@ -420,11 +419,11 @@ dojo.mixin(dojox.fx,{
 			}
 
 			// Create the animation object for the piece
-			var pieceAnimation = dojo.animateProperty({
+			var pieceAnimation = baseFx.animateProperty({
 				node: piece,
 				duration: duration,
 				delay: delay,
-				easing: (args.easing || dojo.fx.easing.sinInOut),
+				easing: (args.easing || easingUtil.sinInOut),
 				properties: properties,
 				beforeBegin: (args.unhide ? function(){
 					if(args.fade){
@@ -441,14 +440,14 @@ dojo.mixin(dojox.fx,{
 			return pieceAnimation;
 		};
 
-		var anim = dojox.fx._split(args);
+		var anim = dojoxFx._split(args);
 		if(args.unhide){
-			dojo.connect(anim, "onEnd", anim, function(){
-				dojo.style(node, { opacity: "1" });
+			connectUtil.connect(anim, "onEnd", anim, function(){
+				htmlUtil.style(node, { opacity: "1" });
 			});
 		}else{
-			dojo.connect(anim, "onPlay", anim, function(){
-				dojo.style(node, { opacity: "0" });
+			connectUtil.connect(anim, "onPlay", anim, function(){
+				htmlUtil.style(node, { opacity: "0" });
 			});
 		}
 		return anim; // dojo.Animation
@@ -456,7 +455,7 @@ dojo.mixin(dojox.fx,{
 
 	unShear: function(/*Object*/ args){
 		args.unhide = true;
-		return dojox.fx.shear(args);
+		return dojoxFx.shear(args);
 	},
 
 	pinwheel: function(/*Object*/ args){
@@ -476,7 +475,7 @@ dojo.mixin(dojox.fx,{
 		//							   randomness is introduced.
 		//		args.unhide: Boolean - If true, the animation is reversed
 
-		var node = args.node = dojo.byId(args.node);
+		var node = args.node = dom.byId(args.node);
 
 		args.rows = args.rows || 4;
 		args.columns = args.columns || 4;
@@ -544,15 +543,15 @@ dojo.mixin(dojox.fx,{
 			}
 
 			// Create the animation object for the piece
-			var pieceAnimation = dojo.animateProperty({
+			var pieceAnimation = baseFx.animateProperty({
 				node: piece,
 				duration: duration,
 				delay: delay,
-				easing: (args.easing || dojo.fx.easing.sinInOut),
+				easing: (args.easing || easingUtil.sinInOut),
 				properties: properties,
 				beforeBegin: (args.unhide ? function(){
 					if(args.fade){
-						dojo.style(piece, "opacity", 0);
+						htmlUtil.style(piece, "opacity", 0);
 					}
 					if(colIsOdd){
 						if(rowIsOdd){
@@ -575,14 +574,14 @@ dojo.mixin(dojox.fx,{
 			return pieceAnimation;
 		};
 
-		var anim = dojox.fx._split(args);
+		var anim = dojoxFx._split(args);
 		if(args.unhide){
-			dojo.connect(anim, "onEnd", anim, function(){
-				dojo.style(node, { opacity: "1" });
+			connectUtil.connect(anim, "onEnd", anim, function(){
+				htmlUtil.style(node, { opacity: "1" });
 			});
 		}else{
-			dojo.connect(anim, "play", anim, function(){
-				dojo.style(node, { opacity: "0" });
+			connectUtil.connect(anim, "play", anim, function(){
+				htmlUtil.style(node, { opacity: "0" });
 			});
 		}
 		return anim; // dojo.Animation
@@ -590,7 +589,7 @@ dojo.mixin(dojox.fx,{
 
 	unPinwheel: function(/*Object*/ args){
 		args.unhide = true;
-		return dojox.fx.pinwheel(args); // dojo.Animation
+		return dojoxFx.pinwheel(args); // dojo.Animation
 	},
 
 	blockFadeOut: function(/*Object*/ args){
@@ -609,7 +608,7 @@ dojo.mixin(dojox.fx,{
 		//		args.reverseOrder: Boolean - If true, pieces animate in reversed order
 		//		args.unhide: Boolean - If true, the animation is reversed
 
-		var node = args.node = dojo.byId(args.node);
+		var node = args.node = dom.byId(args.node);
 
 		args.rows = args.rows || 5;
 		args.columns = args.columns || 5;
@@ -628,27 +627,27 @@ dojo.mixin(dojox.fx,{
 					((x + y) * args.interval),
 				delay = randomDelay * random + Math.max(1 - random, 0) * uniformDelay,
 			// Create the animation object for the piece
-				pieceAnimation = dojo.animateProperty({
+				pieceAnimation = baseFx.animateProperty({
 					node: piece,
 					duration: duration,
 					delay: delay,
-					easing: (args.easing || dojo.fx.easing.sinInOut),
+					easing: (args.easing || easingUtil.sinInOut),
 					properties: {
 						opacity: (args.unhide ? {start: "0", end: "1"} : {start: "1", end: "0"})
 					},
-					beforeBegin: (args.unhide ? function(){ dojo.style(piece, { opacity: "0" });} : function(){ piece.style.filter = ""; })
+					beforeBegin: (args.unhide ? function(){ htmlUtil.style(piece, { opacity: "0" });} : function(){ piece.style.filter = ""; })
 				});
 
 			return pieceAnimation;
 		};
-		var anim = dojox.fx._split(args);
+		var anim = dojoxFx._split(args);
 		if(args.unhide){
-			dojo.connect(anim, "onEnd", anim, function(){
-				dojo.style(node, { opacity: "1" });
+			connectUtil.connect(anim, "onEnd", anim, function(){
+				htmlUtil.style(node, { opacity: "1" });
 			});
 		}else{
-			dojo.connect(anim, "onPlay", anim, function(){
-				dojo.style(node, { opacity: "0" });
+			connectUtil.connect(anim, "onPlay", anim, function(){
+				htmlUtil.style(node, { opacity: "0" });
 			});
 		}
 		return anim; // dojo.Animation
@@ -656,7 +655,8 @@ dojo.mixin(dojox.fx,{
 
 	blockFadeIn: function(/*Object*/ args){
 		args.unhide = true;
-		return dojox.fx.blockFadeOut(args); // dojo.Animation
+		return dojoxFx.blockFadeOut(args); // dojo.Animation
 	}
-
+});
+return fxExt;
 });
\ No newline at end of file
