@@ -1,30 +1,38 @@
-dojo.provide("dojox.gfx.utils");
+define(["dojo/_base/kernel","dojo/_base/lang","./_base", "dojo/_base/html","dojo/_base/array", "dojo/_base/window", "dojo/_base/json", 
+	"dojo/_base/Deferred", "dojo/_base/sniff", "require","dojo/_base/config"], 
+  function(kernel, lang, g, html, arr, win, jsonLib, Deferred, has, require, config){
+	var gu = g.utils = {};
+	/*===== g= dojox.gfx; gu = dojox.gfx.utils; =====*/
 
-dojo.require("dojox.gfx");
-
-(function(){
-	var d = dojo, g = dojox.gfx, gu = g.utils;
-
-	dojo.mixin(gu, {
+	lang.mixin(gu, {
 		forEach: function(
-			/* dojox.gfx.Surface || dojox.gfx.Shape */ object,
+			/*dojox.gfx.Surface|dojox.gfx.Shape*/ object,
 			/*Function|String|Array*/ f, /*Object?*/ o
 		){
-			o = o || d.global;
+			// summary:
+			//		Takes a shape or a surface and applies a function "f" to in the context of "o" 
+			//		(or global, if missing). If "shape" was a surface or a group, it applies the same 
+			//		function to all children recursively effectively visiting all shapes of the underlying scene graph.
+			// object : The gfx container to iterate.
+			// f : The function to apply.
+			// o : The scope.
+			o = o || win.global;
 			f.call(o, object);
 			if(object instanceof g.Surface || object instanceof g.Group){
-				d.forEach(object.children, function(shape){
+				arr.forEach(object.children, function(shape){
 					gu.forEach(shape, f, o);
 				});
 			}
 		},
 
 		serialize: function(
-			/* dojox.gfx.Surface || dojox.gfx.Shape */ object
+			/* dojox.gfx.Surface|dojox.gfx.Shape */ object
 		){
+			// summary:
+			//		Takes a shape or a surface and returns a DOM object, which describes underlying shapes.
 			var t = {}, v, isSurface = object instanceof g.Surface;
 			if(isSurface || object instanceof g.Group){
-				t.children = d.map(object.children, gu.serialize);
+				t.children = arr.map(object.children, gu.serialize);
 				if(isSurface){
 					return t.children;	// Array
 				}
@@ -51,18 +59,22 @@ dojo.require("dojox.gfx");
 		},
 
 		toJson: function(
-			/* dojox.gfx.Surface || dojox.gfx.Shape */ object,
+			/* dojox.gfx.Surface|dojox.gfx.Shape */ object,
 			/* Boolean? */ prettyPrint
 		){
-			return d.toJson(gu.serialize(object), prettyPrint);	// String
+			// summary:
+			//		Works just like serialize() but returns a JSON string. If prettyPrint is true, the string is pretty-printed to make it more human-readable.
+			return jsonLib.toJson(gu.serialize(object), prettyPrint);	// String
 		},
 
 		deserialize: function(
-			/* dojox.gfx.Surface || dojox.gfx.Shape */ parent,
-			/* dojox.gfx.Shape || Array */ object
+			/* dojox.gfx.Surface|dojox.gfx.Shape */ parent,
+			/* dojox.gfx.Shape|Array */ object
 		){
+			// summary:
+			//		Takes a surface or a shape and populates it with an object produced by serialize().
 			if(object instanceof Array){
-				return d.map(object, d.hitch(null, gu.deserialize, parent));	// Array
+				return arr.map(object, lang.hitch(null, gu.deserialize, parent));	// Array
 			}
 			var shape = ("shape" in object) ? parent.createShape(object.shape) : parent.createGroup();
 			if("transform" in object){
@@ -78,15 +90,17 @@ dojo.require("dojox.gfx");
 				shape.setFont(object.font);
 			}
 			if("children" in object){
-				d.forEach(object.children, d.hitch(null, gu.deserialize, shape));
+				arr.forEach(object.children, lang.hitch(null, gu.deserialize, shape));
 			}
 			return shape;	// dojox.gfx.Shape
 		},
 
 		fromJson: function(
-			/* dojox.gfx.Surface || dojox.gfx.Shape */ parent,
+			/* dojox.gfx.Surface|dojox.gfx.Shape */ parent,
 			/* String */ json){
-			return gu.deserialize(parent, d.fromJson(json));	// Array || dojox.gfx.Shape
+			// summary:
+			//		Works just like deserialize() but takes a JSON representation of the object.
+			return gu.deserialize(parent, jsonLib.fromJson(json));	// Array || dojox.gfx.Shape
 		},
 
 		toSvg: function(/*GFX object*/surface){
@@ -105,9 +119,9 @@ dojo.require("dojox.gfx");
 		
 			//Since the init and even surface creation can be async, we need to
 			//return a deferred that will be called when content has serialized.
-			var deferred = new dojo.Deferred();
+			var deferred = new Deferred();
 		
-			if(dojox.gfx.renderer === "svg"){
+			if(g.renderer === "svg"){
 				//If we're already in SVG mode, this is easy and quick.
 				try{
 					var svg = gu._cleanSvg(gu._innerXML(surface.rawNode));
@@ -121,7 +135,7 @@ dojo.require("dojox.gfx");
 				if (!gu._initSvgSerializerDeferred) {
 					gu._initSvgSerializer();
 				}
-				var jsonForm = dojox.gfx.utils.toJson(surface);
+				var jsonForm = gu.toJson(surface);
 				var serializer = function(){
 					try{
 						var sDim = surface.getDimensions();
@@ -132,9 +146,9 @@ dojo.require("dojox.gfx");
 						var node = gu._gfxSvgProxy.document.createElement("div");
 						gu._gfxSvgProxy.document.body.appendChild(node);
 						//Set the node scaling.
-						dojo.withDoc(gu._gfxSvgProxy.document, function() {
-							dojo.style(node, "width", width);
-							dojo.style(node, "height", height);
+						win.withDoc(gu._gfxSvgProxy.document, function() {
+							html.style(node, "width", width);
+							html.style(node, "height", height);
 						}, this);
 
 						//Create temp surface to render object to and render.
@@ -193,9 +207,9 @@ dojo.require("dojox.gfx");
 			// tags:
 			//		private
 			if(!gu._initSvgSerializerDeferred){
-				gu._initSvgSerializerDeferred = new dojo.Deferred();
-				var f = dojo.doc.createElement("iframe");
-				dojo.style(f, {
+				gu._initSvgSerializerDeferred = new Deferred();
+				var f = win.doc.createElement("iframe");
+				html.style(f, {
 					display: "none",
 					position: "absolute",
 					width: "1em",
@@ -203,17 +217,17 @@ dojo.require("dojox.gfx");
 					top: "-10000px"
 				});
 				var intv;
-				if(dojo.isIE){
+				if(has("ie")){
 					f.onreadystatechange = function(){
 						if(f.contentWindow.document.readyState == "complete"){
 							f.onreadystatechange = function() {};
 							intv = setInterval(function() {
-								if(f.contentWindow[dojo._scopeName] &&
-								   f.contentWindow[dojox._scopeName].gfx &&
-								   f.contentWindow[dojox._scopeName].gfx.utils){
+								if(f.contentWindow[kernel.scopeMap["dojo"][1]._scopeName] &&
+								   f.contentWindow[kernel.scopeMap["dojox"][1]._scopeName].gfx &&
+								   f.contentWindow[kernel.scopeMap["dojox"][1]._scopeName].gfx.utils){
 									clearInterval(intv);
-									f.contentWindow.parent[dojox._scopeName].gfx.utils._gfxSvgProxy = f.contentWindow;
-									f.contentWindow.parent[dojox._scopeName].gfx.utils._svgSerializerInitialized();
+									f.contentWindow.parent[kernel.scopeMap["dojox"][1]._scopeName].gfx.utils._gfxSvgProxy = f.contentWindow;
+									f.contentWindow.parent[kernel.scopeMap["dojox"][1]._scopeName].gfx.utils._svgSerializerInitialized();
 								}
 							}, 50);
 						}
@@ -222,20 +236,20 @@ dojo.require("dojox.gfx");
 					f.onload = function(){
 						f.onload = function() {};
 						intv = setInterval(function() {
-							if(f.contentWindow[dojo._scopeName] &&
-							   f.contentWindow[dojox._scopeName].gfx &&
-							   f.contentWindow[dojox._scopeName].gfx.utils){
+							if(f.contentWindow[kernel.scopeMap["dojo"][1]._scopeName] &&
+							   f.contentWindow[kernel.scopeMap["dojox"][1]._scopeName].gfx &&
+							   f.contentWindow[kernel.scopeMap["dojox"][1]._scopeName].gfx.utils){
 								clearInterval(intv);
-								f.contentWindow.parent[dojox._scopeName].gfx.utils._gfxSvgProxy = f.contentWindow;
-								f.contentWindow.parent[dojox._scopeName].gfx.utils._svgSerializerInitialized();
+								f.contentWindow.parent[kernel.scopeMap["dojox"][1]._scopeName].gfx.utils._gfxSvgProxy = f.contentWindow;
+								f.contentWindow.parent[kernel.scopeMap["dojox"][1]._scopeName].gfx.utils._svgSerializerInitialized();
 							}
 						}, 50);
 					};
 				}
 				//We have to load the GFX SVG proxy frame.  Default is to use the one packaged in dojox.
-				var uri = (dojo.config["dojoxGfxSvgProxyFrameUrl"]||dojo.moduleUrl("dojox", "gfx/resources/gfxSvgProxyFrame.html"));
-				f.setAttribute("src", uri);
-				dojo.body().appendChild(f);
+				var uri = (config["dojoxGfxSvgProxyFrameUrl"]||require.toUrl("dojox/gfx/resources/gfxSvgProxyFrame.html"));
+				f.setAttribute("src", uri.toString());
+				win.body().appendChild(f);
 			}
 		},
 
@@ -267,11 +281,25 @@ dojo.require("dojox.gfx");
 					svg = svg.substring(4, svg.length);
 					svg = "<svg xmlns=\"http://www.w3.org/2000/svg\"" + svg;
 				}
+				//Same for xmlns:xlink (missing in Chrome and Safari)
+				if(svg.indexOf("xmlns:xlink=\"http://www.w3.org/1999/xlink\"") == -1){
+					svg = svg.substring(4, svg.length);
+					svg = "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\"" + svg;
+				}
+				//and add namespace to href attribute if not done yet 
+				//(FF 5+ adds xlink:href but not the xmlns def)
+				if(svg.indexOf("xlink:href") === -1){
+					svg = svg.replace(/href\s*=/g, "xlink:href=");
+				}
 				//Do some other cleanup, like stripping out the
-				//dojoGfx attributes.
+				//dojoGfx attributes and quoting ids.
 				svg = svg.replace(/\bdojoGfx\w*\s*=\s*(['"])\w*\1/g, "");
+				svg = svg.replace(/\b__gfxObject__\s*=\s*(['"])\w*\1/g, "");
+				svg = svg.replace(/[=]([^"']+?)(\s|>)/g,'="$1"$2');
 			}
 			return svg;  //Cleaned SVG text.
 		}
 	});
-})();
+
+	return gu;
+});
