@@ -1,6 +1,12 @@
-dojo.provide("dojox.grid._Events");
+define([
+	"dojo/keys",
+	"dojo/dom-class",
+	"dojo/_base/declare",
+	"dojo/_base/event",
+	"dojo/_base/sniff"
+], function(keys, domClass, declare, event, has){
 
-dojo.declare("dojox.grid._Events", null, {
+return declare("dojox.grid._Events", null, {
 	// summary:
 	//		_Grid mixin that provides default implementations for grid events.
 	// description:
@@ -49,13 +55,12 @@ dojo.declare("dojox.grid._Events", null, {
 		if(e.altKey || e.metaKey){
 			return;
 		}
-		var dk = dojo.keys;
 		var colIdx;
 		switch(e.keyCode){
-			case dk.ESCAPE:
+			case keys.ESCAPE:
 				this.edit.cancel();
 				break;
-			case dk.ENTER:
+			case keys.ENTER:
 				if(!this.edit.isEditing()){
 					colIdx = this.focus.getHeaderIndex();
 					if(colIdx >= 0) {
@@ -64,7 +69,7 @@ dojo.declare("dojox.grid._Events", null, {
 					}else {
 						this.selection.clickSelect(this.focus.rowIndex, dojo.isCopyKey(e), e.shiftKey);
 					}
-					dojo.stopEvent(e);
+					event.stop(e);
 				}
 				if(!e.shiftKey){
 					var isEditing = this.edit.isEditing();
@@ -77,10 +82,10 @@ dojo.declare("dojox.grid._Events", null, {
 					var curView = this.focus.focusView || this.views.views[0];  //if no focusView than only one view
 					curView.content.decorateEvent(e);
 					this.onRowClick(e);
-					dojo.stopEvent(e);
+					event.stop(e);
 				}
 				break;
-			case dk.SPACE:
+			case keys.SPACE:
 				if(!this.edit.isEditing()){
 					colIdx = this.focus.getHeaderIndex();
 					if(colIdx >= 0) {
@@ -89,43 +94,43 @@ dojo.declare("dojox.grid._Events", null, {
 					}else {
 						this.selection.clickSelect(this.focus.rowIndex, dojo.isCopyKey(e), e.shiftKey);
 					}
-					dojo.stopEvent(e);
+					event.stop(e);
 				}
 				break;
-			case dk.TAB:
+			case keys.TAB:
 				this.focus[e.shiftKey ? 'previousKey' : 'nextKey'](e);
 				break;
-			case dk.LEFT_ARROW:
-			case dk.RIGHT_ARROW:
+			case keys.LEFT_ARROW:
+			case keys.RIGHT_ARROW:
 				if(!this.edit.isEditing()){
 					var keyCode = e.keyCode;  // IE seems to lose after stopEvent when modifier keys
-					dojo.stopEvent(e);
+					event.stop(e);
 					colIdx = this.focus.getHeaderIndex();
 					if (colIdx >= 0 && (e.shiftKey && e.ctrlKey)){
-						this.focus.colSizeAdjust(e, colIdx, (keyCode == dk.LEFT_ARROW ? -1 : 1)*5);
+						this.focus.colSizeAdjust(e, colIdx, (keyCode == keys.LEFT_ARROW ? -1 : 1)*5);
 					}
 					else{
-						var offset = (keyCode == dk.LEFT_ARROW) ? 1 : -1;
-						if(dojo._isBodyLtr()){ offset *= -1; }
+						var offset = (keyCode == keys.LEFT_ARROW) ? 1 : -1;
+						if(this.isLeftToRight()){ offset *= -1; }
 						this.focus.move(0, offset);
 					}
 				}
 				break;
-			case dk.UP_ARROW:
+			case keys.UP_ARROW:
 				if(!this.edit.isEditing() && this.focus.rowIndex !== 0){
-					dojo.stopEvent(e);
+					event.stop(e);
 					this.focus.move(-1, 0);
 				}
 				break;
-			case dk.DOWN_ARROW:
+			case keys.DOWN_ARROW:
 				if(!this.edit.isEditing() && this.focus.rowIndex+1 != this.rowCount){
-					dojo.stopEvent(e);
+					event.stop(e);
 					this.focus.move(1, 0);
 				}
 				break;
-			case dk.PAGE_UP:
+			case keys.PAGE_UP:
 				if(!this.edit.isEditing() && this.focus.rowIndex !== 0){
-					dojo.stopEvent(e);
+					event.stop(e);
 					if(this.focus.rowIndex != this.scroller.firstVisibleRow+1){
 						this.focus.move(this.scroller.firstVisibleRow-this.focus.rowIndex, 0);
 					}else{
@@ -134,9 +139,9 @@ dojo.declare("dojox.grid._Events", null, {
 					}
 				}
 				break;
-			case dk.PAGE_DOWN:
+			case keys.PAGE_DOWN:
 				if(!this.edit.isEditing() && this.focus.rowIndex+1 != this.rowCount){
-					dojo.stopEvent(e);
+					event.stop(e);
 					if(this.focus.rowIndex != this.scroller.lastVisibleRow-1){
 						this.focus.move(this.scroller.lastVisibleRow-this.focus.rowIndex-1, 0);
 					}else{
@@ -213,7 +218,7 @@ dojo.declare("dojox.grid._Events", null, {
 		// e: Event
 		//		Decorated event object contains reference to grid, cell, and rowIndex
 		if(e.cellNode){
-			dojo.addClass(e.cellNode, this.cellOverClass);
+			domClass.add(e.cellNode, this.cellOverClass);
 		}
 	},
 	
@@ -223,7 +228,7 @@ dojo.declare("dojox.grid._Events", null, {
 		// e: Event
 		//		Decorated event object which contains reference to grid, cell, and rowIndex
 		if(e.cellNode){
-			dojo.removeClass(e.cellNode, this.cellOverClass);
+			domClass.remove(e.cellNode, this.cellOverClass);
 		}
 	},
 	
@@ -244,6 +249,10 @@ dojo.declare("dojox.grid._Events", null, {
 		if(!this.edit.isEditCell(e.rowIndex, e.cellIndex)){
 			this.focus.setFocusCell(e.cell, e.rowIndex);
 		}
+		// in some cases click[0] is null which causes false doubeClicks. Fixes #100703
+		if(this._click.length > 1 && this._click[0] == null){
+			this._click.shift();
+		}
 		this.onRowClick(e);
 	},
 
@@ -252,13 +261,17 @@ dojo.declare("dojox.grid._Events", null, {
 		//		Event fired when a cell is double-clicked.
 		// e: Event
 		//		Decorated event object contains reference to grid, cell, and rowIndex
-		if(this._click.length > 1 && dojo.isIE){
-			this.edit.setEditCell(this._click[1].cell, this._click[1].rowIndex);
+		var event;
+		if(this._click.length > 1 && has('ie')){
+			event = this._click[1];
 		}else if(this._click.length > 1 && this._click[0].rowIndex != this._click[1].rowIndex){
-			this.edit.setEditCell(this._click[0].cell, this._click[0].rowIndex);
+			event = this._click[0];
 		}else{
-			this.edit.setEditCell(e.cell, e.rowIndex);
+			event = e;
 		}
+		this.focus.setFocusCell(event.cell, event.rowIndex);
+		this.onRowClick(event);
+		this.edit.setEditCell(event.cell, event.rowIndex);
 		this.onRowDblClick(e);
 	},
 
@@ -323,7 +336,7 @@ dojo.declare("dojox.grid._Events", null, {
 		//		Event fired when a row context menu is accessed via mouse right click.
 		// e: Event
 		// 		Decorated event object which contains reference to grid, cell, and rowIndex
-		dojo.stopEvent(e);
+		event.stop(e);
 	},
 
 	// header events
@@ -347,7 +360,7 @@ dojo.declare("dojox.grid._Events", null, {
 		// e: Event
 		// 		Decorated event object which contains reference to grid, cell, and rowIndex
 		if(e.cellNode){
-			dojo.addClass(e.cellNode, this.cellOverClass);
+			domClass.add(e.cellNode, this.cellOverClass);
 		}
 	},
 
@@ -357,7 +370,7 @@ dojo.declare("dojox.grid._Events", null, {
 		// e: Event
 		// 		Decorated event object which contains reference to grid, cell, and rowIndex
 		if(e.cellNode){
-			dojo.removeClass(e.cellNode, this.cellOverClass);
+			domClass.remove(e.cellNode, this.cellOverClass);
 		}
 	},
 	
@@ -413,7 +426,7 @@ dojo.declare("dojox.grid._Events", null, {
 		// e: Event
 		//		Decorated event object which contains reference to grid, cell, and rowIndex
 		if(!this.headerMenu){
-			dojo.stopEvent(e);
+			event.stop(e);
 		}
 	},
 
@@ -491,3 +504,4 @@ dojo.declare("dojox.grid._Events", null, {
 	onSelectionChanged: function(){
 	}
 });
+});
\ No newline at end of file
