@@ -1,9 +1,17 @@
-dojo.provide("dojox.grid._FocusManager");
-
-dojo.require("dojox.grid.util");
+define([
+	"dojo/_base/array",
+	"dojo/_base/lang",
+	"dojo/_base/declare",
+	"dojo/_base/connect",
+	"dojo/_base/event",
+	"dojo/_base/sniff",
+	"dojo/query",
+	"./util",
+	"dojo/_base/html"
+], function(array, lang, declare, connect, event, has, query, util, html){
 
 // focus management
-dojo.declare("dojox.grid._FocusManager", null, {
+return declare("dojox.grid._FocusManager", null, {
 	// summary:
 	//	Controls grid cell focus. Owned by grid and used internally for focusing.
 	//	Note: grid cell actually receives keyboard input only when cell is being edited.
@@ -14,17 +22,19 @@ dojo.declare("dojox.grid._FocusManager", null, {
 		this._connects = [];
 		this._headerConnects = [];
 		this.headerMenu = this.grid.headerMenu;
-		this._connects.push(dojo.connect(this.grid.domNode, "onfocus", this, "doFocus"));
-		this._connects.push(dojo.connect(this.grid.domNode, "onblur", this, "doBlur"));
-		this._connects.push(dojo.connect(this.grid.domNode, "oncontextmenu", this, "doContextMenu"));
-		this._connects.push(dojo.connect(this.grid.lastFocusNode, "onfocus", this, "doLastNodeFocus"));
-		this._connects.push(dojo.connect(this.grid.lastFocusNode, "onblur", this, "doLastNodeBlur"));
-		this._connects.push(dojo.connect(this.grid,"_onFetchComplete", this, "_delayedCellFocus"));
-		this._connects.push(dojo.connect(this.grid,"postrender", this, "_delayedHeaderFocus"));
+		this._connects.push(connect.connect(this.grid.domNode, "onfocus", this, "doFocus"));
+		this._connects.push(connect.connect(this.grid.domNode, "onblur", this, "doBlur"));
+		this._connects.push(connect.connect(this.grid.domNode, "mousedown", this, "_mouseDown"));
+		this._connects.push(connect.connect(this.grid.domNode, "mouseup", this, "_mouseUp"));
+		this._connects.push(connect.connect(this.grid.domNode, "oncontextmenu", this, "doContextMenu"));
+		this._connects.push(connect.connect(this.grid.lastFocusNode, "onfocus", this, "doLastNodeFocus"));
+		this._connects.push(connect.connect(this.grid.lastFocusNode, "onblur", this, "doLastNodeBlur"));
+		this._connects.push(connect.connect(this.grid,"_onFetchComplete", this, "_delayedCellFocus"));
+		this._connects.push(connect.connect(this.grid,"postrender", this, "_delayedHeaderFocus"));
 	},
 	destroy: function(){
-		dojo.forEach(this._connects, dojo.disconnect);
-		dojo.forEach(this._headerConnects, dojo.disconnect);
+		array.forEach(this._connects, connect.disconnect);
+		array.forEach(this._headerConnects, connect.disconnect);
 		delete this.grid;
 		delete this.cell;
 	},
@@ -77,7 +87,7 @@ dojo.declare("dojox.grid._FocusManager", null, {
 		// returns:
 		//	index of the focused column header, or -1 if none have focus.
 		if(this._colHeadNode){
-			return dojo.indexOf(this._findHeaderCells(), this._colHeadNode);
+			return array.indexOf(this._findHeaderCells(), this._colHeadNode);
 		}else{
 			return -1;
 		}
@@ -85,12 +95,12 @@ dojo.declare("dojox.grid._FocusManager", null, {
 	_focusifyCellNode: function(inBork){
 		var n = this.cell && this.cell.getNode(this.rowIndex);
 		if(n){
-			dojo.toggleClass(n, this.focusClass, inBork);
+			html.toggleClass(n, this.focusClass, inBork);
 			if(inBork){
 				var sl = this.scrollIntoView();
 				try{
 					if(!this.grid.edit.isEditing()){
-						dojox.grid.util.fire(n, "focus");
+						util.fire(n, "focus");
 						if(sl){ this.cell.view.scrollboxNode.scrollLeft = sl; }
 					}
 				}catch(e){}
@@ -98,16 +108,18 @@ dojo.declare("dojox.grid._FocusManager", null, {
 		}
 	},
 	_delayedCellFocus: function(){
-		if(this.isNavHeader()||!this.grid._focused){
+		if(this.isNavHeader()||!this.grid.focused){
 				return;
 		}
 		var n = this.cell && this.cell.getNode(this.rowIndex);
 		if(n){
 			try{
 				if(!this.grid.edit.isEditing()){
-					dojo.toggleClass(n, this.focusClass, true);
-					this.blurHeader();
-					dojox.grid.util.fire(n, "focus");
+					html.toggleClass(n, this.focusClass, true);
+					if(this._colHeadNode){
+						this.blurHeader();
+					}
+					util.fire(n, "focus");
 				}
 			}
 			catch(e){}
@@ -120,24 +132,24 @@ dojo.declare("dojox.grid._FocusManager", null, {
 		}
 	},
 	_initColumnHeaders: function(){
-		dojo.forEach(this._headerConnects, dojo.disconnect);
+		array.forEach(this._headerConnects, connect.disconnect);
 		this._headerConnects = [];
 		var headers = this._findHeaderCells();
 		for(var i = 0; i < headers.length; i++){
-			this._headerConnects.push(dojo.connect(headers[i], "onfocus", this, "doColHeaderFocus"));
-			this._headerConnects.push(dojo.connect(headers[i], "onblur", this, "doColHeaderBlur"));
+			this._headerConnects.push(connect.connect(headers[i], "onfocus", this, "doColHeaderFocus"));
+			this._headerConnects.push(connect.connect(headers[i], "onblur", this, "doColHeaderBlur"));
 		}
 	},
 	_findHeaderCells: function(){
 		// This should be a one liner:
-		//	dojo.query("th[tabindex=-1]", this.grid.viewsHeaderNode);
-		// But there is a bug in dojo.query() for IE -- see trac #7037.
-		var allHeads = dojo.query("th", this.grid.viewsHeaderNode);
+		//	query("th[tabindex=-1]", this.grid.viewsHeaderNode);
+		// But there is a bug in query() for IE -- see trac #7037.
+		var allHeads = query("th", this.grid.viewsHeaderNode);
 		var headers = [];
 		for (var i = 0; i < allHeads.length; i++){
 			var aHead = allHeads[i];
-			var hasTabIdx = dojo.hasAttr(aHead, "tabIndex");
-			var tabindex = dojo.attr(aHead, "tabIndex");
+			var hasTabIdx = html.hasAttr(aHead, "tabIndex");
+			var tabindex = html.attr(aHead, "tabIndex");
 			if (hasTabIdx && tabindex < 0) {
 				headers.push(aHead);
 			}
@@ -146,11 +158,11 @@ dojo.declare("dojox.grid._FocusManager", null, {
 	},
 	_setActiveColHeader: function(/*Node*/colHeaderNode, /*Integer*/colFocusIdx, /*Integer*/ prevColFocusIdx){
 		//console.log("setActiveColHeader() - colHeaderNode:colFocusIdx:prevColFocusIdx = " + colHeaderNode + ":" + colFocusIdx + ":" + prevColFocusIdx);
-		dojo.attr(this.grid.domNode, "aria-activedescendant",colHeaderNode.id);
+		this.grid.domNode.setAttribute("aria-activedescendant",colHeaderNode.id);
 		if (prevColFocusIdx != null && prevColFocusIdx >= 0 && prevColFocusIdx != colFocusIdx){
-			dojo.toggleClass(this._findHeaderCells()[prevColFocusIdx],this.focusClass,false);
+			html.toggleClass(this._findHeaderCells()[prevColFocusIdx],this.focusClass,false);
 		}
-		dojo.toggleClass(colHeaderNode,this.focusClass, true);
+		html.toggleClass(colHeaderNode,this.focusClass, true);
 		this._colHeadNode = colHeaderNode;
 		this._colHeadFocusIdx = colFocusIdx;
 		this._scrollHeader(this._colHeadFocusIdx);
@@ -205,6 +217,7 @@ dojo.declare("dojox.grid._FocusManager", null, {
 		var info = null;
 		if(this._colHeadNode){
 			var cell = this.grid.getCell(currentIdx);
+			if(!cell){ return; }
 			info = this._scrollInfo(cell, cell.getNode(0));
 		}
 		if(info && info.s && info.sr && info.n){
@@ -214,7 +227,7 @@ dojo.declare("dojox.grid._FocusManager", null, {
 				info.s.scrollLeft = info.n.offsetLeft + info.n.offsetWidth - info.sr.w;
 			}else if(info.n.offsetLeft < info.sr.l){
 				info.s.scrollLeft = info.n.offsetLeft;
-			}else if(dojo.isIE <= 7 && cell && cell.view.headerNode){
+			}else if(has('ie') <= 7 && cell && cell.view.headerNode){
 				// Trac 7158: scroll dojoxGridHeader for IE7 and lower
 				cell.view.headerNode.scrollLeft = info.s.scrollLeft;
 			}
@@ -239,7 +252,7 @@ dojo.declare("dojox.grid._FocusManager", null, {
 				}
 			}
 		}
-		return (curView && dojo.getComputedStyle(curView.headerNode).display == "none");
+		return (curView && html.getComputedStyle(curView.headerNode).display == "none");
 	},
 	colSizeAdjust: function (e, colIdx, delta){ // adjust the column specified by colIdx by the specified delta px
 		var headers = this._findHeaderCells();
@@ -304,8 +317,8 @@ dojo.declare("dojox.grid._FocusManager", null, {
 		}
 		// even if this cell isFocusCell, the document focus may need to be rejiggered
 		// call opera on delay to prevent keypress from altering focus
-		if(dojo.isOpera){
-			setTimeout(dojo.hitch(this.grid, 'onCellFocus', this.cell, this.rowIndex), 1);
+		if(has('opera')){
+			setTimeout(lang.hitch(this.grid, 'onCellFocus', this.cell, this.rowIndex), 1);
 		}else{
 			this.grid.onCellFocus(this.cell, this.rowIndex);
 		}
@@ -373,7 +386,7 @@ dojo.declare("dojox.grid._FocusManager", null, {
 		// Handle column headers.
 		if(this.isNavHeader()){
 			var headers = this._findHeaderCells();
-			var savedIdx = currentIdx = dojo.indexOf(headers, this._colHeadNode);
+			var savedIdx = currentIdx = array.indexOf(headers, this._colHeadNode);
 			currentIdx += inColDelta;
 			while(currentIdx >=0 && currentIdx < headers.length && headers[currentIdx].style.display == "none"){
 				// skip over hidden column headers
@@ -422,7 +435,7 @@ dojo.declare("dojox.grid._FocusManager", null, {
 						this.move(inRowDelta > 0 ? ++inRowDelta : --inRowDelta, inColDelta);
 					}
 					return;
-				}else if((!n || dojo.style(n, "display") === "none") && inColDelta){
+				}else if((!n || html.style(n, "display") === "none") && inColDelta){
 					if((col + inRowDelta) >= 0 && (col + inRowDelta) <= cc){
 						this.move(inRowDelta, inColDelta > 0 ? ++inColDelta : --inColDelta);
 					}
@@ -437,15 +450,15 @@ dojo.declare("dojox.grid._FocusManager", null, {
 	},
 	previousKey: function(e){
 		if(this.grid.edit.isEditing()){
-			dojo.stopEvent(e);
+			event.stop(e);
 			this.previous();
 		}else if(!this.isNavHeader() && !this._isHeaderHidden()) {
 			this.grid.domNode.focus(); // will call doFocus and set focus into header.
-			dojo.stopEvent(e);
+			event.stop(e);
 		}else{
 			this.tabOut(this.grid.domNode);
 			if (this._colHeadFocusIdx != null) { // clear grid header focus
-				dojo.toggleClass(this._findHeaderCells()[this._colHeadFocusIdx], this.focusClass, false);
+				html.toggleClass(this._findHeaderCells()[this._colHeadFocusIdx], this.focusClass, false);
 				this._colHeadFocusIdx = null;
 			}
 			this._focusifyCellNode(false);
@@ -455,7 +468,7 @@ dojo.declare("dojox.grid._FocusManager", null, {
 		var isEmpty = (this.grid.rowCount === 0);
 		if(e.target === this.grid.domNode && this._colHeadFocusIdx == null){
 			this.focusHeader();
-			dojo.stopEvent(e);
+			event.stop(e);
 		}else if(this.isNavHeader()){
 			// if tabbing from col header, then go to grid proper.
 			this.blurHeader();
@@ -464,7 +477,7 @@ dojo.declare("dojox.grid._FocusManager", null, {
 			}
 			this._colHeadNode = this._colHeadFocusIdx= null;
 		}else if(this.grid.edit.isEditing()){
-			dojo.stopEvent(e);
+			event.stop(e);
 			this.next();
 		}else{
 			this.tabOut(this.grid.lastFocusNode);
@@ -475,7 +488,7 @@ dojo.declare("dojox.grid._FocusManager", null, {
 		inFocusNode.focus();
 	},
 	focusGridView: function(){
-		dojox.grid.util.fire(this.focusView, "focus");
+		util.fire(this.focusView, "focus");
 	},
 	focusGrid: function(inSkipFocusCell){
 		this.focusGridView();
@@ -554,8 +567,8 @@ dojo.declare("dojox.grid._FocusManager", null, {
 		}
 	},
 	blurHeader: function(){
-		dojo.removeClass(this._colHeadNode, this.focusClass);
-		dojo.removeAttr(this.grid.domNode,"aria-activedescendant");
+		html.removeClass(this._colHeadNode, this.focusClass);
+		html.removeAttr(this.grid.domNode,"aria-activedescendant");
 		// reset contextMenu onto viewsHeaderNode so right mouse on header will invoke (see focusHeader)
 		if (this.headerMenu && this._contextMenuBindNode == this.grid.domNode) {
 			var viewsHeader = this.grid.viewsHeaderNode;
@@ -567,7 +580,11 @@ dojo.declare("dojox.grid._FocusManager", null, {
 	doFocus: function(e){
 		// trap focus only for grid dom node
 		if(e && e.target != e.currentTarget){
-			dojo.stopEvent(e);
+			event.stop(e);
+			return;
+		}
+		// don't change focus if clicking on scroller bar
+		if(this._clickFocus){
 			return;
 		}
 		// do not focus for scrolling if grid is about to blur
@@ -575,15 +592,15 @@ dojo.declare("dojox.grid._FocusManager", null, {
 			this.focusHeader();
 		}
 		this.tabbingOut = false;
-		dojo.stopEvent(e);
+		event.stop(e);
 	},
 	doBlur: function(e){
-		dojo.stopEvent(e);	// FF2
+		event.stop(e);	// FF2
 	},
 	doContextMenu: function(e){
 	//stop contextMenu event if no header Menu to prevent default/browser contextMenu
 		if (!this.headerMenu){
-			dojo.stopEvent(e);
+			event.stop(e);
 		}
 	},
 	doLastNodeFocus: function(e){
@@ -598,17 +615,27 @@ dojo.declare("dojox.grid._FocusManager", null, {
 			this.focusHeader();
 		}
 		this.tabbingOut = false;
-		dojo.stopEvent(e);	 // FF2
+		event.stop(e);	 // FF2
 	},
 	doLastNodeBlur: function(e){
-		dojo.stopEvent(e);	 // FF2
+		event.stop(e);	 // FF2
 	},
 	doColHeaderFocus: function(e){
-		this._setActiveColHeader(e.target,dojo.attr(e.target, "idx"),this._colHeadFocusIdx);
+		this._setActiveColHeader(e.target,html.attr(e.target, "idx"),this._colHeadFocusIdx);
 		this._scrollHeader(this.getHeaderIndex());
-		dojo.stopEvent(e);
+		event.stop(e);
 	},
 	doColHeaderBlur: function(e){
-		dojo.toggleClass(e.target, this.focusClass, false);
+		html.toggleClass(e.target, this.focusClass, false);
+	},
+	_mouseDown: function(e){
+		// a flag indicating grid is being focused by clicking
+		this._clickFocus = dojo.some(this.grid.views.views, function(v){
+			return v.scrollboxNode === e.target;
+		});
+	},
+	_mouseUp: function(e){
+		this._clickFocus = false;
 	}
 });
+});
\ No newline at end of file
