@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	"descTemplate": "${2} - ${3} von ${1} ${0}",
 	"firstTip": "Erste Seite",
@@ -5,14 +7,18 @@
 	"nextTip": "Nächste Seite",
 	"prevTip": "Vorherige Seite",
 	"itemTitle": "Elemente",
+	"singularItemTitle": "Element",
 	"pageStepLabelTemplate": "Seite ${0}",
 	"pageSizeLabelTemplate": "${0} Elemente pro Seite",
 	"allItemsLabelTemplate": "Alle Elemente",
-	"gotoButtonTitle": "Eine bestimmte Seite aufrufen",
-	"dialogTitle": "Zu Seite",
-	"dialogIndication": "Geben Sie die Seitenzahl an.",
+	"gotoButtonTitle": "Bestimmte Seite aufrufen",
+	"dialogTitle": "Seite aufrufen",
+	"dialogIndication": "Seitenzahl angeben",
 	"pageCountIndication": " (${0} Seiten)",
 	"dialogConfirm": "Start",
-	"dialogCancel": "Abbrechen"
+	"dialogCancel": "Abbrechen",
+	"all": "alle"
 })
+//end v1.x content
+);
 
