@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	"descTemplate": "${2} - ${3} από ${1} ${0}",
 	"firstTip": "Πρώτη σελίδα",
@@ -5,6 +7,7 @@
 	"nextTip": "Επόμενη σελίδα",
 	"prevTip": "Προηγούμενη σελίδα",
 	"itemTitle": "στοιχεία",
+	"singularItemTitle": "στοιχείο",
 	"pageStepLabelTemplate": "Σελίδα ${0}",
 	"pageSizeLabelTemplate": "${0} στοιχεία ανά σελίδα",
 	"allItemsLabelTemplate": "Όλα τα στοιχεία",
@@ -13,6 +16,8 @@
 	"dialogIndication": "Καθορίστε τον αριθμό της σελίδας",
 	"pageCountIndication": " (${0} σελίδες)",
 	"dialogConfirm": "Μετάβαση",
-	"dialogCancel": "Ακύρωση"
+	"dialogCancel": "Ακύρωση",
+	"all": "όλα"
 })
-
+//end v1.x content
+);
