@@ -1,18 +1,24 @@
+define(
+//begin v1.x content
 ({
-	"descTemplate": "${2} à ${3} sur ${1} ${0}",
+	"descTemplate": "${2} - ${3} sur ${1} ${0}",
 	"firstTip": "Première page",
 	"lastTip": "Dernière page",
 	"nextTip": "Page suivante",
 	"prevTip": "Page précédente",
 	"itemTitle": "éléments",
+	"singularItemTitle": "élément",
 	"pageStepLabelTemplate": "Page ${0}",
 	"pageSizeLabelTemplate": "${0} éléments par page",
 	"allItemsLabelTemplate": "Tous les éléments",
-	"gotoButtonTitle": "Aller à une page donnée",
-	"dialogTitle": "Aller à la page",
+	"gotoButtonTitle": "Accéder à une page spécifique",
+	"dialogTitle": "Accéder à la page",
 	"dialogIndication": "Indiquer le numéro de page",
 	"pageCountIndication": " (${0} pages)",
-	"dialogConfirm": "Aller",
-	"dialogCancel": "Annuler"
+	"dialogConfirm": "Accès",
+	"dialogCancel": "Annuler",
+	"all": "tout"
 })
+//end v1.x content
+);
 
