@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 	"descTemplate": "${2} - ${3} z ${1} ${0}",
 	"firstTip": "Prvá strana",
@@ -5,6 +7,7 @@
 	"nextTip": "Ďalšia strana",
 	"prevTip": "Predošlá strana",
 	"itemTitle": "položiek",
+	"singularItemTitle": "položka",
 	"pageStepLabelTemplate": "Strana ${0}",
 	"pageSizeLabelTemplate": "${0} položiek na strane",
 	"allItemsLabelTemplate": "Všetky položky",
@@ -13,6 +16,8 @@
 	"dialogIndication": "Zadajte číslo strany",
 	"pageCountIndication": " (${0} strán)",
 	"dialogConfirm": "Prejsť",
-	"dialogCancel": "Zrušiť"
+	"dialogCancel": "Zrušiť",
+	"all": "všetko"
 })
-
+//end v1.x content
+);
