@@ -1,4 +1,5 @@
-dojo.provide("dojox.io.windowName");
+define(["dojo/_base/kernel", "dojo/_base/window", "dojo/_base/xhr", "dojo/_base/sniff", "dojo/_base/url", "dojo/domReady!"], function(dojo){
+dojo.getObject("io.windowName", true, dojox);
 // Implements the window.name transport
 
 dojox.io.windowName = {
@@ -78,16 +79,7 @@ dojox.io.windowName = {
 				args.timeout
 			);
 		}
-		var self = dojox.io.windowName;
-		if(dojo.body()){
-			// the DOM is ready
-			self._send(dfd, method, authElement, args.onAuthLoad);
-		}else{
-			// we will wait for the DOM to be ready to proceed
-			dojo.addOnLoad(function(){
-				self._send(dfd, method, authElement, args.onAuthLoad);
-			});
-		}
+		dojox.io.windowName._send(dfd, method, authElement, args.onAuthLoad);
 		return dfd;
 	},
 	_send: function(dfd, method, authTarget, onAuthLoad){
@@ -112,7 +104,7 @@ dojox.io.windowName = {
 				outerFrame.style.display='none';
 			}
 			frameContainer.appendChild(outerFrame);
-			
+
 			var firstWindow = outerFrame.contentWindow;
 			doc = firstWindow.document;
 			doc.write("<html><body margin='0px'><iframe style='width:100%;height:100%;border:0px' name='protectedFrame'></iframe></body></html>");
@@ -180,7 +172,7 @@ dojox.io.windowName = {
 			}
 			catch(e){
 			}
-			
+
 		};
 		frame.name = frameName;
 		if(method.match(/GET/i)){
@@ -212,7 +204,7 @@ dojox.io.windowName = {
 			form.method = 'POST';
 			form.action = ioArgs.url;
 			form.target = frameName;// connect the form to the iframe
-			
+
 			form.submit();
 			form.parentNode.removeChild(form);
 		}else{
@@ -223,5 +215,9 @@ dojox.io.windowName = {
 		}
 	},
 	_frameNum: 0
-	
-}
+
+};
+
+return dojox.io.windowName;
+
+});
