@@ -1,25 +1,26 @@
-dojo.provide("dojox.layout.FloatingPane");
-dojo.experimental("dojox.layout.FloatingPane");
+define(["dojo/_base/kernel","dojo/_base/lang","dojo/_base/window","dojo/_base/declare",
+		"dojo/_base/fx","dojo/_base/connect","dojo/_base/array","dojo/_base/sniff",
+		"dojo/window","dojo/dom","dojo/dom-class","dojo/dom-geometry","dojo/dom-construct",
+		"dijit/_TemplatedMixin","dijit/_Widget","dijit/BackgroundIframe","dojo/dnd/Moveable",
+		"./ContentPane","./ResizeHandle","dojo/text!./resources/FloatingPane.html"], function(
+	kernel, lang, winUtil, declare, baseFx, connectUtil, arrayUtil, 
+	has, windowLib, dom, domClass, domGeom, domConstruct, TemplatedMixin, Widget, BackgroundIframe, 
+	Moveable, ContentPane, ResizeHandle, template){
 
-dojo.require("dojo.window");
-
-dojo.require("dijit._Templated");
-dojo.require("dijit._Widget");
-dojo.require("dojo.dnd.Moveable");
-
-dojo.require("dojox.layout.ContentPane");
-dojo.require("dojox.layout.ResizeHandle");
-
-dojo.declare("dojox.layout.FloatingPane",
-	[ dojox.layout.ContentPane, dijit._Templated ],
-	{
+/*=====
+var Widget = dijit._Widget;
+var TemplatedMixin = dijit._TemplatedMixin;
+var ContentPane = dojox.layout.ContentPane;
+=====*/
+kernel.experimental("dojox.layout.FloatingPane");
+var FloatingPane = declare("dojox.layout.FloatingPane", [ ContentPane, TemplatedMixin ],{
 	// summary:
 	//		A non-modal Floating window.
 	//
 	// description:
-	// 		Makes a `dojox.layout.ContentPane` float and draggable by it's title [similar to TitlePane]
-	// 		and over-rides onClick to onDblClick for wipeIn/Out of containerNode
-	// 		provides minimize(dock) / show() and hide() methods, and resize [almost]
+	//		Makes a `dojox.layout.ContentPane` float and draggable by it's title [similar to TitlePane]
+	//		and over-rides onClick to onDblClick for wipeIn/Out of containerNode
+	//		provides minimize(dock) / show() and hide() methods, and resize [almost]
 	//
 	// closable: Boolean
 	//		Allow closure of this Node
@@ -77,15 +78,15 @@ dojo.declare("dojox.layout.FloatingPane",
 	_allFPs: [],
 	_startZ: 100,
 
-	templateString: dojo.cache("dojox.layout","resources/FloatingPane.html"),
+	templateString: template,
 	
-	attributeMap: dojo.delegate(dijit._Widget.prototype.attributeMap, {
+	attributeMap: lang.delegate(Widget.prototype.attributeMap, {
 		title: { type:"innerHTML", node:"titleNode" }
 	}),
 	
 	postCreate: function(){
 		this.inherited(arguments);
-		new dojo.dnd.Moveable(this.domNode,{ handle: this.focusNode });
+		new Moveable(this.domNode,{ handle: this.focusNode });
 		//this._listener = dojo.subscribe("/dnd/move/start",this,"bringToTop");
 
 		if(!this.dockable){ this.dockNode.style.display = "none"; }
@@ -97,13 +98,13 @@ dojo.declare("dojox.layout.FloatingPane",
 		if(!this.resizable){
 			this.resizeHandle.style.display = "none";
 		}else{
-			this.domNode.style.width = dojo.marginBox(this.domNode).w + "px";
+			this.domNode.style.width = domGeom.getMarginBox(this.domNode).w + "px";
 		}
 		this._allFPs.push(this);
 		this.domNode.style.position = "absolute";
 		
-		this.bgIframe = new dijit.BackgroundIframe(this.domNode);
-		this._naturalState = dojo.coords(this.domNode);
+		this.bgIframe = new BackgroundIframe(this.domNode);
+		this._naturalState = domGeom.position(this.domNode);
 	},
 	
 	startup: function(){
@@ -112,13 +113,13 @@ dojo.declare("dojox.layout.FloatingPane",
 		this.inherited(arguments);
 
 		if(this.resizable){
-			if(dojo.isIE){
+			if(has("ie")){
 				this.canvas.style.overflow = "auto";
 			}else{
 				this.containerNode.style.overflow = "auto";
 			}
 			
-			this._resizeHandle = new dojox.layout.ResizeHandle({
+			this._resizeHandle = new ResizeHandle({
 				targetId: this.id,
 				resizeAxis: this.resizeAxis
 			},this.resizeHandle);
@@ -143,13 +144,13 @@ dojo.declare("dojox.layout.FloatingPane",
 				// once, and use it on empty OR invalid dockTo="" node?
 				if(tmpName){
 					tmpId = tmpName;
-					tmpNode = dojo.byId(tmpName);
+					tmpNode = dom.byId(tmpName);
 				}else{
-					tmpNode = dojo.create('div', null, dojo.body());
-					dojo.addClass(tmpNode,"dojoxFloatingDockDefault");
+					tmpNode = domConstruct.create('div', null, winUtil.body());
+					domClass.add(tmpNode,"dojoxFloatingDockDefault");
 					tmpId = 'dojoxGlobalFloatingDock';
 				}
-				this.dockTo = new dojox.layout.Dock({ id: tmpId, autoPosition: "south" }, tmpNode);
+				this.dockTo = new Dock({ id: tmpId, autoPosition: "south" }, tmpNode);
 				this.dockTo.startup();
 			}
 			
@@ -162,33 +163,32 @@ dojo.declare("dojox.layout.FloatingPane",
 		this.connect(this.domNode,	"onmousedown","bringToTop");
 
 		// Initial resize to give child the opportunity to lay itself out
-		this.resize(dojo.coords(this.domNode));
+		this.resize(domGeom.position(this.domNode));
 		
 		this._started = true;
 	},
 
 	setTitle: function(/* String */ title){
 		// summary: Update the Title bar with a new string
-		dojo.deprecated("pane.setTitle", "Use pane.set('title', someTitle)", "2.0");
+		kernel.deprecated("pane.setTitle", "Use pane.set('title', someTitle)", "2.0");
 		this.set("title", title);
-		// this.setTitle = dojo.hitch(this, "setTitle") ??
 	},
 		
 	close: function(){
 		// summary: Close and destroy this widget
 		if(!this.closable){ return; }
-		dojo.unsubscribe(this._listener);
-		this.hide(dojo.hitch(this,function(){
+		connectUtil.unsubscribe(this._listener);
+		this.hide(lang.hitch(this,function(){
 			this.destroyRecursive();
 		}));
 	},
 
 	hide: function(/* Function? */ callback){
 		// summary: Close, but do not destroy this FloatingPane
-		dojo.fadeOut({
+		baseFx.fadeOut({
 			node:this.domNode,
 			duration:this.duration,
-			onEnd: dojo.hitch(this,function() {
+			onEnd: lang.hitch(this,function() {
 				this.domNode.style.display = "none";
 				this.domNode.style.visibility = "hidden";
 				if(this.dockTo && this.dockable){
@@ -203,8 +203,8 @@ dojo.declare("dojox.layout.FloatingPane",
 
 	show: function(/* Function? */callback){
 		// summary: Show the FloatingPane
-		var anim = dojo.fadeIn({node:this.domNode, duration:this.duration,
-			beforeBegin: dojo.hitch(this,function(){
+		var anim = baseFx.fadeIn({node:this.domNode, duration:this.duration,
+			beforeBegin: lang.hitch(this,function(){
 				this.domNode.style.display = "";
 				this.domNode.style.visibility = "visible";
 				if (this.dockTo && this.dockable) { this.dockTo._positionDock(null); }
@@ -216,32 +216,32 @@ dojo.declare("dojox.layout.FloatingPane",
 				}
 			})
 		}).play();
-		this.resize(dojo.coords(this.domNode));
+		this.resize(domGeom.position(this.domNode));
 		this._onShow(); // lazy load trigger
 	},
 
 	minimize: function(){
 		// summary: Hide and dock the FloatingPane
-		if(!this._isDocked){ this.hide(dojo.hitch(this,"_dock")); }
+		if(!this._isDocked){ this.hide(lang.hitch(this,"_dock")); }
 	},
 
 	maximize: function(){
 		// summary: Make this FloatingPane full-screen (viewport)
 		if(this._maximized){ return; }
-		this._naturalState = dojo.position(this.domNode);
+		this._naturalState = domGeom.position(this.domNode);
 		if(this._isDocked){
 			this.show();
-			setTimeout(dojo.hitch(this,"maximize"),this.duration);
+			setTimeout(lang.hitch(this,"maximize"),this.duration);
 		}
-		dojo.addClass(this.focusNode,"floatingPaneMaximized");
-		this.resize(dojo.window.getBox());
+		domClass.add(this.focusNode,"floatingPaneMaximized");
+		this.resize(windowLib.getBox());
 		this._maximized = true;
 	},
 
 	_restore: function(){
 		if(this._maximized){
 			this.resize(this._naturalState);
-			dojo.removeClass(this.focusNode,"floatingPaneMaximized");
+			domClass.remove(this.focusNode,"floatingPaneMaximized");
 			this._maximized = false;
 		}
 	},
@@ -261,13 +261,15 @@ dojo.declare("dojox.layout.FloatingPane",
 		// From the ResizeHandle we only get width and height information
 		var dns = this.domNode.style;
 		if("t" in dim){ dns.top = dim.t + "px"; }
+		else if("y" in dim){ dns.top = dim.y + "px"; }
 		if("l" in dim){ dns.left = dim.l + "px"; }
+		else if("x" in dim){ dns.left = dim.x + "px"; }
 		dns.width = dim.w + "px";
 		dns.height = dim.h + "px";
 
 		// Now resize canvas
 		var mbCanvas = { l: 0, t: 0, w: dim.w, h: (dim.h - this.focusNode.offsetHeight) };
-		dojo.marginBox(this.canvas, mbCanvas);
+		domGeom.setMarginBox(this.canvas, mbCanvas);
 
 		// If the single child can resize, forward resize event to it so it can
 		// fit itself properly into the content area
@@ -279,7 +281,7 @@ dojo.declare("dojox.layout.FloatingPane",
 	
 	bringToTop: function(){
 		// summary: bring this FloatingPane above all other panes
-		var windows = dojo.filter(
+		var windows = arrayUtil.filter(
 			this._allFPs,
 			function(i){
 				return i !== this;
@@ -290,16 +292,16 @@ dojo.declare("dojox.layout.FloatingPane",
 		});
 		windows.push(this);
 		
-		dojo.forEach(windows, function(w, x){
+		arrayUtil.forEach(windows, function(w, x){
 			w.domNode.style.zIndex = this._startZ + (x * 2);
-			dojo.removeClass(w.domNode, "dojoxFloatingPaneFg");
+			domClass.remove(w.domNode, "dojoxFloatingPaneFg");
 		}, this);
-		dojo.addClass(this.domNode, "dojoxFloatingPaneFg");
+		domClass.add(this.domNode, "dojoxFloatingPaneFg");
 	},
 	
 	destroy: function(){
 		// summary: Destroy this FloatingPane completely
-		this._allFPs.splice(dojo.indexOf(this._allFPs, this), 1);
+		this._allFPs.splice(arrayUtil.indexOf(this._allFPs, this), 1);
 		if(this._resizeHandle){
 			this._resizeHandle.destroy();
 		}
@@ -307,10 +309,7 @@ dojo.declare("dojox.layout.FloatingPane",
 	}
 });
 
-
-dojo.declare("dojox.layout.Dock",
-	[dijit._Widget,dijit._Templated],
-	{
+var Dock = declare("dojox.layout.Dock",[Widget, TemplatedMixin],{
 	// summary:
 	//		A widget that attaches to a node and keeps track of incoming / outgoing FloatingPanes
 	// 		and handles layout
@@ -327,8 +326,8 @@ dojo.declare("dojox.layout.Dock",
 	addNode: function(refNode){
 		// summary: Instert a dockNode refernce into the dock
 		
-		var div = dojo.create('li', null, this.containerNode),
-			node = new dojox.layout._DockNode({
+		var div = domConstruct.create('li', null, this.containerNode),
+			node = new DockNode({
 				title: refNode.title,
 				paneRef: refNode
 			}, div)
@@ -343,7 +342,7 @@ dojo.declare("dojox.layout.Dock",
 			// attach window.onScroll, and a position like in presentation/dialog
 			this.connect(window, 'onresize', "_positionDock");
 			this.connect(window, 'onscroll', "_positionDock");
-			if(dojo.isIE){
+			if(has("ie")){
 				this.connect(this.domNode, "onresize", "_positionDock");
 			}
 		}
@@ -356,9 +355,9 @@ dojo.declare("dojox.layout.Dock",
 		if(!this._inPositioning){
 			if(this.autoPosition == "south"){
 				// Give some time for scrollbars to appear/disappear
-				setTimeout(dojo.hitch(this, function() {
+				setTimeout(lang.hitch(this, function() {
 					this._inPositiononing = true;
-					var viewport = dojo.window.getBox();
+					var viewport = windowLib.getBox();
 					var s = this.domNode.style;
 					s.left = viewport.l + "px";
 					s.width = (viewport.w-2) + "px";
@@ -372,9 +371,7 @@ dojo.declare("dojox.layout.Dock",
 
 });
 
-dojo.declare("dojox.layout._DockNode",
-	[dijit._Widget,dijit._Templated],
-	{
+var DockNode = declare("dojox.layout._DockNode",[Widget, TemplatedMixin],{
 	// summary:
 	//		dojox.layout._DockNode is a private widget used to keep track of
 	//		which pane is docked.
@@ -399,5 +396,7 @@ dojo.declare("dojox.layout._DockNode",
 		this.paneRef.bringToTop();
 		this.destroy();
 	}
-
 });
+
+return FloatingPane;
+});
\ No newline at end of file
