@@ -1,17 +1,18 @@
-dojo.provide("dojox.string.BidiComplex");
-dojo.experimental("dojox.string.BidiComplex");
-
 // summary:
 //		BiDiComplex module handles complex expression issues known when using BiDi characters
 //		in File Paths, URLs, E-mail Address, XPATH, etc.
 //		this module adds property listeners to the text fields to correct the text representation
 //		in both static text and dynamic text during user input.
 
-(function(){
+define(["dojo/_base/kernel", "dojo/_base/lang", "dojo/_base/array", "dojo/_base/connect", "dojo/_base/sniff",
+		"dojo/keys"], 
+  function(dojo, lang, arr, hub, has, keys){
+	dojo.experimental("dojox.string.BidiComplex");
+	var bdc = lang.getObject("string.BidiComplex", true, dojox);
 
 	var _str0 = []; //FIXME: shared reference here among various functions means the functions can't be reused
 
-	dojox.string.BidiComplex.attachInput = function(/*DOMNode*/field, /*String*/pattern){
+	bdc.attachInput = function(/*DOMNode*/field, /*String*/pattern){
 		// summary:
 		//		Attach key listeners to the INPUT field to accomodate dynamic complex BiDi expressions
 		// field: INPUT DOM node
@@ -19,26 +20,26 @@ dojo.experimental("dojox.string.BidiComplex");
 
 		field.alt = pattern;
 
-		dojo.connect(field, "onkeydown",  this, "_ceKeyDown");
-		dojo.connect(field, "onkeyup", this, "_ceKeyUp");
+		hub.connect(field, "onkeydown",  this, "_ceKeyDown");
+		hub.connect(field, "onkeyup", this, "_ceKeyUp");
 
-		dojo.connect(field, "oncut", this, "_ceCutText");
-		dojo.connect(field, "oncopy", this, "_ceCopyText");
+		hub.connect(field, "oncut", this, "_ceCutText");
+		hub.connect(field, "oncopy", this, "_ceCopyText");
 
-		field.value = dojox.string.BidiComplex.createDisplayString(field.value, field.alt);
+		field.value = bdc.createDisplayString(field.value, field.alt);
 	};
 		
-	dojox.string.BidiComplex.createDisplayString = function(/*String*/str, /*String*/pattern){
+	bdc.createDisplayString = function(/*String*/str, /*String*/pattern){
 		// summary:
 		//		Create the display string by adding the Unicode direction Markers
 		// pattern: Complex Expression Pattern type. One of "FILE_PATH", "URL", "EMAIL", "XPATH"
 
-		str = dojox.string.BidiComplex.stripSpecialCharacters(str);
-		var segmentsPointers = dojox.string.BidiComplex._parse(str, pattern);
+		str = bdc.stripSpecialCharacters(str);
+		var segmentsPointers = bdc._parse(str, pattern);
 		
 		var buf = '\u202A'/*LRE*/ + str;
 		var shift = 1;
-		dojo.forEach(segmentsPointers, function(n){
+		arr.forEach(segmentsPointers, function(n){
 			if(n != null){
 				var preStr = buf.substring(0, n + shift);
 				var postStr = buf.substring(n + shift, buf.length);
@@ -49,51 +50,51 @@ dojo.experimental("dojox.string.BidiComplex");
 		return buf;
 	};
 
-	dojox.string.BidiComplex.stripSpecialCharacters = function(str){
+	bdc.stripSpecialCharacters = function(str){
 		// summary:
 		//		removes all Unicode directional markers from the string
 
 		return str.replace(/[\u200E\u200F\u202A-\u202E]/g, ""); // String
 	};
 
-	dojox.string.BidiComplex._ceKeyDown = function(event){
-		var elem = dojo.isIE ? event.srcElement : event.target;
+	bdc._ceKeyDown = function(event){
+		var elem = has("ie") ? event.srcElement : event.target;
 		_str0 = elem.value;
 	};
 				
-	dojox.string.BidiComplex._ceKeyUp = function(event){
+	bdc._ceKeyUp = function(event){
 		var LRM = '\u200E';
-		var elem = dojo.isIE ? event.srcElement : event.target;
+		var elem = has("ie") ? event.srcElement : event.target;
 
 		var str1 = elem.value;
 		var ieKey = event.keyCode;
 		
-		if((ieKey == dojo.keys.HOME)
-			|| (ieKey == dojo.keys.END)
-			|| (ieKey == dojo.keys.SHIFT)){
+		if((ieKey == keys.HOME)
+			|| (ieKey == keys.END)
+			|| (ieKey == keys.SHIFT)){
 			return;
 		}
 
 		var cursorStart, cursorEnd;
-		var selection = dojox.string.BidiComplex._getCaretPos(event, elem);
+		var selection = bdc._getCaretPos(event, elem);
 		if(selection){
 			cursorStart = selection[0];
 			cursorEnd = selection[1];
 		}
 
 	//Jump over a cursor processing
-		if(dojo.isIE){
+		if(has("ie")){
 			var cursorStart1 = cursorStart, cursorEnd1 = cursorEnd;
 
-			if(ieKey == dojo.keys.LEFT_ARROW){
+			if(ieKey == keys.LEFT_ARROW){
 				if((str1.charAt(cursorEnd-1) == LRM)
 						&& (cursorStart == cursorEnd)){
-					dojox.string.BidiComplex._setSelectedRange(elem,cursorStart - 1, cursorEnd - 1);
+					bdc._setSelectedRange(elem,cursorStart - 1, cursorEnd - 1);
 				}
 				return;
 			}
 
-			if(ieKey == dojo.keys.RIGHT_ARROW){
+			if(ieKey == keys.RIGHT_ARROW){
 				if(str1.charAt(cursorEnd-1) == LRM){
 					cursorEnd1 = cursorEnd + 1;
 					if(cursorStart == cursorEnd){
@@ -101,55 +102,55 @@ dojo.experimental("dojox.string.BidiComplex");
 					}
 				}
 
-				dojox.string.BidiComplex._setSelectedRange(elem, cursorStart1, cursorEnd1);
+				bdc._setSelectedRange(elem, cursorStart1, cursorEnd1);
 				return;
 			}
 		}else{ //Firefox
-			if(ieKey == dojo.keys.LEFT_ARROW){
+			if(ieKey == keys.LEFT_ARROW){
 				if(str1.charAt(cursorEnd-1) == LRM){
-					dojox.string.BidiComplex._setSelectedRange(elem, cursorStart - 1, cursorEnd - 1);
+					bdc._setSelectedRange(elem, cursorStart - 1, cursorEnd - 1);
 				}
 				return;
 			}
-			if(ieKey == dojo.keys.RIGHT_ARROW){
+			if(ieKey == keys.RIGHT_ARROW){
 				if(str1.charAt(cursorEnd-1) == LRM){
-					dojox.string.BidiComplex._setSelectedRange(elem, cursorStart + 1, cursorEnd + 1);
+					bdc._setSelectedRange(elem, cursorStart + 1, cursorEnd + 1);
 				}
 				return;
 			}
 		}
 		
-		var str2 = dojox.string.BidiComplex.createDisplayString(str1, elem.alt);
+		var str2 = bdc.createDisplayString(str1, elem.alt);
 
 		if(str1 != str2)
 		{
 			window.status = str1 + " c=" + cursorEnd;
 			elem.value = str2;
 
-			if((ieKey == dojo.keys.DELETE) && (str2.charAt(cursorEnd)==LRM)){
+			if((ieKey == keys.DELETE) && (str2.charAt(cursorEnd)==LRM)){
 				elem.value = str2.substring(0, cursorEnd) + str2.substring(cursorEnd+2, str2.length);
 			}
 
-			if(ieKey == dojo.keys.DELETE){
-				dojox.string.BidiComplex._setSelectedRange(elem,cursorStart,cursorEnd);
-			}else if(ieKey == dojo.keys.BACKSPACE){
+			if(ieKey == keys.DELETE){
+				bdc._setSelectedRange(elem,cursorStart,cursorEnd);
+			}else if(ieKey == keys.BACKSPACE){
 				if((_str0.length >= cursorEnd) && (_str0.charAt(cursorEnd-1)==LRM)){
-					dojox.string.BidiComplex._setSelectedRange(elem, cursorStart - 1, cursorEnd - 1);
+					bdc._setSelectedRange(elem, cursorStart - 1, cursorEnd - 1);
 				}else{
-					dojox.string.BidiComplex._setSelectedRange(elem, cursorStart, cursorEnd);
+					bdc._setSelectedRange(elem, cursorStart, cursorEnd);
 				}
 			}else if(elem.value.charAt(cursorEnd) != LRM){
-				dojox.string.BidiComplex._setSelectedRange(elem, cursorStart + 1, cursorEnd + 1);
+				bdc._setSelectedRange(elem, cursorStart + 1, cursorEnd + 1);
 			}
 		}
 	};
 
-	dojox.string.BidiComplex._processCopy = function(elem, text, isReverse){
+	bdc._processCopy = function(elem, text, isReverse){
 		// summary:
 		//		This function strips the unicode directional controls when the text copied to the Clipboard
 
 		if(text == null){
-			if(dojo.isIE){
+			if(has("ie")){
 				var range = document.selection.createRange();
 				text = range.text;
 			}else{
@@ -157,29 +158,29 @@ dojo.experimental("dojox.string.BidiComplex");
 			}
 		}
 
-		var textToClipboard = dojox.string.BidiComplex.stripSpecialCharacters(text);
+		var textToClipboard = bdc.stripSpecialCharacters(text);
 	
-		if(dojo.isIE){
+		if(has("ie")){
 			window.clipboardData.setData("Text", textToClipboard);
 		}
 		return true;
 	};
 
-	dojox.string.BidiComplex._ceCopyText = function(elem){
-		if(dojo.isIE){
+	bdc._ceCopyText = function(elem){
+		if(has("ie")){
 			elem.returnValue = false;
 		}
-		return dojox.string.BidiComplex._processCopy(elem, null, false);
+		return bdc._processCopy(elem, null, false);
 	};
 
-	dojox.string.BidiComplex._ceCutText = function(elem){
+	bdc._ceCutText = function(elem){
 
-		var ret = dojox.string.BidiComplex._processCopy(elem, null, false);
+		var ret = bdc._processCopy(elem, null, false);
 		if(!ret){
 			return false;
 		}
 
-		if(dojo.isIE){
+		if(has("ie")){
 	//		curPos = elem.selectionStart;
 			document.selection.clear();
 		}else{
@@ -192,8 +193,8 @@ dojo.experimental("dojox.string.BidiComplex");
 	};
 
 	// is there dijit code to do this?
-	dojox.string.BidiComplex._getCaretPos = function(event, elem){
-		if(dojo.isIE){
+	bdc._getCaretPos = function(event, elem){
+		if(has("ie")){
 			var position = 0,
 			range = document.selection.createRange().duplicate(),
 			range2 = range.duplicate(),
@@ -216,8 +217,8 @@ dojo.experimental("dojox.string.BidiComplex");
 	};
 
 	// is there dijit code to do this?
-	dojox.string.BidiComplex._setSelectedRange = function(elem,selectionStart,selectionEnd){
-		if(dojo.isIE){
+	bdc._setSelectedRange = function(elem,selectionStart,selectionEnd){
+		if(has("ie")){
 			var range = elem.createTextRange();
 			if(range){
 				if(elem.type == "textarea"){
@@ -262,7 +263,7 @@ dojo.experimental("dojox.string.BidiComplex");
 	};
 
 
-	dojox.string.BidiComplex._parse = function(/*String*/str, /*String*/pattern){
+	bdc._parse = function(/*String*/str, /*String*/pattern){
 		var previous = -1, segmentsPointers = [];
 		var delimiters = {
 			FILE_PATH: "/\\:.",
@@ -275,7 +276,7 @@ dojo.experimental("dojox.string.BidiComplex");
 			case "FILE_PATH":
 			case "URL":
 			case "XPATH":
-				dojo.forEach(str, function(ch, i){
+				arr.forEach(str, function(ch, i){
 					if(delimiters.indexOf(ch) >= 0 && _isCharBeforeBiDiChar(str, i, previous)){
 						previous = i;
 						segmentsPointers.push(i);
@@ -285,7 +286,7 @@ dojo.experimental("dojox.string.BidiComplex");
 			case "EMAIL":
 				var inQuotes = false; // FIXME: unused?
 	
-				dojo.forEach(str, function(ch, i){
+				arr.forEach(str, function(ch, i){
 					if(ch== '\"'){
 						if(_isCharBeforeBiDiChar(str, i, previous)){
 							previous = i;
@@ -310,4 +311,5 @@ dojo.experimental("dojox.string.BidiComplex");
 		}
 		return segmentsPointers;
 	};
-})();
+	return dojox.string.BidiComplex;
+});
