@@ -1,13 +1,20 @@
-dojo.provide("dojox.validate.isbn");
+define(["dojo/_base/lang", "./_base"], function(lang, validate){
 // summary: Provides ISBN validation functions in `dojox.validate`
 //
-dojox.validate.isValidIsbn = function(/* String */value) {
+
+/*=====
+
+	validate = dojox.validate;
+
+=====*/
+
+validate.isValidIsbn = function(/* String */value) {
 	// summary: Validate ISBN-10 or ISBN-13 based on the length of value
 	// value: String
 	//		An ISBN to validate
 	// returns: Boolean
 	var len, sum = 0, weight;
-	if(!dojo.isString(value)){
+	if(!lang.isString(value)){
 		value = String(value);
 	}
 	value = value.replace(/[- ]/g,''); //ignore dashes and whitespaces
@@ -35,4 +42,7 @@ dojox.validate.isValidIsbn = function(/* String */value) {
 			break;
 	}
 	return false;
-}
+};
+
+return validate.isValidIsbn;
+});
