@@ -1,8 +1,42 @@
-define("dojox/widget/Standby", ["dojo", "dijit", "dojox", "dojo/window", "dojo/fx", "dijit/_Widget", "dijit/_Templated"], function(dojo, dijit, dojox) {
+define(["dojo/_base/kernel",
+	"dojo/_base/declare",
+	"dojo/_base/array",
+	"dojo/_base/event",
+	"dojo/_base/sniff",
+	"dojo/dom",
+	"dojo/dom-attr",
+	"dojo/dom-construct",
+	"dojo/dom-geometry",
+	"dojo/dom-style",
+	"dojo/window",
+	"dojo/_base/window",
+	"dojo/_base/fx",
+	"dojo/fx",
+	"dijit/_Widget",
+	"dijit/_TemplatedMixin",
+	"dijit/registry"],
 
-dojo.experimental("dojox.widget.Standby");
+function(kernel,
+		declare,
+		array,
+		event,
+		has,
+		dom,
+		attr,
+		construct,
+		geometry,
+		domStyle,
+		window,
+		baseWindow,
+		baseFx,
+		fx,
+		_Widget,
+		_TemplatedMixin,
+		registry) {
 
-dojo.declare("dojox.widget.Standby",[dijit._Widget, dijit._Templated],{
+kernel.experimental("dojox.widget.Standby");
+
+return declare("dojox.widget.Standby", [_Widget, _TemplatedMixin],{
 	// summary:
 	//		A widget designed to act as a Standby/Busy/Disable/Blocking widget to indicate a
 	//		particular DOM node is processing and cannot be clicked on at this time.
@@ -72,11 +106,11 @@ dojo.declare("dojox.widget.Standby",[dijit._Widget, dijit._Templated],{
 
 	// image: String
 	//		The URL to the image to center in the overlay.
-	image: dojo.moduleUrl("dojox", "widget/Standby/images/loading.gif").toString(),
+	image: require.toUrl("dojox/widget/Standby/images/loading.gif").toString(),
 
 	// imageText: String
 	//		Text for the ALT tag.
-	imageText: "Please Wait...",
+	imageText: "Please Wait...", // TODO: i18n
 
 	// text: String
 	//		Text/HTML to display in the center of the overlay
@@ -134,12 +168,8 @@ dojo.declare("dojox.widget.Standby",[dijit._Widget, dijit._Templated],{
 		//		Configures the target node and sets the image to use.
 		if(!this._started){
 			if(typeof this.target === "string"){
-				var w = dijit.byId(this.target);
-				if(w){
-					this.target = w.domNode;
-				}else{
-					this.target = dojo.byId(this.target);
-				}
+				var w = registry.byId(this.target);
+				this.target = w ? w.domNode : dom.byId(this.target);
 			}
 
 			if(this.text){
@@ -147,38 +177,39 @@ dojo.declare("dojox.widget.Standby",[dijit._Widget, dijit._Templated],{
 			}
 			if(this.centerIndicator === "image"){
 				this._centerNode = this._imageNode;
-				dojo.attr(this._imageNode, "src", this.image);
-				dojo.attr(this._imageNode, "alt", this.imageText);
+				attr.set(this._imageNode, "src", this.image);
+				attr.set(this._imageNode, "alt", this.imageText);
 			}else{
 				this._centerNode = this._textNode;
 			}
-			dojo.style(this._underlayNode, {
+			domStyle.set(this._underlayNode, {
 				display: "none",
 				backgroundColor: this.color
 			});
-			dojo.style(this._centerNode, "display", "none");
+			domStyle.set(this._centerNode, "display", "none");
 			this.connect(this._underlayNode, "onclick", "_ignore");
 
 			//Last thing to do is move the widgets parent, if any, to the current document body.
 			//Avoids having to deal with parent relative/absolute mess.  Otherwise positioning
 			//tends to go goofy.
-			if(this.domNode.parentNode && this.domNode.parentNode != dojo.body()){
-				dojo.body().appendChild(this.domNode);
+			if(this.domNode.parentNode && this.domNode.parentNode != baseWindow.body()){
+				baseWindow.body().appendChild(this.domNode);
 			}
 
 			//IE 7 has a horrible bug with zoom, so we have to create this node
 			//to cross-check later.  Sigh.
-			if(dojo.isIE == 7){
-				this._ieFixNode = dojo.doc.createElement("div");
-				dojo.style(this._ieFixNode, {
+			if(has("ie") == 7){
+				this._ieFixNode = construct.create("div");
+				domStyle.set(this._ieFixNode, {
 					opacity: "0",
 					zIndex: "-1000",
 					position: "absolute",
 					top: "-1000px"
 				});
-				dojo.body().appendChild(this._ieFixNode);
+				baseWindow.body().appendChild(this._ieFixNode);
 			}
-		}
+			this.inherited(arguments);
+		}		
 	},
 
 	show: function(){
@@ -239,10 +270,10 @@ dojo.declare("dojox.widget.Standby",[dijit._Widget, dijit._Templated],{
 		if(this._resizeCheck){
 			clearInterval(this._resizeCheck);
 		}
-		dojo.style(this._centerNode, "display", "none");
-		dojo.style(this._underlayNode, "display", "none");
-		if(dojo.isIE == 7){
-			dojo.body().removeChild(this._ieFixNode);
+		domStyle.set(this._centerNode, "display", "none");
+		domStyle.set(this._underlayNode, "display", "none");
+		if(has("ie") == 7 && this._ieFixNode){
+			baseWindow.body().removeChild(this._ieFixNode);
 			delete this._ieFixNode;
 		}
 		if(this._anim){
@@ -263,7 +294,7 @@ dojo.declare("dojox.widget.Standby",[dijit._Widget, dijit._Templated],{
 		// tags:
 		//		private
 		if(this._displayed){
-			var dir = dojo.attr(dojo.body(), "dir");
+			var dir = attr.get(baseWindow.body(), "dir");
 			if(dir){dir = dir.toLowerCase();}
 			var _ie7zoom;
 			var scrollers = this._scrollerWidths();
@@ -271,18 +302,18 @@ dojo.declare("dojox.widget.Standby",[dijit._Widget, dijit._Templated],{
 			var target = this.target;
 
 			//Show the image and make sure the zIndex is set high.
-			var curStyle = dojo.style(this._centerNode, "display");
-			dojo.style(this._centerNode, "display", "block");
-			var box = dojo.position(target, true);
-			if(target === dojo.body() || target === dojo.doc){
+			var curStyle = domStyle.get(this._centerNode, "display");
+			domStyle.set(this._centerNode, "display", "block");
+			var box = geometry.position(target, true);
+			if(target === baseWindow.body() || target === baseWindow.doc){
 				// Target is the whole doc, so scale to viewport.
-				box = dojo.window.getBox();
+				box = window.getBox();
 				box.x = box.l;
 				box.y = box.t;
 			}
 
-			var cntrIndicator = dojo.marginBox(this._centerNode);
-			dojo.style(this._centerNode, "display", curStyle);
+			var cntrIndicator = geometry.getMarginBox(this._centerNode);
+			domStyle.set(this._centerNode, "display", curStyle);
 
 			//IE has a horrible zoom bug.  So, we have to try and account for
 			//it and fix up the scaling.
@@ -295,7 +326,7 @@ dojo.declare("dojox.widget.Standby",[dijit._Widget, dijit._Templated],{
 			}
 
 			//Figure out how to zIndex this thing over the target.
-			var zi = dojo.style(target, "zIndex");
+			var zi = domStyle.get(target, "zIndex");
 			var ziUl = zi;
 			var ziIn = zi;
 
@@ -308,8 +339,8 @@ dojo.declare("dojox.widget.Standby",[dijit._Widget, dijit._Templated],{
 					//are any parent zIndexs to overlay.
 					var cNode = target.parentNode;
 					var oldZi = -100000;
-					while(cNode && cNode !== dojo.body()){
-						zi = dojo.style(cNode, "zIndex");
+					while(cNode && cNode !== baseWindow.body()){
+						zi = domStyle.get(cNode, "zIndex");
 						if(!zi || zi === "auto"){
 							cNode = cNode.parentNode;
 						}else{
@@ -329,14 +360,14 @@ dojo.declare("dojox.widget.Standby",[dijit._Widget, dijit._Templated],{
 				ziIn = parseInt(this.zIndex, 10) + 2;
 			}
 
-			dojo.style(this._centerNode, "zIndex", ziIn);
-			dojo.style(this._underlayNode, "zIndex", ziUl);
+			domStyle.set(this._centerNode, "zIndex", ziIn);
+			domStyle.set(this._underlayNode, "zIndex", ziUl);
 
 
 			var pn = target.parentNode;
-			if(pn && pn !== dojo.body() &&
-				target !== dojo.body() &&
-				target !== dojo.doc){
+			if(pn && pn !== baseWindow.body() &&
+				target !== baseWindow.body() &&
+				target !== baseWindow.doc){
 				
 				// If the parent is the body tag itself,
 				// we can avoid all this, the body takes
@@ -346,7 +377,7 @@ dojo.declare("dojox.widget.Standby",[dijit._Widget, dijit._Templated],{
 				// anyway.
 				var obh = box.h;
 				var obw = box.w;
-				var pnBox = dojo.position(pn, true);
+				var pnBox = geometry.position(pn, true);
 
 				//More IE zoom corrections.  Grr.
 				if(this._ieFixNode){
@@ -367,15 +398,15 @@ dojo.declare("dojox.widget.Standby",[dijit._Widget, dijit._Templated],{
 				//(and differently depending on browser, ugh!)
 				//WebKit and others still need work.
 				if(dir === "rtl"){
-					if(dojo.isOpera){
+					if(has("opera")){
 						box.x += pn.scrollHeight > pn.clientHeight &&
 							pn.clientHeight > 0 ? scrollers.v: 0;
 						pnBox.x += pn.scrollHeight > pn.clientHeight &&
 							pn.clientHeight > 0 ? scrollers.v: 0;
-					}else if(dojo.isIE){
+					}else if(has("ie")){
 						pnBox.x += pn.scrollHeight > pn.clientHeight &&
 							pn.clientHeight > 0 ? scrollers.v: 0;
-					}else if(dojo.isWebKit){
+					}else if(has("webkit")){
 						//TODO:  FIX THIS!
 					}
 				}
@@ -455,7 +486,7 @@ dojo.declare("dojox.widget.Standby",[dijit._Widget, dijit._Templated],{
 
 			if(box.h > 0 && box.w > 0){
 				//Set position and size of the blocking div overlay.
-				dojo.style(this._underlayNode, {
+				domStyle.set(this._underlayNode, {
 					display: "block",
 					width: box.w + "px",
 					height: box.h + "px",
@@ -467,7 +498,7 @@ dojo.declare("dojox.widget.Standby",[dijit._Widget, dijit._Templated],{
 					"borderTopRightRadius","borderBottomLeftRadius",
 					"borderBottomRightRadius"];
 				this._cloneStyles(styles);
-				if(!dojo.isIE){
+				if(!has("ie")){
 					//Browser specific styles to try and clone if non-IE.
 					styles = ["MozBorderRadius", "MozBorderRadiusTopleft",
 						"MozBorderRadiusTopright","MozBorderRadiusBottomleft",
@@ -481,18 +512,18 @@ dojo.declare("dojox.widget.Standby",[dijit._Widget, dijit._Templated],{
 				var cntrIndicatorLeft = (box.w/2) - (cntrIndicator.w/2);
 				//Only show the image if there is height and width room.
 				if(box.h >= cntrIndicator.h && box.w >= cntrIndicator.w){
-					dojo.style(this._centerNode, {
+					domStyle.set(this._centerNode, {
 						top: (cntrIndicatorTop + box.y) + "px",
 						left: (cntrIndicatorLeft + box.x) + "px",
 						display: "block"
 					});
 				}else{
-					dojo.style(this._centerNode, "display", "none");
+					domStyle.set(this._centerNode, "display", "none");
 				}
 			}else{
 				//Target has no size, display nothing on it!
-				dojo.style(this._underlayNode, "display", "none");
-				dojo.style(this._centerNode, "display", "none");
+				domStyle.set(this._underlayNode, "display", "none");
+				domStyle.set(this._centerNode, "display", "none");
 			}
 			if(this._resizeCheck === null){
 				//Set an interval timer that checks the target size and scales as needed.
@@ -512,8 +543,8 @@ dojo.declare("dojox.widget.Standby",[dijit._Widget, dijit._Templated],{
 		//
 		// tags:
 		//		private
-		dojo.forEach(list, function(style){
-			dojo.style(this._underlayNode,style,dojo.style(this.target,style));
+		array.forEach(list, function(s){
+			domStyle.set(this._underlayNode, s, domStyle.get(this.target, s));
 		}, this);
 	},
 
@@ -523,12 +554,12 @@ dojo.declare("dojox.widget.Standby",[dijit._Widget, dijit._Templated],{
 		// tags:
 		//		private
 		var self = this;
-		var underlayNodeAnim = dojo.animateProperty({
+		var underlayNodeAnim = baseFx.animateProperty({
 			duration: self.duration,
 			node: self._underlayNode,
 			properties: {opacity: {start: 0, end: 0.75}}
 		});
-		var imageAnim = dojo.animateProperty({
+		var imageAnim = baseFx.animateProperty({
 			duration: self.duration,
 			node: self._centerNode,
 			properties: {opacity: {start: 0, end: 1}},
@@ -537,7 +568,7 @@ dojo.declare("dojox.widget.Standby",[dijit._Widget, dijit._Templated],{
 				delete self._anim;
 			}
 		});
-		this._anim = dojo.fx.combine([underlayNodeAnim,imageAnim]);
+		this._anim = fx.combine([underlayNodeAnim,imageAnim]);
 		this._anim.play();
 	},
 
@@ -547,38 +578,38 @@ dojo.declare("dojox.widget.Standby",[dijit._Widget, dijit._Templated],{
 		// tags:
 		//		private
 		var self = this;
-		var underlayNodeAnim = dojo.animateProperty({
+		var underlayNodeAnim = baseFx.animateProperty({
 			duration: self.duration,
 			node: self._underlayNode,
 			properties: {opacity: {start: 0.75, end: 0}},
 			onEnd: function(){
-				dojo.style(this.node,{"display":"none", "zIndex": "-1000"});
+				domStyle.set(this.node,{"display":"none", "zIndex": "-1000"});
 			}
 		});
-		var imageAnim = dojo.animateProperty({
+		var imageAnim = baseFx.animateProperty({
 			duration: self.duration,
 			node: self._centerNode,
 			properties: {opacity: {start: 1, end: 0}},
 			onEnd: function(){
-				dojo.style(this.node,{"display":"none", "zIndex": "-1000"});
+				domStyle.set(this.node,{"display":"none", "zIndex": "-1000"});
 				self.onHide();
 				self._enableOverflow();
 				delete self._anim;
 			}
 		});
-		this._anim = dojo.fx.combine([underlayNodeAnim,imageAnim]);
+		this._anim = fx.combine([underlayNodeAnim,imageAnim]);
 		this._anim.play();
 	},
 
-	_ignore: function(event){
+	_ignore: function(e){
 		// summary:
 		//		Function to ignore events that occur on the overlay.
 		// event: Event
 		//		The event to halt
 		// tags:
 		//		private
-		if(event){
-			dojo.stopEvent(event);
+		if(e){
+			event.stop(e);
 		}
 	},
 
@@ -591,8 +622,8 @@ dojo.declare("dojox.widget.Standby",[dijit._Widget, dijit._Templated],{
 		//		and h is horizontal scrollbar width.
 		// tags:
 		//		private
-		var div = dojo.doc.createElement("div");
-		dojo.style(div, {
+		var div = construct.create("div");
+		domStyle.set(div, {
 			position: "absolute",
 			opacity: 0,
 			overflow: "hidden",
@@ -600,25 +631,24 @@ dojo.declare("dojox.widget.Standby",[dijit._Widget, dijit._Templated],{
 			height: "50px",
 			zIndex: "-100",
 			top: "-200px",
-			left: "-200px",
 			padding: "0px",
 			margin: "0px"
 		});
-		var iDiv = dojo.doc.createElement("div");
-		dojo.style(iDiv, {
+		var iDiv = construct.create("div");
+		domStyle.set(iDiv, {
 			width: "200px",
 			height: "10px"
 		});
 		div.appendChild(iDiv);
-		dojo.body().appendChild(div);
+		baseWindow.body().appendChild(div);
 
 		//Figure out content size before and after
 		//scrollbars are there, then just subtract to
 		//get width.
-		var b = dojo.contentBox(div);
-		dojo.style(div, "overflow", "scroll");
-		var a = dojo.contentBox(div);
-		dojo.body().removeChild(div);
+		var b = geometry.getContentBox(div);
+		domStyle.set(div, "overflow", "scroll");
+		var a = geometry.getContentBox(div);
+		baseWindow.body().removeChild(div);
 		return { v: b.w - a.w, h: b.h - a.h };
 	},
 
@@ -640,7 +670,7 @@ dojo.declare("dojox.widget.Standby",[dijit._Widget, dijit._Templated],{
 		//		div overlay.
 		// c: String
 		//		The color to set the background underlay to in #XXXXXX format..
-		dojo.style(this._underlayNode, "backgroundColor", c);
+		domStyle.set(this._underlayNode, "backgroundColor", c);
 		this.color = c;
 	},
 
@@ -650,7 +680,7 @@ dojo.declare("dojox.widget.Standby",[dijit._Widget, dijit._Templated],{
 		//		the image (if using image center display).
 		// text: String
 		//		The text to set.
-		dojo.attr(this._imageNode, "alt", text);
+		attr.set(this._imageNode, "alt", text);
 		this.imageText = text;
 	},
 
@@ -659,7 +689,7 @@ dojo.declare("dojox.widget.Standby",[dijit._Widget, dijit._Templated],{
 		//		Function to allow widget.attr to set the url source for the center image
 		// text: String
 		//		The url to set for the image.
-		dojo.attr(this._imageNode, "src", url);
+		attr.set(this._imageNode, "src", url);
 		this.image = url;
 	},
 
@@ -672,10 +702,10 @@ dojo.declare("dojox.widget.Standby",[dijit._Widget, dijit._Templated],{
 		this.centerIndicator = indicator;
 		if(indicator === "image"){
 			this._centerNode = this._imageNode;
-			dojo.style(this._textNode, "display", "none");
+			domStyle.set(this._textNode, "display", "none");
 		}else{
 			this._centerNode = this._textNode;
-			dojo.style(this._imageNode, "display", "none");
+			domStyle.set(this._imageNode, "display", "none");
 		}
 	},
 
@@ -683,17 +713,17 @@ dojo.declare("dojox.widget.Standby",[dijit._Widget, dijit._Templated],{
 		 // summary:
 		 //		Function to disable scrollbars on the body.  Only used if the overlay
 		 //		targets the body or the document.
-		 if(this.target === dojo.body() || this.target === dojo.doc){
+		 if(this.target === baseWindow.body() || this.target === baseWindow.doc){
 			 // Store the overflow state we have to restore later.
 			 // IE had issues, so have to check that it's defined.  Ugh.
 			 this._overflowDisabled = true;
-			 var body = dojo.body();
+			 var body = baseWindow.body();
 			 if(body.style && body.style.overflow){
-				 this._oldOverflow = dojo.style(body, "overflow");
+				 this._oldOverflow = domStyle.set(body, "overflow");
 			 }else{
 				 this._oldOverflow = "";
 			 }
-			 if(dojo.isIE && !dojo.isQuirks){
+			 if(has("ie") && !has("quirks")){
 				 // IE will put scrollbars in anyway, html (parent of body)
 				 // also controls them in standards mode, so we have to
 				 // remove them, argh.
@@ -703,14 +733,14 @@ dojo.declare("dojox.widget.Standby",[dijit._Widget, dijit._Templated],{
 					 this._oldBodyParentOverflow = body.parentNode.style.overflow;
 				 }else{
 					 try{
-						this._oldBodyParentOverflow = dojo.style(body.parentNode, "overflow");
+						this._oldBodyParentOverflow = domStyle.set(body.parentNode, "overflow");
 					 }catch(e){
 						 this._oldBodyParentOverflow = "scroll";
 					 }
 				 }
-				 dojo.style(body.parentNode, "overflow", "hidden");
+				 domStyle.set(body.parentNode, "overflow", "hidden");
 			 }
-			 dojo.style(body, "overflow", "hidden");
+			 domStyle.set(body, "overflow", "hidden");
 		 }
 	},
 
@@ -720,16 +750,16 @@ dojo.declare("dojox.widget.Standby",[dijit._Widget, dijit._Templated],{
 		 //		targets the body or the document.
 		 if(this._overflowDisabled){
 			delete this._overflowDisabled;
-			var body = dojo.body();
+			var body = baseWindow.body();
 			// Restore all the overflow.
-			if(dojo.isIE && !dojo.isQuirks){
+			if(has("ie") && !has("quirks")){
 				body.parentNode.style.overflow = this._oldBodyParentOverflow;
 				delete this._oldBodyParentOverflow;
 			}
-			dojo.style(body, "overflow", this._oldOverflow);
-			if(dojo.isWebKit){
+			domStyle.set(body, "overflow", this._oldOverflow);
+			if(has("webkit")){
 				//Gotta poke WebKit, or scrollers don't come back. :-(
-				var div = dojo.create("div", { style: {
+				var div = construct.create("div", { style: {
 						height: "2px"
 					}
 				});
@@ -743,6 +773,4 @@ dojo.declare("dojox.widget.Standby",[dijit._Widget, dijit._Templated],{
 	}
 });
 
-return dojox.widget.Standby;
-
 });
