@@ -1,3 +1,5 @@
+define(
+//begin v1.x content
 ({
 redLabel: "k",
 greenLabel: "y",
@@ -5,6 +7,8 @@ blueLabel: "m",
 hueLabel: "t",
 saturationLabel: "d",
 valueLabel: "d", /* aka intensity or brightness */
-hexLabel: "onaltılı"
+hexLabel: "onaltılı",
+huePickerTitle: "Ton Seçici",
+saturationPickerTitle: "Doygunluk Seçici"
 })
-
+);
