@@ -7,7 +7,7 @@ dojo.require("dijit._Container");
 
 dojo.declare("dojox.wire.demos.WidgetRepeater", [ dijit._Widget, dijit._Templated, dijit._Container ], {
 	//	summary:
-	//		Simple widget that does generation of widgets repetatively, based on calls to 
+	//		Simple widget that does generation of widgets repetatively, based on calls to
 	//		the createNew function and contains them as child widgets.
 	templateString: "<div class='WidgetRepeater' dojoAttachPoint='repeaterNode'></div>",
 	widget: null,
@@ -15,11 +15,11 @@ dojo.declare("dojox.wire.demos.WidgetRepeater", [ dijit._Widget, dijit._Template
 	createNew: function(obj){
 		//	summary:
 		//		Function to handle the creation of a new widget and appending it into the widget tree.
-		//	obj:	
+		//	obj:
 		//		The parameters to pass to the widget.
 		try{
 			if(dojo.isString(this.widget)){
-				dojo.require(this.widget);
+				// dojo.require(this.widget);	confuses new AMD builder, include resource manually first
 				this.widget = dojo.getObject(this.widget);
 			}
 			this.addChild(new this.widget(obj));
