@@ -1,13 +1,4 @@
-if(window["dojo"]){
-	dojo.provide("doh.robot");
-	dojo.experimental("doh.robot");
-	dojo.require("doh.runner");
-}else if(!doh["robot"]){
-	doh.robot={};
-}
-
-if(!doh.robot["_robotLoaded"]){
-(function(){
+define(["doh/_browserRunner", "require"], function(doh, require){
 
 	// loading state
 	var _robot = null;
@@ -25,7 +16,7 @@ if(!doh.robot["_robotLoaded"]){
 	doh.run = function(){
 		if(!doh.robot._runsemaphore.unlock()){
 			// hijack doh._onEnd to clear the applet
-			// have to do it here because _browserRunner sets it in onload in standalone case
+			// have to do it here because browserRunner sets it in onload in standalone case
 			var __onEnd = doh._onEnd;
 			doh._onEnd = function(){
 				doh.robot.killRobot();
@@ -59,7 +50,7 @@ if(!doh.robot["_robotLoaded"]){
 	// prime the event pump for fast browsers like Google Chrome - it's so fast, it doesn't stop to listen for keypresses!
 	_spaceReceived: false,
 	_primePump: false,
-	
+
 	_killApplet: function(){}, // overridden by Robot.html
 
 	killRobot: function(){
@@ -86,7 +77,7 @@ if(!doh.robot["_robotLoaded"]){
 			}
 		}
 	},
-	
+
 	startRobot: function(){
 		//startRobot should be called to initialize the robot (after the java applet is loaded).
 		//one good place to do this is in a dojo.addOnLoad handler. This function will be called
@@ -487,7 +478,7 @@ if(!doh.robot["_robotLoaded"]){
 			_robot.wheelMouse(isSecure(), Number(wheelAmt), Number(0), Number(duration||0));
 		},delay,duration);
 	},
-	
+
 	setClipboard: function(/*String*/data,/*String, optional*/format){
 		// summary:
 		//		Set clipboard content.
@@ -525,9 +516,8 @@ if(!doh.robot["_robotLoaded"]){
 	// if loaded with dojo, there might not be a runner.js!
 	if(!iframesrc && window["dojo"]){
 		// if user set document.domain to something else, send it to the Robot too
-		iframesrc = dojo.moduleUrl("util", "doh/")+"Robot.html?domain="+escape(document.domain);
+		iframesrc = require.toUrl("./Robot.html") + "?domain=" + escape(document.domain);
 	}
 	document.writeln('<div id="dohrobotview" style="border:0px none; margin:0px; padding:0px; position:absolute; bottom:0px; right:0px; width:1px; height:1px; overflow:hidden; visibility:hidden; background-color:red;"></div>'+
 		'<iframe application="true" style="border:0px none; z-index:32767; padding:0px; margin:0px; position:absolute; left:0px; top:0px; height:42px; width:200px; overflow:hidden; background-color:transparent;" tabIndex="-1" src="'+iframesrc+'" ALLOWTRANSPARENCY="true"></iframe>');
-})();
-}
+});
